(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    164344,       6178]*)
(*NotebookOutlinePosition[    193121,       7108]*)
(*  CellTagsIndexPosition[    192998,       7100]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Non-Euclidean Geometry", "Title",
  TextAlignment->Center,
  FontSize->35],

Cell["by Rolf Sulanke", "Subtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman"],

Cell["May 24, 2005", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontSize->13,
  Background->None],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Left,
  FontFamily->"Times New Roman"],

Cell["\<\
This notebook contains the basic definition of  concepts and constructions in \
the non-euclidean plane. Pseudo-euclidean vector algebra,  treated in the \
notebook pseuklid.nb in details, has been included for convenience;  now, in \
the package neuvec.m, the shape of  the scalar product pssp has been changed: \
in accordance with the book [2] the pseudo-orthonormal  bases start with the \
timelike vector stb[1].  Therefore the notebook is not compatible with the \
elder package pseuvec.m and the notebook pseuklid.nb, in which the last \
coordinate of the space  is timelike. Since pseudo-euclidean vector algebra  \
is needed for many applications in distinct dimensions and indexes, we \
present the new version in section 2 for arbitrary finite values of dim and \
ind. The main result described in this notebook is the classification of  the \
quadrics of the hyperbolic plane up to isometric motions. The theoretical \
background can be found in reference [2]. \
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection"],

Cell[TextData[{
  "This notebook is  yet a beta version  0.8. The work began January 22, \
2005. It has been created with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.2"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Keywords", "Subsubsection"],

Cell["\<\
Dimension dim, index ind, pseudo-euclidean scalar product, generalized cross \
product, spacelike, timelike, isotropic vectors, norming, pseudo-orthogonal \
basis.
Stereographic projection.,Klein model, , conformal model, Poincar\[EAcute] \
model of the non-euclidean plane. Symmetric operators. Quadrics i the \
non-euclidean plane.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names with the condition that they cite the \
original notebook with the Internet address or other sources where they got \
it. I am not responsible for errors or damages originated by the use of the \
procedures contained in my notebooks or packages; anybody who applies them \
should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  FontFamily->"Times"],

Cell["\<\
First, if not done already,  copy the needed package  euvec.m, neuvec.m, and \
this notebook noeuklid2D.nb  into your working directory, and  insert the \
path of your working directory, e.g. under Windows, \"C:\\Eigene \
Dateien\\mymath\\mathwork\", into the next command line:\
\>", "Text"],

Cell[BoxData[
    \(SetDirectory["\<C:\\Dokumente und Einstellungen\\rolf\\Eigene \
Dateien\\mymath\\mathwork\>"]\)], "Input",
  CellLabel->"In[9]:=",
  FontFamily->"Times New Roman"],

Cell["For Unix, e.g.", "Text"],

Cell[BoxData[
    \(SetDirectory["\<~/mymath/mathwork\>"]\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[TextData[StyleBox["Now: Activite Kernel/Evaluation/Evaluate \
Initialization from the menu!",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
    \(Needs["\<neuvec`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
Remark. With this command, the package euvec.m is imported automatically.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["1. Introduction.  The usages. Tools", "Section"],

Cell[CellGroupData[{

Cell["1.1 Dimension and index", "Subsection"],

Cell["\<\
This notebook aims to non-euclidean geometry of dimension n. Being the \
beginning of our considerations it treats the case n=2 of the non-eucidean  \
plane only. The model is the hyperboloid in the pseudo-euclidean vector space \
of dimension n+1, with index 1. Therefore we set\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(dim\  = \ 3; ind = 1;\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True,
  FontSize->15],

Cell[TextData[{
  "Always have in mind that almost all the defined concepts  depend on dim \
and ind; if you want to change the default values, simply enter the commands\n\
dim = n; ind = m;\n where n and m, 0 \[LessEqual] m \[LessEqual] n,  are \
integers, your preferred values.  At the initialization of  the notebook, \
leave the dimension be dim = 3, since otherwise some of  the initialization \
cells may not be evaluated. The ",
  StyleBox["pseudo-euclidean model ",
    FontColor->RGBColor[0, 0, 1]],
  "of  the non-euclidean plane can be visualized as the upper (or right)  \
half of the hyperboloid, beeing the \"sphere\" of imaginary radius i*r, r>0. \
defined by the equation"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(pssp[vec[x], vec[x]]\  \[Equal] \ \(-r^2\)\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True],

Cell[BoxData[
    \(hyperboloid[s_, t_, \ r_:  1]\  := \ 
      r*{Cosh[t], Sinh[t]*Sin[s], \ Sinh[t]*Cos[s]}\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \(ParametricPlot3D[hyperboloid[s, t], {s, 0, 2*Pi}, \ {t, 0, 3}, 
      PlotPoints\  \[Rule] 30, PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell[BoxData[
    \(pseusph\  = \ %\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell["\<\
The parameter r>0 defines the metric of  the plane. Since we have to consider \
 the linear  transformations of the vector space preserving these \
hyperboloids we are lead to  the pseudo-euclidean vector spaces of dimmension \
n=3 and index 1. The basic concepts used in the pseudo-euclidean vector \
algebra are contained  in the package neuvec.m, which automatically imports \
the package euvec.m containing general definitions of  n-dimensional linear \
algebra. \
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell["\<\
F. Klein introduced another model of the non-euclidean plane, namely the \
inner points of the unit disk.  To any timelike vector, especially to any \
vector of the hyperboloid just defined, corresponds a point of the unit disk \
in the euclidean hyperplane x[1] = 0.\
\>", "Text"],

Cell[BoxData[
    \(eucl[v_List]\  := \ 
      Module[{u, l = Length[v]}, \ \[IndentingNewLine]u\  = 
          Take[v, \(-l\) + 1]/v[\([1]\)]]\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell[TextData[{
  "This correpondence is a bijection between the points of the upper bowl \
(x[1]>0) of the hyperboloid and the points of the unit disk. This model we \
call the ",
  StyleBox["Klein model ",
    FontColor->RGBColor[0, 0, 1]],
  "of the hyperbolic plane.\n",
  StyleBox["Warning:",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  "the function eucl is defined for all Lists v, but it has a geometric \
meaning for non-euclidean geometry only if it is restricted to timelike \
vectors.  Of course, if v[[1]] = 0, the result is indetermined:"
}], "Text",
  FontSize->13,
  CellTags->"Euklid"],

Cell[BoxData[
    \(eucl[stb[3]]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(eucl[{2, 1, 0}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(eucl[{2/Sqrt[3], 1/Sqrt[3], 0}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(eucl[{2*a, 1*a, 0}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(eucl[{1, 0, 0}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(eucl[{1, 0, 1}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(eucl[{1, 1, 0}]\)], "Input",
  CellLabel->"In[61]:="],

Cell["\<\
Sometimes we shall need the graphics of the unit circle for visualizing the \
hyperbolic plane:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[{Cos[t], Sin[t]}, {t, 0, 2*Pi}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True],

Cell[BoxData[
    \(klkr\  = \ %\)], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True],

Cell["\<\
The hyperbolic lines are the intersections of the projective lines with the \
inner region of the defining ellipsoid or ellipse.  They are mapped on the \
chords of the Klein model.  A family of hyperbolic lines depending on a \
parameter a, considered in the pseudo-euclidean model let have the parameter \
representation (with line parameter t):\
\>", "Text"],

Cell[BoxData[
    \(\(hypline[a_]\)[t_]\  := \ 
      stb[1]*Cosh[t]\  + \((stb[2]*Cos[a]\  + stb[3]*Sin[a])\)*
          Sinh[t]\)], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True],

Cell[BoxData[
    \(a\  = \ 0.1; 
    ParametricPlot[eucl[\(hypline[a]\)[t]], {t, \(-10\), 10}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Show[{klkr, %}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(ParametricPlot[eucl[\(hypline[0]\)[t]], {t, \(-10\), 10}, 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[64]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 The usages", "Subsection"],

Cell[TextData[{
  "Here is an overview of the symbols,   introduced in the packages euvec.m, \
neuvec.m,  and their usages. In difference to the names used in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the names introduced in our packages begin with small letters. To read \
the usages first initialize the notebook. "
}], "Text"],

Cell["\<\
If you want information about the  loaded concepts, enter e.g.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(?ide\)\)], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  FontSize->15],

Cell["\<\
 Often you can inform yourself about the definitions by evoking or applying \
them:\
\>", "Text"],

Cell[BoxData[
    \(ide[]\)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True],

Cell["The standard basis is", "Text"],

Cell[BoxData[
    \(Table[stb[i], {i, \ dim}]\)], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True],

Cell["\<\
and the matrix of the scalar products of the basis vectors is\
\>", "Text"],

Cell[BoxData[
    \(Table[pssp[stb[i], \ stb[j]], \ {i, dim}, \ {j, dim}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True],

Cell["Here pssp denotes the pseudo-euclidean scalar product.", "Text"],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[67]:="],

Cell["\<\
For convenience, all the definitions contained in the packages euvec.m and \
neuvec.m are listed in the next subsections.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Concepts in euvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell["Valid for arbitrary values of the dimension dim are", "Text"],

Cell[BoxData[
    \(\(?null\)\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?vec\)\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?randomv\)\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?stb\)\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?cross\)\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?outzero\)\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?rank\)\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?basis\)\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sterproj\)\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?invsterproj\)\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?hyperplane\)\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?stb\)\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?unit\)\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphericalreflection\)\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?esorthonorm\)\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?innerprod\)\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?orthocomplement\)\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?normed\)\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?print\)\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?renorm\)\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?smoothing\)\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell["The following commands work in dimensions  4 or 3  only:", "Text"],

Cell[BoxData[
    \(\(?tg4frame\)\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphere\)\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphereplot3D\)\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?subsphere\)\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?subspheremf\)\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Concepts in neuvec.m:",
  FontSize->12]], "Subsubsection",
  FontSize->10],

Cell[BoxData[
    \(\(?ide\)\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(\(?dual\)\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(\(?psCross\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(\(?pscross\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(\(?pr\)\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Options[orthonorm]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(\(?normed\)\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(\(?print\)\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(\(?normalize\)\)], "Input",
  CellLabel->"In[103]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Full definitions", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
For getting the usage together with the complete definition, enter the name \
prepended with two ?, e.g.\
\>", "Text"],

Cell[BoxData[
    \(?? ind\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? esorthonorm\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(?? nullmatrix\)], "Input",
  CellLabel->"In[107]:="],

Cell["\<\
Since the names are prepended by the ContextNames the definitions obtained in \
this way are hard to read. Therefore you will find some of them in the \
original form in unevaluatable cells.  For other ones it is recommended to \
look into the package.\
\>", "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3 Tools", "Subsection"],

Cell["\<\
In this section we introduce some simple concepts often useful for handling \
of matrices and transformations, \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
1.3.1 General matrix. Transposition matrix. Reflection at hyperplanes\
\>", "Subsubsection"],

Cell[TextData[{
  "This is a ",
  StyleBox["general square matrix ",
    FontColor->RGBColor[0, 0, 1]],
  "with elements b[i,j]"
}], "Text"],

Cell[BoxData[
    \(matrix[b_, n_:  dim] := \ Table[b[i, j], {i, n}, {j, n}]\)], "Input",
  CellLabel->"In[16]:=",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Transposition:",
    FontColor->RGBColor[0, 0, 1]],
  " The following module transposes two coordinates resp. basis elements"
}], "Text"],

Cell[BoxData[
    \(trp[i_, j_, n_:  dim] := 
      Module[{m = IdentityMatrix[n]}, \ 
        m[\([i]\)] = stb[j, n]; \[IndentingNewLine]m[\([j]\)] = 
          stb[i, n]; \[IndentingNewLine]m]\)], "Input",
  CellLabel->"In[17]:=",
  InitializationCell->True],

Cell[BoxData[
    \(matrix[b] // MatrixForm\)], "Input",
  CellLabel->"In[46]:="],

Cell["Now we transpose two rows of the matrix:", "Text"],

Cell[BoxData[
    \(trp[1, 3] . % // MatrixForm\)], "Input",
  CellLabel->"In[47]:="],

Cell["The next result show two transposed columns:", "Text"],

Cell[BoxData[
    \(%% . trp[1, 3] // MatrixForm\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(trp[1, 3] . % // MatrixForm\)], "Input",
  CellLabel->"In[49]:="],

Cell[TextData[{
  StyleBox["Reflection",
    FontColor->RGBColor[0, 0, 1]],
  " at the hyperplane x[i]\[Equal] 0:"
}], "Text"],

Cell[BoxData[
    \(refl[i_, n_:  dim]\  := 
      Module[{mm = 
            IdentityMatrix[n]}, \[IndentingNewLine]mm[\([i, 
              i]\)] = \ \(-1\); \[IndentingNewLine]mm]\)], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True],

Cell[BoxData[
    \(refl[2] . vec[x]\)], "Input",
  CellLabel->"In[85]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2. Vector Operations in Euclidean and Pseudo-Euclidean Spaces\
\>", "Section",
  Evaluatable->False,
  Background->None],

Cell[CellGroupData[{

Cell["2.1 Basic definitions", "Subsection",
  Evaluatable->False,
  FontSize->14,
  Background->None],

Cell["\<\
Of course, we can apply all the operations of real linear vector algebra. We \
have the null vector:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(\(\n\)\(null[]\)\)\)], "Input",
  CellLabel->"In[68]:=",
  FontSize->15],

Cell["The standard basis is:", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(Table[stb[i], {i, \ dim}]\)], "Input",
  CellLabel->"In[69]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->15,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->None],

Cell["\<\
The basic concept of pseudo-euclidean geometry is the indefinite scalar \
product pssp. 
The standard basis {stb[i]} is orthonormal with respect to this scalar \
product; the matrix of the scalar products is the Gram matrix:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(gram\  := 
      Table[pssp[stb[i], \ stb[j]], \ {i, \ dim}, \ {j, \ dim}]\)], "Input",
  CellLabel->"In[19]:=",
  InitializationCell->True],

Cell[BoxData[
    \(MatrixForm[gram]\)], "Input",
  CellLabel->"In[20]:=",
  PageWidth->Infinity,
  InitializationCell->True,
  FontSize->15,
  Background->None],

Cell["The diagonal of this matrix is", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(ide[]\)], "Input",
  CellLabel->"In[72]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["The dualization of a vector ", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(vec[x]\)], "Input",
  CellLabel->"In[73]:=",
  FontSize->15],

Cell[" is given by", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(dual[vec[x]]\)], "Input",
  CellLabel->"In[74]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(% \[Equal] gram . vec[x]\)], "Input",
  CellLabel->"In[75]:="],

Cell[TextData[{
  "This corresponds to the dual coordinates of a vector in Riemannian \
geometry. The scalar product pssp is related to the usual positive definite \
scalar product, denoted in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by  Dot ., as follows"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(pssp[vec[x], \ vec[y]]\  == \ vec[x] . dual[vec[y]]\)], "Input",
  CellLabel->"In[76]:=",
  FontSize->15],

Cell["\<\
The definition of the pseudo-orthogonal scalar product of type (dim - ind, \
ind) implies the following rules:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(pssp[x, y] == pssp[y, x]\)], "Input",
  CellLabel->"In[77]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[x + y, u] == pssp[x, u] + pssp[y, u]\)], "Input",
  CellLabel->"In[78]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[a\ k, l] == a\ pssp[k, l]\)], "Input",
  CellLabel->"In[79]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
The Dot product is more general. Therefore commutativity is not valid, in \
general:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(x . y\  == \ y . x\)], "Input",
  CellLabel->"In[80]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(\((vec[x] + vec[a])\) . vec[y]\  == \ 
      vec[y] . vec[x]\  + \ vec[y] . vec[a]\)], "Input",
  CellLabel->"In[82]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[83]:=",
  FontSize->15]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Type of a vector", "Subsection",
  FontSize->14],

Cell["\<\
A non zero vector v is called  space-, time-, or light-like (in relativity \
theory),  if  its scalar square pssp[x,x]  is positive, negative, or zero, \
respectively. In geometrical context one mostly uses \"isotropic\" instead of \
\"lightlike\". This property of the vector can be indicated by the function \
ch (== character), which gives the sign of pssp[v, v].  \
\>", "Text",
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[84]:=",
  FontSize->15],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times",
  FontSize->11],

Cell["Error messages: The nullvector", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[null[]]\)], "Input",
  CellLabel->"In[85]:=",
  FontSize->15],

Cell["or a vector with incorrect dimension:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[1, 5]]\)], "Input",
  CellLabel->"In[86]:=",
  FontSize->15],

Cell["Timelike vectors", "Text",
  FontSize->13],

Cell[BoxData[
    StyleBox[\(ch[stb[1]]\),
      FontSize->12]], "Input",
  CellLabel->"In[87]:=",
  FontSize->23,
  Background->None],

Cell[BoxData[
    \(ch[stb[1]*Cosh[t]\  + \ stb[dim]*Sinh[t]]\)], "Input",
  CellLabel->"In[88]:=",
  FontSize->15],

Cell["Isotropic vectors:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[1]\ Cos[Pi/4]\  + \ stb[dim]\ Sin[Pi/4]]\)], "Input",
  CellLabel->"In[89]:=",
  FontSize->15],

Cell[BoxData[
    \(ch[stb[1]*a + \ stb[dim]*a\ ]\)], "Input",
  CellLabel->"In[90]:=",
  FontSize->15],

Cell["Spacelike vectors:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[dim]]\)], "Input",
  CellLabel->"In[91]:=",
  FontSize->15],

Cell[BoxData[
    \(ch[stb[dim]*Cosh[t]\  + \ stb[1]*Sinh[t]]\)], "Input",
  CellLabel->"In[92]:=",
  FontSize->15],

Cell["ch[stb[1]*Cos[t] + stb[2]*Sin[t]]", "Input",
  CellLabel->"In[93]:=",
  FontSize->14,
  Background->None],

Cell[BoxData[
    \(vec[x]\  - \ stb[1]*x[1]\)], "Input",
  CellLabel->"In[94]:="],

Cell["ch[%]", "Input",
  CellLabel->"In[95]:=",
  FontSize->14,
  Background->None],

Cell["ch[vec[x] - stb[dim]*x[dim]]", "Input",
  CellLabel->"In[96]:=",
  FontSize->14,
  Background->None],

Cell["Type of a random vector", "Text"],

Cell[BoxData[
    \(ch[randomv[]]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(\(\(v1\)\(\ \)\(=\)\(\ \)\(randomv[]\)\(\ \ \)\)\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(ch[v1]\)], "Input",
  CellLabel->"In[99]:="],

Cell["\<\
The empirical probability that such a random vector is timelike equals \
approximately 0.06:\
\>", "Text"],

Cell[BoxData[
    \(zj\  = \ 0; 
    For[i = 1, 
      i < 10000, \ \(i++\), \n\t\((v1\  = \ randomv[]; 
        If[ch[v1] == \ \(-1\), \ zj\  = \ zj + 1])\)]; 
    Print[zj, "\<; \>", N[zj/10000]]\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \(Clear[zj, \ v1, i]\)], "Input",
  CellLabel->"In[282]:="],

Cell["\<\
Sometimes, clearly, it is impossible to decide which character  the vector \
has, since it depends of  the values of parameters:\
\>", "Text",
  FontSize->13],

Cell["ch[vec[x]]", "Input",
  CellLabel->"In[102]:=",
  FontSize->14,
  Background->None],

Cell[BoxData[
    \(ch[stb[1]\ Cos[t]\  + \ stb[dim]\ Sin[t]]\)], "Input",
  CellLabel->"In[103]:=",
  FontSize->15],

Cell["Plotting shows the character in dependence of the parameter:", "Text",
  FontSize->13],

Cell[BoxData[
    \(Plot[
      ch[stb[1]\ Cos[t]\  + \ stb[dim]\ Sin[t]], \ {t, 0, \ 
        2\ Pi}]\)], "Input",
  CellLabel->"In[104]:=",
  FontSize->15],

Cell["\<\
In the next example the character does not depend on the parameter; therefore \
it will be evaluated:\
\>", "Text"],

Cell[BoxData[
    \(ch[stb[dim]\ Cos[t]\  + \ stb[dim - ind]\ Sin[t]]\)], "Input",
  CellLabel->"In[105]:=",
  FontSize->15]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Norming", "Subsection",
  FontSize->14],

Cell["Now we consider the norming of the vector", "Text",
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(normalize[vec[x]]\)], "Input",
  CellLabel->"In[106]:=",
  FontSize->15,
  Background->None],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " often has difficulties with evaluations and simplifications of  Sqrt or \
Abs it is recommended to use normalize only in unavoidable cases, and, if \
possible, only  at the end of a module or calculation.  The vectors \
describing the model with r =1 are timelike and normed."
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(dim = 3\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \(pssp[hyperboloid[u, v], hyperboloid[u, v]]\)], "Input",
  CellLabel->"In[286]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[287]:="],

Cell[BoxData[
    \(ch[hyperboloid[u, v]]\)], "Input",
  CellLabel->"In[288]:="],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->11,
  Background->None],

Cell[BoxData[
    \(\(?normalize\)\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(normalize[stb[1] + 2\ stb[2]]\)], "Input",
  CellLabel->"In[111]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
Here you can see the problems if you want to norm general vectors:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1]*Cosh[t] + stb[2]]\)], "Input",
  CellLabel->"In[112]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[113]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[114]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%, \ t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[115]:=",
  FontSize->15],

Cell[TextData[{
  "In newer versions, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simplifies expressions with additional conditions, see Simplify in the \
help system. Sometimes the result depends on the place in the sequence of \
evaluations:"
}], "Text"],

Cell[BoxData[
    \(TrueQ[1 + \ Abs[\ Cosh[t]]\  >= \ 0]\)], "Input",
  CellLabel->"In[116]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[1 + \ Abs[\ Cosh[t]]\  >= \ 0, \ 
      t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[117]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[Abs[\ Cosh[t]]\  >= \ 0, \ 
      t\  \[Element] \ Complexes]\)], "Input",
  CellLabel->"In[118]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[Abs[t] >= \ 0, \ t\  \[Element] \ Complexes]\)], "Input",
  CellLabel->"In[119]:=",
  FontSize->15],

Cell[BoxData[
    \(TrueQ[Simplify[1 + Abs[Cosh[abcd]] >= \ 0]]\)], "Input",
  CellLabel->"In[120]:=",
  FontSize->15],

Cell["\<\
Mathematica does not return True, since generally t could be a complex \
parameter. But\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(TrueQ[Abs[1 + \ \ Cosh[t]^2\ ] >= \ 0]\)], "Input",
  CellLabel->"In[121]:=",
  FontSize->15],

Cell[BoxData[
    \(TrueQ[Simplify[Abs[1 + \ \ Cosh[t]^2\ ]] >= \ 0]\)], "Input",
  CellLabel->"In[122]:=",
  FontSize->15],

Cell["\<\
is not recognized, too.  In the next example the norming works ignoring the \
isotropic case t=0:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1] + stb[dim]*Cosh[t]]\)], "Input",
  CellLabel->"In[123]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(% /. \ t\  -> 0\)], "Input",
  CellLabel->"In[124]:="],

Cell["\<\
Norming an isotropic vector, or the nullvector, returns the vector itself\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1] + \ stb[dim]]\)], "Input",
  CellLabel->"In[125]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(normalize[stb[1]*a + \ stb[dim]*a]\)], "Input",
  CellLabel->"In[126]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(normalize[stb[dim]*a + \ stb[2]*a\  + stb[3\ ]*b]\)], "Input",
  CellLabel->"In[127]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[128]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%, a > 0 && \ b > 0]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(normalize[null[]]\)], "Input",
  CellLabel->"In[130]:=",
  FontSize->15,
  Background->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 The general cross product", "Subsection",
  Evaluatable->False,
  FontSize->14,
  Background->None],

Cell[TextData[{
  "As in euclidean geometry, the cross product of dim -1 vectors  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "  is the vector v uniquely defined by\npssp[v, x] = Det[",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(n - 1\)\)]],
  ", x]\t   (n = dim).\n First we remember our definition of  the euclidean \
cross product for arbitrary dimension, contained in euvec.m:"
}], "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(?cross\)\)], "Input",
  CellLabel->"In[131]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(cross[b_List]\  := \ 
      Module[{d\  = \ Length[b]\  + \ 1, v}, \n\t\tv\  = \ 
          null[d]; \n\t\t\tFor[i = 1, i < d, \(i++\), 
          If[Length[b[\([i]\)]\ ] != \ d, \ \n\t\t\t\t\t\t\t\tReturn[
              Print[b[\([i]\)], \ "\< is not a correct argument!\>"]], \n\t\t\
\t\t\t\t\t\tv[\([i]\)]\  = \ 
              Det[Append[b, \ stb[i, \ d]]]]]; \n\t\t\tv[\([d]\)]\  = \ 
          Det[Append[b, \ stb[d, \ d]]]; \n\t\t\tReturn[v]]\)], "Input",
  CellLabel->"In[17]:=",
  Evaluatable->False,
  FontSize->15],

Cell[TextData[{
  "The difference to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s function Cross is that cross' first argument is a list of lists, while \
Cross depends of dim -1 vectors."
}], "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(?? Cross\)], "Input",
  CellLabel->"In[132]:=",
  FontSize->15],

Cell["Here are the generalizations to the pseudo-Euclidean case:", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[133]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
If  you want that the cross product depends of dim - 1 arguments, and not of \
the list of these arguments, you may use psCross:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(psCross := Composition[dual, \ Cross]\)], "Input",
  CellLabel->"In[13]:=",
  PageWidth->Infinity,
  Evaluatable->False,
  FontSize->15,
  Background->None],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->11,
  Background->None],

Cell[BoxData[
    \(dim\  = \ 5\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(cross[{stb[1], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[135]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(Cross[stb[1], stb[2], \ stb[3], stb[4]]\)], "Input",
  CellLabel->"In[136]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pscross[{stb[1], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[137]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(vt\  = \ %\)], "Input",
  CellLabel->"In[138]:=",
  FontSize->15],

Cell[BoxData[
    \(Det[{stb[1], stb[2], \ stb[3], stb[4], vec[x]}]\)], "Input",
  CellLabel->"In[139]:=",
  FontSize->15],

Cell[BoxData[
    \(pssp[vt, \ vec[x]]\)], "Input",
  CellLabel->"In[140]:=",
  FontSize->15],

Cell[BoxData[
    \(pscross[{stb[5], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[141]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(psCross[stb[1], \ stb[2], \ stb[3], \ 
      stb[3]*Cos[t] + stb[4]*Sin[t]]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \(pscross[{stb[1], \ stb[2], \ stb[3], \ 
        stb[3]*Cos[t] + stb[4]*Sin[t]}]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(cross[{stb[1], \ stb[2], \ stb[3], \ 
        stb[3]*Cos[t] + stb[4]*Sin[t]}]\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \(psCross[stb[5], stb[2], \ stb[3], stb[4]]\)], "Input",
  CellLabel->"In[145]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(cross[{stb[5], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[146]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pscross[{stb[2], \ stb[3]*Cos[t] + \ stb[4]*Sin[t], \ 
        stb[4]*Cos[t] - \ stb[3]*Sin[t], stb[5]}]\)], "Input",
  CellLabel->"In[147]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[148]:=",
  FontSize->15],

Cell[BoxData[
    \(cross[{vec[a], vec[b], vec[c], 
          vec[d]}]\  == \ \(-cross[{vec[b], vec[a], vec[c], 
            vec[d]}]\)\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(Cross[vec[a], vec[b], vec[c], 
        vec[d]]\  == \ \(-Cross[vec[b], vec[a], vec[c], vec[d]]\)\)], "Input",\

  CellLabel->"In[150]:="],

Cell[BoxData[
    \(pscross[{vec[a], vec[b], vec[c], 
          vec[d]}]\  == \ \(-pscross[{vec[b], vec[a], vec[c], 
            vec[d]}]\)\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(pscross[{vec[a], vec[b], vec[c], vec[d]}]\  == \ \(-psCross[vec[b], 
          vec[a], vec[c], vec[d]]\)\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(dim\  = \ 3\)], "Input",
  CellLabel->"In[153]:="]
}, Closed]]
}, Closed]],

Cell["2.5. Orthogonality", "Subsection"],

Cell[CellGroupData[{

Cell["2.5.1 Definition", "Subsection",
  FontSize->14],

Cell[TextData[{
  "As in euclidean geometry a list {",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "} of non zero vectors is called orthogonal, if pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`v\_j\)]],
  " ] = 0 for i \[NotEqual] j; it is called orthonormal if it is orthogonal \
and for each i one has pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = 1, pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = -1, or pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = 0 with ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "\[NotEqual] o. An orthonormal sequence of vectors which does not contain \
isotropic vectors is linearly independent, therefore its length is less or  \
equal dim. Obviously, an orthonormal sequencewhich contains isotropic vectors \
needs not to be linearely independent.   By the theorem of inertia the number \
of timelike vectors in an orthonormal sequence is less or equal the index \
ind. An orthonormal sequence of maximal length dim which does not contain \
isotropic vectors is called an orthonormal frame; in any orthonormal frame \
the number of timelike vectors equals ind. If not another order  is mentioned \
explicitely, in an orthonormal frame the last ind vectors are assumed to be \
timelike.\nIn this section we collect definitions and modules for orthogonal \
vectors in the pseudo-euclidean space, which we need for certain \
applications, especially in M\[ODoubleDot]bius geometry.  The basic \
orthonormalization procedure orthonorm is contained in the package neuvec.m. \
The Erhard Schmidt orthogonalization (for positive semidefinite scalar \
products) esorthonorm (contained in euvec.m) is tested in the notebook ",
  ButtonBox["Euklid.nb",
    ButtonData:>{"Euklid.nb", None},
    ButtonStyle->"Hyperlink"],
  ", and the general orthogonalization orthonorm  is treated below.  A \
generalization of orthonorm for scalar products in matrix spaces and \
applications to Killing forms can be found in the item Lie algebras, on my \
homepage, or in :"
}], "Text",
  FontSize->13],

Cell["http://www.mathsource.com/cgi-bin/msitem?0210-845", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.2 Pseudo-euclidean orthogonalization", "Subsection",
  FontSize->14],

Cell[CellGroupData[{

Cell["2.5.2.1 General remarks", "Subsubsection"],

Cell[TextData[{
  "For definite scalar products J. M.Novak's GramSchmidt orthogonalization \
works well. Clearly, Novak's procedure GramSchmidt (see \
.../mathematica/AddOns/StandardPackages/LinearAlgebra/Orthogonalization.m) \
was not intended for applications to indefinite scalar products, and it did \
not work correctly for these. For pseudo-euclidean vector spaces we \
programmed a procedure orthonorm with the following properties:\nGiven a \
sequence of vectors ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_k\)\(}\)\)\)]],
  ". Construct an orthogonal basis  ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  ",...,",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  " of the  span \n                                                           \
    span[ ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  "] = span[ ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  ",...,",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  "]. \nTo this aim we use  functions defined in euvec.m which can be useful \
also for other applications:"
}], "Text",
  TextAlignment->Left,
  FontSize->13],

Cell[BoxData[
    \(\(?outzero\)\)], "Input",
  CellLabel->"In[154]:=",
  FontSize->15],

Cell[BoxData[
    \(outzero[{null[], \ stb[1]}]\)], "Input",
  CellLabel->"In[155]:=",
  FontSize->15],

Cell[BoxData[
    \(\(?basis\)\)], "Input",
  CellLabel->"In[156]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.2.2 Orthonormalization", "Subsubsection"],

Cell["\<\
The orthogonalization is more complicated as in the euclidean case; the \
following procedure is contained in pseuvec.m:\
\>", "Text"],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \(Options[orthonorm]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[159]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(orthonorm[b_List, opts___] := 
      Module[{v, w, va, vb, l, ort = {}, i, j, f, h, sm, aus, prod, nor, pr, 
          bn, follow, iso, 
          control}, {prod, nor, pr, 
            bn} = \({innerprod, normed, print, neglect} /. {opts}\) /. 
            Options[orthonorm]; \[IndentingNewLine]f[h_] := 
          smoothing[h, 10^bn]; \[IndentingNewLine]sm[aus_] := 
          MapAll[f, aus]; \[IndentingNewLine]w = 
          outzero[sm[b]]; \[IndentingNewLine]Label[
          follow]; \[IndentingNewLine]l = Length[w]; \[IndentingNewLine]If[
          l \[Equal] 0, Goto[control]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l, \(i++\), 
          If[Not[Simplify[sm[prod[w[\([i]\)], w[\([i]\)]]]] \[Equal] 0], 
            AppendTo[ort, w[\([i]\)]]; \[IndentingNewLine]If[
              pr \[Equal] True, Print[w[\([i]\)]]]; \[IndentingNewLine]v = 
              Simplify[
                sm[Table[
                    w[\([j]\)] - 
                      w[\([i]\)]*
                        prod[w[\([i]\)], w[\([j]\)]]/
                          prod[w[\([i]\)], w[\([i]\)]], {j, 
                      l}]]]; \[IndentingNewLine]w = outzero[v]; \ 
            Goto[follow], Null, 
            AppendTo[ort, w[\([i]\)]]; \[IndentingNewLine]If[
              pr \[Equal] True, Print[w[\([i]\)]]]; \[IndentingNewLine]v = 
              Simplify[
                sm[Table[
                    w[\([j]\)] - 
                      w[\([i]\)]*
                        prod[w[\([i]\)], w[\([j]\)]]/
                          prod[w[\([i]\)], w[\([i]\)]], {j, 
                      l}]]]; \[IndentingNewLine]w = outzero[v]; \ 
            Goto[follow]]]; \[IndentingNewLine]Label[iso]; 
        l = Length[w]; \[IndentingNewLine]If[l \[Equal] 0, 
          Goto[control]]; \[IndentingNewLine]v = w; \[IndentingNewLine]If[
          l \[Equal] 1, AppendTo[ort, v[\([1]\)]]; \ 
          If[pr \[Equal] True, Print[v[\([1]\)]]]; \[IndentingNewLine]Goto[
            control]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l, \(i++\), 
          For[j = i + 1, j \[LessEqual] l, \(j++\), 
            If[Not[Simplify[sm[prod[v[\([i]\)], v[\([j]\)]]]] \[Equal] 0], 
              va = v[\([j]\)] - v[\([i]\)]; \[IndentingNewLine]vb = 
                v[\([j]\)] + v[\([i]\)]; \ \t\t\t\tv[\([i]\)] = va; 
              v[\([j]\)] = vb; \[IndentingNewLine]w = 
                outzero[Simplify[sm[v]]]; 
              Goto[follow]]]]; \[IndentingNewLine]v = \ 
          basis[v]; \[IndentingNewLine]\ 
        ort = Join[ort, v]; \[IndentingNewLine]Label[
          control]; \[IndentingNewLine]l = Length[ort]; \[IndentingNewLine]If[
          l \[Equal] 0, Return[ort]]; \[IndentingNewLine]If[
          nor \[Equal] True, 
          ort = sm[
              Table[Simplify[normalize[ort[\([i]\)], prod]], {i, 
                  Length[ort]}]]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l - 1, \(i++\), 
          For[j = i + 1, j \[LessEqual] l, \(j++\), 
            If[Not[Simplify[sm[prod[ort[\([i]\)], ort[\([j]\)]]]] \[Equal] 
                  0], Return[
                Print["\<I cannot orthogonalize the given sequence!\>"]], 
              Null, Return[
                Print["\<I cannot orthogonalize the given sequence!\>"]]]]]; \
\ \tReturn[ort]]\)], "Input",
  CellLabel->"In[9]:=",
  Evaluatable->False],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nor\)\" is similar to \
existing symbol \"\!\(Nor\)\"."\)], "Message",
  CellLabel->"From In[9]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.2.3  WARNINGS:", "Subsubsection"],

Cell["\<\
1. In certain cases the pseudo-euclidean orthonormalization procedure \
orthonorm cannot  be carried out. Then instead of the orthonormed matrix \
appears the message  \"I cannot orthogonalize the given sequence!\"  \
Sometimes the norming is the reason; then try the orthogonalization with the \
option normed -> False. Besides of the parameter dependence the reason can be \
a numerical badly conditioned matrix b (e.g. contains vectors with very \
small, or very different in magnitude, components). In this case one can try \
applying orthonorm  on the renormed matrix renorm[b]. \
\>", "Text"],

Cell["\<\
2. In the pseudo-euclidean vector spaces exist vector sequences which may not \
be orthogonalized preserving its flag structure. In difference to Erhard \
Schmidt's orthogonalization the procedure orthonorm does not preserve the \
flag structure of the given sequence in general.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.3 Examples, tests", "Subsection",
  FontSize->14],

Cell[CellGroupData[{

Cell["2.5.3.1 Simple, parameterfree vectors", "Subsubsection"],

Cell[BoxData[
    \(dim\  = \ 5\)], "Input",
  CellLabel->"In[291]:="],

Cell[BoxData[
    \(orthonorm[{null[]}]\)], "Input",
  CellLabel->"In[161]:="],

Cell["\<\
Isotropic vectors are treated correctly; here the orthonormal basis of the \
2-space is non isotropic:\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[5]}]\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[2] + stb[5]}]\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(psfilter[%%]\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[166]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[1] - stb[5]}]\)], "Input",
  CellLabel->"In[167]:="],

Cell["\<\
In the new version,   orthonormal linearly dependent isotropic vectors don't \
appear:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[2], 
        stb[1] + stb[5], \((stb[1]\  + \ stb[5])\)*3}]\)\)\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[1], stb[5]\  - stb[2], null[], \ 
        stb[2]*5 + \ stb[5]}]\)\)\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[1], \((stb[5]\  - stb[2])\)*25, \ 
        stb[1]*5 + \ stb[4]}]\)\)\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[4], stb[1]\  - \ stb[5], 
        stb[1]*3\  - stb[5]}]\)], "Input",
  CellLabel->"In[293]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[294]:="],

Cell["\<\
Clearly,  by numerical reason,  one may expect an approximative result only, \
if during the calculation appear floating point numbers.\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[4], stb[1]\  - \ stb[5], 
        stb[1]*3.1\  - stb[5]}]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[175]:="],

Cell["Here is a test with a random floating point number:", "Text"],

Cell[BoxData[{
    \(\(t1\  = \ 10*Random[];\)\), "\n", 
    \(\(avt\  = 
        orthonorm[{\ stb[3], stb[5]\  + \ stb[2], \ null[], \ 
            stb[5] Cosh[t1]\  + \ 5*stb[1] Sinh[t1], 
            stb[5]\  + \ stb[2]}];\)\), "\n", 
    \(\tsmoothing[
      Table[pssp[avt[\([i]\)], avt[\([j]\)]], {i, Length[avt]}, {j, 
          Length[avt]}]]\)}], "Input",
  CellLabel->"In[176]:=",
  FontSize->15],

Cell["Repeat the evaluation of the next cell several times!", "Text"],

Cell[BoxData[{
    \(\(t1\  = \ 10*Random[];\)\), "\n", 
    \(\(avt\  = 
        orthonorm[{\ stb[3], stb[5]\  + \ stb[2], \ null[], \ 
            stb[5] Cosh[t1]\  + \ 5*stb[1] Sinh[t1], 
            stb[5]\  + \ stb[2]}];\)\), "\n", 
    \(\tTable[pssp[avt[\([i]\)], avt[\([j]\)]], {i, 3}, {j, 3}]\)}], "Input",
  CellLabel->"In[179]:=",
  FontSize->15],

Cell[BoxData[
    \(Remove[avt]\)], "Input",
  CellLabel->"In[182]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.3.2 Vectors depending on parameters", "Subsubsection"],

Cell["\<\
The following examples show that orthonorm worked correctly also on sequences \
depending on parameters.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[
          1], \((stb[5]\  - stb[2])\)*25, \ \((stb[1]*5 + \ stb[4])\)*
          a}, \[IndentingNewLine]print \[Rule] True]\)\)\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[
          1], \((stb[5]\  - stb[2])\)*25, \ \((stb[1]*5 + \ stb[4])\)*
          a}, \[IndentingNewLine]print \[Rule] True, \ 
      normed\  \[Rule] \ False]\)\)\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(orthonorm[{stb[1]\ *c + \ stb[5]*3, stb[1]\  + \ stb[5]}, 
      print \[Rule] True, \ normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(orthonorm[{stb[1]\ *c + \ stb[5]*3, stb[1]\  + \ stb[5]}, 
      print \[Rule] True]\)], "Input",
  CellLabel->"In[186]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \(te[c_] = \ %\)], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(te[c]\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(te[3]\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] \ 3]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] 3, \ 
      Direction\  \[Rule] \ \(-1\)]\)], "Input",
  CellLabel->"In[193]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] \ 3, \ Direction\  \[Rule] \ 1]\)], "Input",
  CellLabel->"In[194]:="],

Cell["\<\
The evaluation worked for general c, in spite of the fact that at c = 3  the \
character  of the constructed vectors changes. Moreover, for c= 3 the 2-space \
degenerates to an isotropic line. \
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[1] Cosh[t]\  + \ 2*stb[5] Sinh[t], \n\ \ \ \ stb[1]\  + \ 
          stb[2]}, \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    \(Table[
      pssp[%[\([i]\)], %[\([j]\)]], {i, Length[%]}, {j, 
        Length[%]}]\)], "Input",
  CellLabel->"In[196]:="],

Cell[BoxData[
    \(ftest[t_]\  = \ Simplify[Together[%]]\)], "Input",
  CellLabel->"In[197]:="],

Cell[BoxData[
    \(ftest[0]\)], "Input",
  CellLabel->"In[198]:="],

Cell[BoxData[
    \(Limit[ftest[t], \ t\  \[Rule] \ 0, \ Direction\  \[Rule] 1]\)], "Input",\

  CellLabel->"In[199]:="],

Cell[BoxData[
    \(Limit[ftest[t], \ t\  \[Rule] \ 0, \ 
      Direction\  \[Rule] \(-1\)]\)], "Input",
  CellLabel->"In[200]:="],

Cell[BoxData[
    \(ftest[1. ]\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \(ftest[0.1]\)], "Input",
  CellLabel->"In[202]:="],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[2] Cosh[t]\  + \ stb[5] Sinh[t], \n\ \ \ \ stb[1]\  + \ 
          stb[2]}]\)], "Input",
  CellLabel->"In[203]:="],

Cell[BoxData[
    \(orthonorm[{\ stb[1] Cosh[t]\  + \ stb[5] Sinh[t], 
        stb[1]\  + \ \ stb[2], stb[2], \ null[], 
        stb[1]\  - \ stb[2]}]\)], "Input",
  CellLabel->"In[204]:="],

Cell[BoxData[
    \(Table[
      pssp[%[\([i]\)], %[\([j]\)]], {i, Length[%]}, {j, 
        Length[%]}]\)], "Input",
  CellLabel->"In[205]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[206]:="],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[1] Cosh[t]\  + \ stb[5] Sinh[t], \n\ \ \ \ stb[3]\  + \ 
          stb[2]}]\)], "Input",
  CellLabel->"In[207]:="],

Cell[BoxData[
    \(Remove[te, \ ftest]\)], "Input",
  CellLabel->"In[208]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.3.3 Index ind = 2", "Subsubsection"],

Cell["\<\
If the index is greater than 1, you can meet also mutual orthogonal, \
isotropic,  linearly independent vectors. First we change the index:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(ind\  = \ 2\)], "Input",
  CellLabel->"In[209]:="],

Cell[BoxData[
    \(ch[stb[4] + stb[2]]\)], "Input",
  CellLabel->"In[210]:="],

Cell[BoxData[
    \(pssp[stb[2], stb[2]]\)], "Input",
  CellLabel->"In[211]:="],

Cell["\<\
Here we have two isotropic orthogonal vectors spanning a totally isotropic \
2-dimensional subspace:\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[4]\  + stb[2]}]\)], "Input",
  CellLabel->"In[212]:=",
  FontSize->15],

Cell["\<\
These vectors are orthogonal and have norm 0, therefore they have been \
returned correctly. Moreover, they are linearly independent.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[1]*2\  + \ stb[3], 
        stb[4]\  + stb[2]}]\)], "Input",
  CellLabel->"In[213]:=",
  FontSize->15],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[214]:="],

Cell["\<\
The next two isotropic vectors span a 2-dimensional pseudoeuclidean subspace:\
\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[1]\  + stb[2]}, 
      print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[215]:=",
  FontSize->15],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[216]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.3.4 Tests with random vectors (case ind = 2)", "Subsubsection"],

Cell[BoxData[
    \(ind\)], "Input",
  CellLabel->"In[217]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 5}];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[218]:="],

Cell[BoxData[{
    \(\(atest\  = 
        PrependTo[Table[randomv[5], {i, 7}], 
          stb[1]\  + \ stb[5]];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
        Length[ot]}]\)}], "Input",
  CellLabel->"In[221]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 3}];\)\), "\n", 
    \(\(atest\  = \ 
        Join[atest, {stb[1]\  + \ stb[5], stb[2]\  + \ stb[4]}];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[224]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 7}];\)\), "\n", 
    \(\(atest\  = \ 
        Join[{stb[1]\  + \ stb[5], stb[2]\  + \ stb[4]}, atest];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[228]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 7}];\)\), "\n", 
    \(ot\  = orthonorm[atest, print\  \[Rule] \ True]; 
    Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
        Length[ot]}]\)}], "Input",
  CellLabel->"In[232]:="],

Cell[BoxData[
    \(Remove[atest, \ ot]\)], "Input",
  CellLabel->"In[235]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.3.5 Renorming of badly conditioned matrices", "Subsubsection"],

Cell["\<\
PRESERVE ind = 2, dim = 5 !
The comments are valid in this case only. For ind =1, dim = 5 the sequence ot \
will be orthonormed with approximative correctness, test it later!\
\>", "Text"],

Cell["\<\
The next matrix ot has vectors with coordinates of very different absolute \
values. Applying orthonorm ,  we  do not get orthogonal vectors:\
\>", "Text"],

Cell[BoxData[
    \(ot\  = {{0.675496095887281988`, 0.838111706002798051`, 
          0.0599127084283752431`, 0.0726205437662291686`, 
          0.396285246447809988`}, {2.90602662075336581`, \
\(-0.838111706002798761`\), \(-0.0599127084283752875`\), \
\(-0.0726205437662292307`\), 
          3.18523747019283787`}, {\(-9.19936356392773468`*^7\), 
          3.3554431999999994`*^7, \(-6.36335108454432329`*^-10\), 
          3.35544319999999984`*^7, \(-9.19936356392773468`*^7\)}}\)], "Input",\

  CellLabel->"In[236]:="],

Cell["The three vectors are \"almost\" orthogonal:", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
          Length[ot]}] // MatrixForm\)], "Input",
  CellLabel->"In[237]:="],

Cell[BoxData[
    \(at\  = orthonorm[ot]\)], "Input",
  CellLabel->"In[238]:="],

Cell["We try it without norming:", "Text"],

Cell[BoxData[
    \(at\  = orthonorm[ot, \ normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[239]:="],

Cell["\<\
If one renorms the vectors of ot, one preserves their span, and hopefully, \
can find  a nearly orthonormal basis:\
\>", "Text"],

Cell[BoxData[
    \(\(?renorm\)\)], "Input",
  CellLabel->"In[240]:="],

Cell[BoxData[
    \(renorm[b_?MatrixQ] := \ 
      Module[{bo\  = \ outzero[b], i\ }, \n\t
        Table[bo[\([i]\)]/Sqrt[bo[\([i]\)] . bo[\([i]\)]], 
          \ {i, \ Length[bo]}]]\)], "Input",
  CellLabel->"In[13]:=",
  Evaluatable->False],

Cell[BoxData[
    \(otre\  = \ renorm[ot]\)], "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    \(orthonorm[otre, \ \ print\  \[Rule] \ True, \ 
      normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[242]:="],

Cell[BoxData[
    \(\(at\  = \ %;\)\)], "Input",
  CellLabel->"In[243]:="],

Cell[BoxData[
    \(Table[
        smoothing[pssp[at[\([i]\)], at[\([j]\)]]], {i, Length[at]}, {j, 
          Length[at]}] // \n\ \ MatrixForm\)], "Input",
  CellLabel->"In[244]:="],

Cell["\<\
Here  we succeeded,  but if we want to get normed vectors, the procedure does \
not work:. \
\>", "Text"],

Cell[BoxData[
    \(orthonorm[otre, \ \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[245]:="],

Cell["\<\
The reason is that the last vector may not be normalized correctly:\
\>", "Text"],

Cell[BoxData[
    \(atn = \ Table[normalize[at[\([i]\)]], {i, 3}]\)], "Input",
  CellLabel->"In[246]:="],

Cell["\<\
The scalar products after normalization are incorrect; therefore the \
procedure did not return the found vectors:\
\>", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[atn[\([i]\)], atn[\([j]\)]]], {i, Length[atn]}, {j, 
          Length[atn]}] // \n\ \ MatrixForm\)], "Input",
  CellLabel->"In[247]:="],

Cell["\<\
The third vector of at seems to be isotropic; but copying it we get its \
'inner hidden' value:\
\>", "Text"],

Cell[BoxData[
    \(badv\  = {\(-0.6642969596426436`\), 0.24230053530593257`, 0, 
        0.24230053530593232`, \(-0.6642969596426437`\)}\)], "Input",
  CellLabel->"In[248]:="],

Cell[BoxData[
    \(pssp[badv, badv]\)], "Input",
  CellLabel->"In[249]:="],

Cell[BoxData[
    \(normalize[badv]\)], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    \(badnormv\  = \ %\)], "Input",
  CellLabel->"In[251]:="],

Cell[BoxData[
    \(pssp[badnormv, badnormv]\)], "Input",
  CellLabel->"In[252]:="],

Cell["The hidden value of badnormv is", "Text"],

Cell[BoxData[
    \({\(-6.304594370522744`*^7\), 2.2995838964643177`*^7, 0, 
      2.299583896464315`*^7, \(-6.304594370522745`*^7\)}\)], "Input",
  CellLabel->"In[253]:="],

Cell["\<\
Here  we succeeded,  but in the next example we have certain difficulties. \
\>", "Text"],

Cell[BoxData[
    \(\(ot\  = {{0.675496095887281988`, 0.838111706002798051`, 
            0.0599127084283752431`, 0.0726205437662291686`, 
            0.396285246447809988`}, {2.90602662075336581`, \
\(-0.838111706002798761`\), \(-0.0599127084283752875`\), \
\(-0.0726205437662292307`\), 
            3.18523747019283787`}, {\(-9.19936356392773468`*^7\), 
            3.3554431999999994`*^7, \(-6.36335108454432329`*^-10\), 
            3.35544319999999984`*^7, \(-9.19936356392773468`*^7\)}, \
{6.82635841776287133`*^7, \(-2.48989593404715137`*^7\), 
            9.9150403743008848`*^-9, \(-2.48989593404715048`*^7\), 
            6.82635841776287133`*^7}, {\(-1.82640220915799815`*^7\), 
            6.66175309911068413`*^6, 2.6549032889775681`*^-7, 
            6.66175309911060686`*^6, \(-1.82640220915799815`*^7\)}};\)\)], \
"Input",
  CellLabel->"In[254]:="],

Cell["\<\
This matrix is bad conditioned too, but not nearly orthogonal:\
\>", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
          Length[ot]}] // MatrixForm\)], "Input",
  CellLabel->"In[255]:="],

Cell[BoxData[
    \(orthonorm[ot]\)], "Input",
  CellLabel->"In[256]:="],

Cell[BoxData[
    \(otre\  = \ renorm[ot]\)], "Input",
  CellLabel->"In[257]:="],

Cell["\<\
The matrix  otre is badly conditioned again: The last three vectors are \
pairwise almost linearly dependent, and we have\
\>", "Text"],

Cell[BoxData[
    \(Det[otre]\)], "Input",
  CellLabel->"In[258]:="],

Cell[BoxData[
    \(Table[pssp[otre[\([i]\)], otre[\([j]\)]], {i, 5}, {j, 5}]\)], "Input",
  CellLabel->"In[259]:="],

Cell["With the default norming we do not succeed:", "Text"],

Cell[BoxData[
    \(at1\  = \ orthonorm[otre, \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[260]:="],

Cell["but without norming we get a reasonable result:", "Text"],

Cell[BoxData[
    \(at1\  = \ 
      orthonorm[otre, \ print\  \[Rule] \ True, 
        normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[261]:="],

Cell[BoxData[
    \(Table[
        smoothing[pssp[at1[\([i]\)], at1[\([j]\)]]], {i, Length[at1]}, {j, 
          Length[at1]}] // MatrixForm\)], "Input",
  CellLabel->"In[262]:="],

Cell["\<\
That looks wrong: in the pseudo-euclidean vector space of index 2 there may \
not exist three mutual orthogonal linearly independent isotropic vectors! The \
numerical deviation from orthonormality one can see evaluating the scalar \
products not using smoothing:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      pssp[at1[\([i]\)], at1[\([j]\)]], {i, Length[at1]}, {j, 
        Length[at1]}]\)], "Input",
  CellLabel->"In[263]:="],

Cell["\<\
Thus, orthonorm yields very small, almost orthogonal vectors, and the last \
three vectors are almost isotropic; the five vectors are \"almost linearly \
dependent\":\
\>", "Text"],

Cell[BoxData[
    \(Det[at1]\)], "Input",
  CellLabel->"In[264]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.5.4  psfilter", "Subsection",
  FontSize->14],

Cell["We now go back to index 1: ", "Text"],

Cell[BoxData[
    \(ind\  = \ 1\)], "Input",
  CellLabel->"In[265]:="],

Cell[BoxData[
    \({dim\ , \ ind}\)], "Input",
  CellLabel->"In[295]:="],

Cell["\<\
Remember that in a space of index ind  any orthogonal sequence of linearly \
independent vectors may contain not more than ind non spacelike vectors.\
\>", "Text"],

Cell["\<\
Sometimes it is necessary to place the spacelike vectors of a sequence b at \
the first places. The following procedure  realizes such a permutation: \
\>", "Text"],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[267]:="],

Cell[BoxData[
    \(psfilter[b_List]\  := \ 
      Module[{i, \ lb\  = \ Length[b], \ bn = \ {}, qn\  = \ {}}, \n\t\tFor[
          i = 1, i <= lb, \(i++\), \n\t\t\tIf[
            Length[b[\([i]\)]\ ]\  != \ dim, \ 
            Return[\ Print["\<Incorrect argument \>", 
                b[\([i]\)], "\<!!!\>"]]]]; \n\t\tFor[i = 1, \ 
          i <= lb, \ \(i++\), \n\t\t\tIf[ch[b[\([i]\)]\ ] == \ \(-1\), \ 
            AppendTo[bn, \ b[\([i]\)]], AppendTo[qn, b[\([i]\)]], 
            AppendTo[qn, b[\([i]\)]]]]; \n\t\t\t\tReturn[
          Join[bn, qn]]]\)], "Input",
  CellLabel->"In[16]:=",
  Evaluatable->False],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{a}]\)\)\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{null[], \ stb[5], \ stb[1]}]\)\)\)], "Input",
  CellLabel->"In[269]:="],

Cell["\<\
psfilter  yields the expected result also for non orthogonal sequences:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{stb[2], stb[5]*Cos[t], \ stb[5], \ 
        stb[1]}]\)\)\)], "Input",
  CellLabel->"In[270]:="],

Cell[BoxData[
    \(psfilter[%]\)], "Input",
  CellLabel->"In[271]:="],

Cell[BoxData[
    \(psfilter[{\ stb[1]\  + \ stb[5], 
        stb[5]\  + stb[2], \ {Cos[t], \ Sin[t], \ 1, 0, 1}}]\)], "Input",
  CellLabel->"In[296]:="],

Cell["\<\
Now we return to dimension 3 and begin with applications to the hyperbolic \
plane:\
\>", "Text"],

Cell[BoxData[
    \(dim\  = \ 3\)], "Input",
  CellLabel->"In[297]:="],

Cell[BoxData[
    \(\[Angstrom]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" 3. Models of the hyperbolic plane", "Section"],

Cell[CellGroupData[{

Cell["3.1 The spherical model", "Subsection"],

Cell[TextData[{
  "We start from the",
  " Klein model",
  ", described already in ",
  ButtonBox["section 1.1.",
    ButtonData:>"Euklid",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
We put r = 1 and consider the halfsphere of radius 1 above the disk within \
the y,z-plane representing the points of the hyperbolic plane. To any point \
of the unit disk there corresponds a uniquely defined point of the halfsphere \
projected orthogonally on the given point:\
\>", "Text"],

Cell[BoxData[
    \(hsphpt[v_List]\  := 
      Module[{a, \ c\  = \ Length[v]}, \[IndentingNewLine]If[
          c \[NotEqual] dim\  - 1, \ Print["\<Incorrect argument\>"]; 
          Return[]]; \[IndentingNewLine]a\  = 
          Prepend[v, 0]; \ \[IndentingNewLine]a\  = \ 
          a\  + \ stb[1]*Sqrt[1\  - \ \ a . a]; \[IndentingNewLine]Return[
          a]]\)], "Input",
  CellLabel->"In[21]:=",
  InitializationCell->True],

Cell["\<\
Obviously, this yields a real point only if a.a\[LessEqual]1, i.e. for points \
of the unit disk.\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(hsphpt[{a, b}] . hsphpt[{a, b}]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(hsphpt[{a, b}]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(hsphpt[{a, 0}]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(ParametricPlot3D[
      hsphpt[{s*Cos[t], \ s*Sin[t]}], \ {t, 0, 2*Pi}, \ {s, 0, 1}]\)], "Input",\

  CellLabel->"In[28]:="],

Cell["\<\
In the spherical model the lines are represented by halfcircles orthogonal to \
the bording circle.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 A conformal model ", "Subsection"],

Cell["\<\
The stereographical projection  from the north pole maps the lower halfsphere \
back onto the unit disk:\
\>", "Text"],

Cell[BoxData[
    \(\(?sterproj\)\)], "Input",
  CellLabel->"In[46]:="],

Cell["\<\
To get a correct picture we must turn the halfsphere around the y-axis  into \
the lower halfspace x[3]<0,  then applying sterproj and permuting x- and \
y-axes  we define:\
\>", "Text"],

Cell[BoxData[
    \(euklein[v_List] := \ 
      Module[\ {vv\  = hsphpt[v]}, \ 
        vv = sterproj[{vv[\([3]\)], 
              vv[\([2]\)], \(-vv[\([1]\)]\)}]; \
\[IndentingNewLine]{vv[\([2]\)], \ vv[\([1]\)]}]\)], "Input",
  CellLabel->"In[22]:=",
  InitializationCell->True],

Cell[BoxData[
    \(euklein[{s*Cos[t], \ s*Sin[t]}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(euklein[{a, 0}]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(ParametricPlot[
      Evaluate[euklein[{ .5*Cos[t],  .5  Sin[t]}]], {t, 0, 2*Pi}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[53]:="],

Cell[TextData[{
  "The representation of the hyperbolic plane obtained projecting the \
spherical model stereographically onto the unit disk is called the ",
  StyleBox["conformal model ",
    FontColor->RGBColor[0, 0, 1]],
  "of the hyperbolic plane.  The transformation of the Klein model into the \
conformal model is given by euklein."
}], "Text"],

Cell[TextData[{
  StyleBox["Warning: ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "Remember that the definition of euklein makes sense for vectors v with v.v \
\[LessEqual] 1 only!\nThe points of the bording unit circle are fixed under \
the transformation:"
}], "Text"],

Cell[BoxData[
    \(euklein[{Cos[t], Sin[t]}]\)], "Input",
  CellLabel->"In[114]:="],

Cell["\<\
The advantage of the conformal model is that it prserves angles; it is a \
conformal map of the hyperbolic plane onto the unit disk. The bording circle \
represents the \"infinite points\" of the hyperbolic plane.  In the Klein \
model the chords of the circle represent the lines; they are mapped by \
euklein on circle arcs perpendicular to the bording circle (in particular, \
diameters are mapped onto itself, as one sees in the last graphics).  \
\>", "Text"],

Cell[BoxData[
    \(a\  = \ 1.9; 
    Table[ParametricPlot[
        euklein[eucl[\(hypline[j*a/4]\)[t]]], {t, \(-5\), 5}], \ {j, \(-4\), 
        4}]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[55]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 H. Poincar\[EAcute] model", "Subsection"],

Cell["\<\
Now we take the Klein model  on the unit disk of the x[2],x[3] plane of the \
euclidean 3-space; the embedding is\
\>", "Text"],

Cell[BoxData[
    \(Prepend[{x, y}, 0]\)], "Input",
  CellLabel->"In[124]:="],

Cell["\<\
We consider the positive half sphere over the disk defined by hsphpt in \
section 1.. Stereographical  projection from the north pole transforms the \
bording meridian into the x[2]-axis and defines the Poincar\[EAcute] model on \
the x[1],x[2] half plane defined by x[1] > 0:\
\>", "Text"],

Cell[BoxData[
    \(eupoincare[v_List] := \ sterproj[hsphpt[v]]\)], "Input",
  CellLabel->"In[23]:=",
  InitializationCell->True],

Cell["\<\
Sometimes it is useful to include the border, i.e. the y-axis, into a picture \
of objects in the Poincar\[EAcute] model. Therefore we define\
\>", "Text"],

Cell[BoxData[
    \(poinborder[l_:  1]\  := 
      Graphics[Line[{{0, \(-l\)}, {0, l}}]]\)], "Input",
  CellLabel->"In[24]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Clear[a]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(eupoincare[eucl[\(hypline[a]\)[t]]]\)], "Input",
  CellLabel->"In[62]:="],

Cell["\<\
The line family considered before in the conformal model  now looks like\
\>", "Text"],

Cell[BoxData[
    \(a\  = \ 0.9; 
    Table[ParametricPlot[
        eupoincare[eucl[\(hypline[j*a/4]\)[t]]], {t, \(-5\), 
          5}], \ {j, \(-4\), 4}]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Show[{%\ , poinborder[3]}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Clear[a]\)], "Input",
  CellLabel->"In[66]:="],

Cell["\<\
In this model, the hyperbolic lines are mapped onto half circles or half \
lines orthogonal to the border. The images of Circles are circles again:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      Append[eupoincare[{s*Cos[t], \ s*Sin[t]}], \ 0], {t, 0, 2*Pi}, \ {s, 
        0,  .4}, PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        eupoincare[{s/10*Cos[t], \ s/10*Sin[t]}], {t, 0, 2*Pi}], {s, 1, 
        5}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Show[{%, poinborder[ .7]}, AspectRatio \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[70]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4. Symmetric operators and quadrics", "Section"],

Cell["\<\
Quadrics in hyperbolic geometry are defined as the sets of hyperbolic points \
of projective quadrics, i.e. intersections of projective quadrics with  the \
hyperbolic space or plane. In this section we consider plane quadrics. The \
aim is the classification of these quadrics with respect to  hyperbolic \
transformations, and relating algebraic properties of the defining symmetric \
bilinear forms  with the shape of the curves.  We start with considerations \
about associated operators by the help of which the classification can be \
carried out.\
\>", "Text"],

Cell[CellGroupData[{

Cell["4.1 Adjoint  operators and associated  bilinear forms", "Subsection"],

Cell[TextData[{
  "For any linear map a of the pseudo-euclidean vector space the ",
  "adjoint",
  " linear map a' ",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  "is defined by"
}], "Text"],

Cell[BoxData[
    \(pssp[a' \((x)\), y]\  = \ pssp[x, a \((y)\)]\)], "Input",
  Evaluatable->False],

Cell["If", "Text"],

Cell[BoxData[
    \(matrix[a]\)], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
is the matrix of a with respect to a pseudo-orthonormal basis then the matrix \
of a' with respect to the same basis is\
\>", "Text"],

Cell[BoxData[
    \(adjoint[m_]\  := \ gram . Transpose[m] . gram\)], "Input",
  CellLabel->"In[25]:=",
  InitializationCell->True],

Cell[BoxData[
    \(adjoint[matrix[a]]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[54]:="],

Cell["\<\
The linear map is called symmetric, if it coincides with its adjoint map; for \
the matrices that means\
\>", "Text"],

Cell[BoxData[
    \(\((\((matrix[a]\  - \ adjoint[matrix[a]])\) // 
          MatrixForm)\) \[Equal] \ \((nullmatrix[3] // 
          MatrixForm)\)\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
Thus, a matrix matrix[a] is symmetric iff the following equations are \
fullfilled:\
\>", "Text"],

Cell[BoxData[
    \(a[1, 2]\  \[Equal] \ a[2, 1]; \ a[1, 3] \[Equal] \ \(-a[3, 1]\); \ 
    a[2, 3]\  \[Equal] \ \ \(-a[3, 2]\);\)], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
Obviously, any operator having a pseudo-orthogonal basis of eigenvectors is \
symmetric. 
To any linear map is associated a corresponding bilinear map defined by\
\>", "Text"],

Cell[BoxData[
    \(\(blf[a]\)[x, y]\  = \ pssp[a \((x)\), y]\)], "Input",
  Evaluatable->False],

Cell["\<\
Obviously, blf[a] is symmetric iff a is symmetric. The matrix of blf[a] is \
defined by\
\>", "Text"],

Cell[BoxData[
    \(blf[m_]\  := \ Transpose[m] . gram\)], "Input",
  CellLabel->"In[26]:=",
  InitializationCell->True],

Cell[BoxData[
    \(blf[matrix[a]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[38]:="],

Cell["Since", "Text"],

Cell[BoxData[
    \(gram . gram\)], "Input",
  CellLabel->"In[39]:="],

Cell["\<\
we obtain the matrix m of  the linear map associated to the bilinear form \
with matrix matrix[b] by\
\>", "Text"],

Cell[BoxData[
    \(operator[b_]\  := \ gram . Transpose[b]\)], "Input",
  CellLabel->"In[27]:=",
  InitializationCell->True],

Cell[BoxData[
    \(operator[matrix[b]] // MatrixForm\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(blf[operator[matrix[b]]] // MatrixForm\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(operator[blf[matrix[a]]] // MatrixForm\)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
This coincides with the general formulas in [2], section 2.2.10.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example: Circles", "Subsubsection"],

Cell["Obviously, the following  circular cones define circles", "Text"],

Cell[BoxData[
    \(blfc[a_]\  := {{a, 0, 0}, {0, a, 0}, {0, 0, \(-1\)}}\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(blfc[a] // MatrixForm\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(operator[blfc[a]]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(vec[x] . blfc[a] . vec[x]\)], "Input",
  CellLabel->"In[47]:="],

Cell["The center is z = stb[3]; the general solution is", "Text"],

Cell[BoxData[
    \(circs[a_, t_]\  := \ {Cos[t]/Sqrt[a], \ Sin[t]/Sqrt[a], \ 1}\)], "Input",\

  CellLabel->"In[48]:="],

Cell[BoxData[
    \(circs[a, t] . blfc[a] . circs[a, t]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[50]:="],

Cell["The hyperbolic radius of the circle is ", "Text"],

Cell[BoxData[
    \(ArcCosh[
      pssp[stb[3], circs[a, t]]/pssp[circs[a, t], circs[a, t]]]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[52]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 Central quadrics", "Subsection"],

Cell["\<\
From theorem 2.6.28 in [2] it follows that every central quadric in the \
hyperbolic plane has a normal form representation with the matrix\
\>", "Text"],

Cell[BoxData[
    \(central[a_, 
        b_]\  := \ {{\(-1\), 0, 0}, {0, a, 0}, {0, 0, b}}\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(vec[x] . central[a, b] . vec[x]\)], "Input",
  CellLabel->"In[28]:="],

Cell["\<\
Of course, the eigenvalues and eigenvectors of the associated operator can be \
read directly\
\>", "Text"],

Cell[BoxData[
    \(Eigensystem[operator[central[a, b]]]\)], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
for the Klein model we set x[1] = 1,  x[2] = x,  x[3] = y. The index \
condition index[b] < 3/2 implies 0 <a\[LessEqual]b; we consider non \
degenerate quadrics only. Under this condition we apply the usual parameter \
representation of an ellipse:\
\>", "Text"],

Cell[BoxData[
    \(\(\(ellipse[t_, a_, b_]\)\(\ \)\(:=\)\({Cos[t]/Sqrt[a], \ 
        Sin[t]/Sqrt[b]}\)\(\ \)\)\)], "Input",
  CellLabel->"In[28]:=",
  InitializationCell->True],

Cell["\<\
 By the cited theorem,  this ellipse belongs entirely to the unit disk, iff  \
1<a\[LessEqual]b takes place; it is a circle iff 1<a =b. We shall construct \
the ellipses in the conformal and the Poincar\[EAcute] model\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[euklein[ellipse[t, \ 1.1, 4]], {t, 0, 2*Pi}]\)], "Input",\

  CellLabel->"In[57]:="],

Cell[BoxData[
    \(Show[{%, \ klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(kleinell\  = \ %\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(Export["\<kleinell.eps\>", kleinell]\)], "Input",
  CellLabel->"In[37]:="],

Cell["The Poincar\[EAcute] image loses convexity:", "Text"],

Cell[BoxData[
    \(ParametricPlot[
      eupoincare[ellipse[t, \ 1.1, 4]], {t, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(Show[{%, poinborder[1.2]}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(poinell = \ %\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(Export["\<poinell.eps\>", poinell]\)], "Input",
  CellLabel->"In[44]:="],

Cell["More interesting is the case a = 1:", "Text"],

Cell[BoxData[
    \(ParametricPlot[euklein[ellipse[t, \ 1, 2]], {t, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(ParametricPlot[eupoincare[ellipse[t, \ 1, 2]], {t, 0, 2*Pi}]\)], "Input",\

  CellLabel->"In[58]:="],

Cell["\<\
The ellipse is inscribed in the unit circle, tangent to it in two opposite \
points:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[ellipse[t, \ 1, 2], {t, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(Show[{klkr, %}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[60]:="],

Cell["\<\
Now, the first step in constructing the conformal or the Poincar\[EAcute] \
model, is projecting the unit circle around the origine within the y,z-plane \
orthogonally onto the half-sphere x>0;  by this projection the ellipse is \
broken into two branches with intersecting at the tangent points.\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[hsphpt[ellipse[t, \ 1, 2]], \ {t, 0, 2*Pi}]\)], "Input",\

  CellLabel->"In[61]:="],

Cell["\<\
The quadric has two infinite points, but it does not have an asymptote at \
these points (The border is not met orthogonally.) In the next subsection \
they will be identified as the equidistants  of  a line.\
\>", "Text"],

Cell["\<\
In case a<1<b the ellipse has points outside and inside  the unit disk:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[ellipse[t,  .5, \ 3], {t, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(Show[{%, \ klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Clear[a, b, t]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Solve[ellipse[t, a, \ b] . ellipse[t, a, \ b] \[Equal] \ 1, \ 
      t]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(a =  .5; b = 1.8; 
    ParametricPlot[
      euklein[ellipse[t, a\ , b]], {t, 
        ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)], 
        ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]}]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(ellio1 = \ %\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(a =  .5; b = 1.8; 
    ParametricPlot[
      euklein[ellipse[t, a\ , 
          b]], {t, \(-ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)]\), \
\(-ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]\)}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(ellio2\  = \ %\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Show[{ellio1, ellio2, klkr}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(kleinhyp\  = \ %\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Export["\<kleinhyp.eps\>", kleinhyp]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(a =  .5; b = 1.8; 
    ParametricPlot[
      eupoincare[ellipse[t, a\ , b]], {t, 
        ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)], 
        ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(poinellio1\  = \ %\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(a =  .5; b = 1.8; 
    ParametricPlot[
      eupoincare[
        ellipse[t, a\ , 
          b]], {t, \(-ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)]\), \
\(-ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]\)}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(poinellio2\  = \ %\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Show[{poinellio1, \ poinellio2, \ poinborder[2.3]}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(poinhyp\  = \ %\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(Export["\<poinhyp.eps\>", poinhyp]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(D[eupoincare[ellipse[t, a, b]], t]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(Limit\ [\(Out[143]\)[\([2]\)]/\(Out[143]\)[\([1]\)], \ 
      t \[Rule] \(-ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)]\)]\)], \
"Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(Clear[a, b, t]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(D[eupoincare[ellipse[t, a, b]], t]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(Limit\ [\(Out[151]\)[\([2]\)]/\(Out[151]\)[\([1]\)], \ 
      t \[Rule] \(-ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)]\)]\)], \
"Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(Limit\ [\(Out[151]\)[\([2]\)]/\(Out[151]\)[\([1]\)], \ 
      t \[Rule] 
        ArcCos[\(-\(\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)\)\)]]\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(Limit\ [\(Out[151]\)[\([2]\)]/\(Out[151]\)[\([1]\)], \ 
      t \[Rule] ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(Limit\ [\(Out[151]\)[\([2]\)]/\(Out[151]\)[\([1]\)], \ 
      t \[Rule] \(-ArcCos[\(\@a\ \@\(1 - b\)\)\/\@\(a - b\)]\)]\)], "Input",
  CellLabel->"In[155]:="],

Cell["\<\
It follows: The pictures do not lie: the quadrics intersect the infinite \
border orthogonally, i.e. they have asymptotes at its infinite points! \
Therefore they should be called hyperbolic hyperbolas.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3 Example:  Equidistants are central quadrics", "Subsection"],

Cell["We consider the line defined by the x[1]-axis:", "Text"],

Cell[BoxData[
    \(\(hypline[0]\)[t]\)], "Input",
  CellLabel->"In[157]:="],

Cell["The Klein picture is the diameter", "Text"],

Cell[BoxData[
    \(euklein[eucl[\(hypline[0]\)[t]]]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \(Limit[Tanh[t]\/\(1 + \@Sech[t]\^2\), \ 
      t\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[159]:="],

Cell[TextData[{
  "The equidistants to this line with distance d are given by (s.",
  ButtonBox[" [2]",
    ButtonData:>"[2]",
    ButtonStyle->"Hyperlink"],
  ", (2.6.54-55))"
}], "Text"],

Cell[BoxData[
    \(\(equidist[d_]\)[
        t_]\  := \((stb[1]*Cosh[t]\  + \ stb[2]*Sinh[t])\)*Cosh[d]\  + 
        stb[3]*Sinh[d]\)], "Input",
  CellLabel->"In[29]:=",
  InitializationCell->True],

Cell["\<\
where d may be positive or negative; the distance, of course, is Abs[d].  We \
consider the symmetric bilinear form with matrix\
\>", "Text"],

Cell[BoxData[
    \(equi[
        d_]\  := \ {{\(-1\), \ 0, \ 0}, {0, 1, 0}, {0, 0, 
          Coth[d]^2}}\)], "Input",
  CellLabel->"In[30]:=",
  InitializationCell->True],

Cell[BoxData[
    \(equi[d] // MatrixForm\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(Simplify[\(equidist[d]\)[
          t] . \((equi[d] . \(equidist[d]\)[t])\)]\)], "Input",
  CellLabel->"In[163]:="],

Cell[TextData[{
  "It follows the statement (s",
  ButtonBox[".[2]",
    ButtonData:>"[2]",
    ButtonStyle->"Hyperlink"],
  ", example 2.6.12). In the kleinpicture we have"
}], "Text"],

Cell[BoxData[
    \(ParametricPlot[
      euklein[eucl[\(equidist[1. ]\)[t]]], {t, \(-5\), 5}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(eq1\  = \ %\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(ParametricPlot[
      euklein[eucl[\(equidist[\(-1. \)]\)[t]]], {t, \(-5\), 5}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(eq2\  = \ %\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Show[{eq1, eq2, klkr}, AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(kleinequidist\  = \ %\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(aequiop[d_]\  := \ operator[equi[d]]\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \(aequiop[d] // MatrixForm\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \(Eigensystem[aequiop[d]]\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \(Coth[2. ]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(Coth[ .5]\)], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
Now we define an elliptical cone with parameters a,b in the e-dimensional \
vector space:\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b, s, 
      t]; \ \(cone[a_, b_]\)[s_, t_] := \ {1, \ a*Cos[s], b*Sin[s]}*
        t\)], "Input",
  CellLabel->"In[31]:=",
  InitializationCell->True],

Cell["\<\
The cone corresponding to the quadric of our  equidistants is\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(cone[1, 1/Coth[1. ]^2]\)[s, t], {s, 0, 2*Pi}, {t, 0, 
        10}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(graequi\  = \ %\)], "Input",
  CellLabel->"In[58]:="],

Cell["\<\
Its position within the pseudo-spherical model of the hyperbolic plane is the \
intersection og the cone with the absolute pseudosphere:\
\>", "Text"],

Cell[BoxData[
    \(Show[{pseusph, graequi}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(interaequi = %\)], "Input",
  CellLabel->"In[175]:="],

Cell["Better visible is the situation i in the Klein model:", "Text"],

Cell[BoxData[
    \(ParametricPlot[
      Take[\(cone[1, 1/Coth[1. ]^2]\)[s, 1], \(-2\)], \ {s, 0, 2*Pi}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[67]:="],

Cell["\<\
Compare this with the Graphics kleinequidist constructed above:\
\>", "Text"],

Cell[BoxData[
    \(Show[kleinequidist]\)], "Input",
  CellLabel->"In[68]:="],

Cell["We construct the Poincar\[EAcute] picture:", "Text"],

Cell[BoxData[
    \(ParametricPlot[
      eupoincare[eucl[\(equidist[\(-1. \)]\)[t]]], {t, \(-5\), 5}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(poiequi1 = %\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(ParametricPlot[eupoincare[eucl[\(equidist[1. ]\)[t]]], {t, \(-5\), 5}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(poiequi2\  = %\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(ParametricPlot[eupoincare[eucl[\(hypline[0]\)[t]]], {t, \(-5\), 5}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(poiline\  = %\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Show[{poiline, poiequi1, poiequi2}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[75]:="],

Cell["This is the wanted picture in the Poincar\[EAcute] model.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4 Example:  Horocycles are quadrics", "Subsection"],

Cell[TextData[{
  "By Proposition 2.6.20 in ",
  ButtonBox["[2]",
    ButtonData:>"[2]",
    ButtonStyle->"Hyperlink"],
  ",  p.260, all horocycles (Grenzkreise) of the hyperbolic plane are \
congruent. We consider one of them, which is a curve with parameter \
representation  (adapt [2], (2.6.64)"
}], "Text"],

Cell[BoxData[
    \(horo[t_]\  := \ 
      stb[2]*t/Sqrt[2] - stb[3]*t^2/4\  + \ stb[1]*\((1 + t^2/4)\)\)], "Input",\

  CellLabel->"In[32]:=",
  InitializationCell->True],

Cell[BoxData[
    \(pssp[horo[t], horo[t]]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[130]:="],

Cell["We consider the bilinear form with matrix", "Text"],

Cell[BoxData[
    \(ory\  = \ {{0, 0, 1}, {0, 1, 0}, {1, 0, 2}}\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(vec[x] . ory . vec[x]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(horo[t] . ory . horo[t]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[136]:="],

Cell["\<\
It follows that the horocycles are quadrics. To calculate the invariants of \
this special quadric, we consider the associated operator\
\>", "Text"],

Cell[BoxData[
    \(opory\  = \ operator[ory]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \(Eigenvalues[opory]\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(Eigenvectors[opory]\)], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \(Solve[opory . vec[x]\  - \ {\(-1\), 0, 1} \[Equal] \ vec[x], \ 
      vec[x]]\)], "Input",
  CellLabel->"In[141]:="],

Cell[BoxData[
    \(opory . {1, 0, 0}\)], "Input",
  CellLabel->"In[142]:="],

Cell["A basis for which  opory has Jordan normal form is", "Text"],

Cell[BoxData[
    \(va[2]\  = \ stb[1]; \ va[1]\  = stb[2]; \ 
    va[3] = \(-stb[1]\)\  + \ stb[3];\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(Transpose[{va[1], va[2], va[3]}]\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[145]:="],

Cell["\<\
Therefore a  transformation yielding the Jordan normal form of the associated \
operator opory is \
\>", "Text"],

Cell[BoxData[
    \(transf\  = \ Transpose[{va[1], va[2], va[3]}]\)], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(Inverse[transf] . opory . transf\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[149]:="],

Cell["The scalar products of the basis elements are", "Text"],

Cell[BoxData[
    \(Table[pssp[va[i], va[j]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[151]:="],

Cell["\<\
The Jordan basis is not pseudo-orthogonal; it is easy to show that any \
eigenvector belonging to a Jordan cell of order greater  than 1 must be \
isotropic.
Here are pictures of the constructed horocycle in the conformal and the \
Poincar\[EAcute] models:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[euklein[eucl[horo[t]]], {t, \(-120\), 120}, 
      AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(grhoro\  = %\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(Show[{grhoro, klkr}, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(ParametricPlot[eupoincare[eucl[horo[t]]], {t, \(-120\), 120}, 
      AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[155]:="],

Cell["\<\
Now we conctruct the intersection of the standard hyperboloid with the \
horocyclic cone:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      horo[t]*s/\(horo[t]\)[\([1]\)], \ {t, \(-20\), 20}, \ {s, 0, 10}, 
      PlotPoints\  \[Rule] \ 50]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \(Show[{%, pseusph}]\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \(horo3d = %\)], "Input",
  CellLabel->"In[158]:="],

Cell["\<\
Remark: In the euclidean picture, the horocycle is not a circle!\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[eucl[horo[t]], {t, \(-120\), 120}, 
      AspectRatio\  \[Rule] \ Automatic, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[75]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.5 Plane quadrics  whose associated operator is a Jordan cell of order 3\
\>", "Subsection"],

Cell[BoxData[
    \(quadj3[u_] := {{\(-u\), 0, 1}, {0, u, 1}, {1, 1, u}}\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(quadj3[u] // MatrixForm\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(vec[x] . quadj3[u] . vec[x]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[30]:="],

Cell["\<\
In case u=o the quadric degenerates to a pair of planes :x[3] = 0, x[2] = \
-x[1]; in the hyperbolic plane one has the line x[3] = 0 only; the second \
plane yields the infinite point x[2] = -1 only.  In the following we assume u\
\[NotEqual]0.\
\>", "Text"],

Cell[BoxData[
    \(opj3[u_] := \ operator[quadj3[u]]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(opj3[u] // MatrixForm\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(Det[opj3[u]]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Eigensystem[opj3[u]]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(opj3[u] . {\(-1\), 1, 0}\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(pssp[opj3[u] . vec[x], vec[y]] - 
      pssp[vec[x], opj3[u] . vec[y]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[38]:="],

Cell["We set", "Text"],

Cell[BoxData[
    \(baj3[3]\  = \ \(-stb[1]\) + stb[2]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(Solve[\((opj3[u] - u*IdentityMatrix[3])\) . vec[x] \[Equal] \ {\(-1\), 
          1, 0}, vec[x]]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(opj3[u] . stb[3]\  \[Equal] \ {0, 0, 1}*u\ \  - stb[1] + 
        stb[2]\)], "Input",
  CellLabel->"In[41]:="],

Cell["Thus we set", "Text"],

Cell[BoxData[
    \(baj3[2]\  = \ stb[3]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(Solve[\((opj3[u] - u*IdentityMatrix[3])\) . vec[x] \[Equal] \ baj3[2], 
      vec[x]]\)], "Input",
  CellLabel->"In[43]:="],

Cell["We may set", "Text"],

Cell[BoxData[
    \(baj3[1]\  = \ stb[1]\)], "Input",
  CellLabel->"In[44]:="],

Cell["A basis for which opj3[u] has Jordan normal form is ", "Text"],

Cell[BoxData[
    \(mtbaj3\  = \ Transpose[Table[baj3[i], \ {i, 3}]]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[49]:="],

Cell["Indeed:", "Text"],

Cell[BoxData[
    \(Inverse[mtbaj3] . opj3[u] . mtbaj3\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(Inverse[mtbaj3]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[51]:="],

Cell[CellGroupData[{

Cell["The shape of the quadric, 1. approach", "Subsubsection"],

Cell[BoxData[
    \(vec[x] . quadj3[u] . vec[x]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[104]:="],

Cell["We set x[1] :", "Text"],

Cell[BoxData[
    \(Solve[{2\ \((x[1] + x[2])\)\ x[3] + 
            u\ \((\(-x[1]\^2\) + x[2]\^2 + x[3]\^2)\) \[Equal] 0, 
        x[1] \[Equal] \ 1}, \ vec[x]]\)], "Input",
  CellLabel->"In[105]:="],

Cell["The zeros of the radicand are obtained by", "Text"],

Cell["fr[t_, u_] := 4*t^2 - 4*u*(-u + 2*t + u*t^2)", "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(Solve[fr[t, u] \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(qj3curvep[t_, u_] := \ {\((\(-2\)*t\  + Sqrt[fr[t, u]])\)/\((2*u)\), \ 
        t}\)], "Input",
  CellLabel->"In[108]:="],

Cell["u = 2;ParametricPlot[qj3curvep[t,u],{t, u/(1+u),u/(1-u)}]", "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(q3jp2\  = \ %\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(Clear[u]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(qj3curven[t_, u_] := \ {\((\(-2\)*t\  - Sqrt[fr[t, u]])\)/\((2*u)\), \ 
        t}\)], "Input",
  CellLabel->"In[112]:="],

Cell["u = 2;ParametricPlot[qj3curven[t,u],{t,u/(1-u),u/(1+u)}]", "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(q3jn2\  = \ %\)], "Input",
  CellLabel->"In[114]:="],

Cell["The figure of the curve in the Klein model (u=2) is", "Text"],

Cell[BoxData[
    \(Show[{q3jp2, q3jn2, klkr}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(Clear[u]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Solve[qj3curvep[t, u] . qj3curvep[t, u] \[Equal] \ 1, \ t]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Solve[qj3curven[t, u] . qj3curven[t, u] \[Equal] \ 1, u, t]\)], "Input",\

  CellLabel->"In[118]:="],

Cell[BoxData[
    \(qj3curvep[t, u] . qj3curvep[t, u]\)], "Input",
  CellLabel->"In[119]:="],

Cell[TextData[{
  "Obviously, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " found the trivial solution only, and this is the only solution. To get \
the hyperbolic points, we plot"
}], "Text"],

Cell["u = 2;ParametricPlot[qj3curvep[t,u],{t, 0,u/(1+u)}]", "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(qj3hyp2\  = \ %\)], "Input",
  CellLabel->"In[121]:="],

Cell["u = 2;ParametricPlot[qj3curven[t,u],{t, 0,u/(1+u)}]", "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(qj3hyn2 = %\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(Show[{qj3hyp2, qj3hyn2, klkr}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[124]:="],

Cell["Wanting the Klein picture we set", "Text"],

Cell["u = 2;ParametricPlot[euklein[qj3curvep[t,u]],{t, 0,u/(1+u)}]", "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(qj3klp = %\)], "Input",
  CellLabel->"In[126]:="],

Cell["u = 2;ParametricPlot[euklein[qj3curven[t,u]],{t, 0,u/(1+u)}]", "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(qj3kln = %\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(Show[{qj3klp, qj3kln, klkr}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[129]:="],

Cell["Finally we plot the Poincar\[EAcute] picture", "Text"],

Cell["\<\
u = 2;ParametricPlot[eupoincare[qj3curvep[t,u]],{t, 0,u/(1+u)}]\
\>", "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(qj3poinp\  = \ %\)], "Input",
  CellLabel->"In[131]:="],

Cell["\<\
u = 2;ParametricPlot[eupoincare[qj3curven[t,u]],{t, 0,u/(1+u)}]\
\>", "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(qj3poinn = %\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(Show[{qj3poinp, qj3poinn}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Clear[u\ , \ a, \ x]\)], "Input",
  CellLabel->"In[135]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The shape of the quadric, 2. approach", "Subsubsection"],

Cell["\<\
One observes that the curves obtained are orthogonally projected bijectively \
on the hyperbolic line joining its infinite points. Thus, it is a better \
method to solve the equation of the quadric\
\>", "Text"],

Cell[BoxData[
    \(2\ \((x[1] + x[2])\)\ x[3] + 
      u\ \((\(-x[1]\^2\) + x[2]\^2 + x[3]\^2)\)\)], "Output",
  CellLabel->"Out[104]="],

Cell["\<\
setting x[1] = 1, [x[2] = x, x[3] = y and find the solution as a function \
y(x):\
\>", "Text"],

Cell[BoxData[
    \(Solve[{2\ \((1 + x)\)\ y + u\ \((\(-1\) + x^2 + y^2)\) \[Equal] 0}, 
      y]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[35]:="],

Cell["The solutions are", "Text"],

Cell["\<\
fpj3[x_, u_] := (-1 - x + Sqrt[(1 + x)^2 - u^2*(-1 + x^2)])/u\
\>", "Input",
  CellLabel->"In[36]:="],

Cell["fnj3[x_, u_] := (-1 - x -Sqrt[(1 + x)^2 - u^2*(-1 + x^2)])/u", "Input",
  CellLabel->"In[37]:="],

Cell["The radicand is ", "Text"],

Cell["frad[x_, u_] := (1 + x)^2 - u^2*(-1 + x^2)", "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(Solve[frad[x, u]\  \[Equal] \ 0, \ x]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(Plot[\(1 + u\^2\)\/\(\(-1\) + u\^2\), {u, \ 0, 5}]\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
The solutions intersect the infinity, i.e. the unit circle, within the points \
obtained for x = \[PlusMinus]1:\
\>", "Text"],

Cell[BoxData[
    \(fpj3[1, u]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(fpj3[\(-1\), u]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(fnj3[\(-1\), u]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(fpj3[\(-1\), u]\)], "Input",
  CellLabel->"In[44]:="],

Cell["For u=1 we obtain", "Text"],

Cell[BoxData[
    \(Plot[fpj3[x, 1], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(Plot[fnj3[x, 1], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(Show[{%, %%}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[48]:="],

Cell["\<\
The first solution fnj3 yields points outside the hyperbolic plane only. To \
prove this we consider the function\
\>", "Text"],

Cell[BoxData[
    \(ftest[x_, u_]\  := \ x^2\  + \ fnj3[x, u]^2\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(Simplify[ftest[x, u]]\)], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
We show that this function is greater or equal 1 at all its real points.\
\>", "Text"],

Cell[BoxData[
    \(Solve[% \[Equal] \ 1, x]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(Solve[%% \[Equal] \ 1, u]\)], "Input",
  CellLabel->"In[52]:="],

Cell["\<\
Only the points where the radicand is not negative are of interest. We find \
the roots of the radicand\
\>", "Text"],

Cell[BoxData[
    \(Solve[\((1 + x)\)\^2 - u\^2\ \((\(-1\) + x\^2)\) \[Equal] \ 0, \ 
      x]\)], "Input",
  CellLabel->"In[53]:="],

Cell["For u > 1 we consider", "Text"],

Cell[BoxData[
    \(Table[
      Plot[ftest[x, 
          u], \ {x, \ \(-1\), \ \((1 + u^2)\)/\((\(-1\) + u^2)\)}], \ {u, 
        1 +  .1, 4,  .2}]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(Show\ [%]\)], "Input",
  CellLabel->"In[55]:="],

Cell["For u < 1 we get ", "Text"],

Cell[BoxData[
    \(Table[
      Plot[ftest[x, 
          u], \ {x, \ \((1 + u^2)\)/\((\(-1\) + u^2)\), \(-1\)}], \ {u, 
        1 +  .1, 4,  .2}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(Simplify[ftest[x, 1]]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(Plot[%, {x, \ \(-1\), \ 1}]\)], "Input",
  CellLabel->"In[59]:="],

Cell["Also fr u=1 we get outer points only.", "Text"],

Cell[BoxData[
    \(Limit\ [ftest[x, u], \ x\  \[Rule] \ \(-1\)]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(Limit\ [ftest[x, u], \ 
      x\  \[Rule] \ \ \((1 + u^2)\)/\((\(-1\) + u^2)\)]\)], "Input",
  CellLabel->"In[61]:="],

Cell["\<\
This entity is greater or equal 1, as easely can be seen, It follows \
ftest[x,u]\[GreaterEqual]1 at all its real points; the corresponding points \
are not hyperbolic.\
\>", "Text"],

Cell["Now we consider the curves within the conformal model:", "Text"],

Cell[BoxData[
    \(ParametricPlot[euklein[{x, \ fpj3[x, 1]}], {x, \(-1\), 1}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[euklein[{x, \ fpj3[x,  .5*j]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 1, 10}]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Show[{%, klkr}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Show[%, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(qj3p1plus\  = \ %\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Export["\<qj3p1plus.eps\>", qj3p1plus]\)], "Input",
  CellLabel->"In[67]:="],

Cell["\<\
This are the quadrics quadj3[u] for u = 0.5,1, 1.5,....., 5 in the conformal \
model\
\>", "Text"],

Cell["\<\
For u -> 0, u>0,  the quadrics converge to the line joining their infinite \
points:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[euklein[{x, \ fpj3[x, 1/\((3*j)\)]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 2, 5}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Show[%, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[69]:="],

Cell["\<\
This limit process may better be observed within the Poincar\[EAcute] \
model:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        eupoincare[{x, \ fpj3[x, 1/\((3*j)\)]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 2, 5}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[71]:="],

Cell["\<\
For u -> \[Infinity] the  quadrics converge to infinity:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[euklein[{x, \ fpj3[x, \((10*2^j)\)]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 2, 5}]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Show[{%, klkr}]\)], "Input",
  CellLabel->"In[73]:="],

Cell["\<\
Negative values of u give the  reflections at the lines joining the infinite \
points of the quadrc:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[euklein[{x, \ fpj3[x, \(-1\)]}], {x, \(-1\), 1}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[euklein[{x, \ fpj3[x, \(-j\)]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 1, 10}]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(Show[{%, \ klkr}, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(qj3p1minus\  = \ %\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(Export["\<qj3p1minus.eps\>", qj3p1minus]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(Show[{qj3p1minus, qj3p1plus, \ klkr}, \ 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(j3kl\  = %\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(Export["\<j3kl.eps\>", j3kl]\)], "Input",
  CellLabel->"In[90]:="],

Cell["\<\
This are the quadrics quadj3[u] for u = -1,-2,...., -10  in the conformal \
model\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[eupoincare[{x, \ fpj3[x,  .5*j]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 1, 10}]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Show[%, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(poinqj3p1plus\  = \ %\)], "Input",
  CellLabel->"In[81]:="],

Cell["\<\
This are the quadrics quadj3[u] for u = 0.5,1, 1.5,....., 5 in the Poincar\
\[EAcute] model.\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[eupoincare[{x, \ fpj3[x, \(-j\)]}], {x, \(-1\), 1}, \ 
        AspectRatio\  \[Rule] \ Automatic], {j, 1, 10}]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(poinqj3p1minus\  = \ %\)], "Input",
  CellLabel->"In[84]:="],

Cell["\<\
This are the quadrics quadj3[u] for u = -1,-2,...., -10  in the Poincar\
\[EAcute] model\
\>", "Text"],

Cell[BoxData[
    \(Show[{%, poinqj3p1plus}]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(poinqj3\  = \ %\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(Export["\<poinqj3.eps\>", poinqj3]\)], "Input",
  CellLabel->"In[87]:="],

Cell["\<\
This is the picture of all the quadrics scetched before in the conformal \
model, now in the Poincar\[EAcute] model.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.6 Quadrics whose associated operators have  only two Jordan cells \
\>", "Subsection"],

Cell[CellGroupData[{

Cell["4.6.1 Normal form of the Operator and the equation", "Subsubsection"],

Cell[TextData[StyleBox["We consider symmetric operators with the Jordan \
normal form", "Text"]], "Text"],

Cell[BoxData[
    \(jop[u_, v_] := {{v, 0, 0}, {1, v, 0}, {0, 0, u}}\)], "Input",
  CellLabel->"In[33]:=",
  InitializationCell->True],

Cell[BoxData[
    \(jop[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[68]:="],

Cell[TextData[{
  StyleBox["Remark:",
    FontColor->RGBColor[0, 0, 1]],
  " Mathematica's JordanDecomposition differs formally from that used in the \
book:"
}], "Text"],

Cell[BoxData[
    \(JordanDecomposition[jop[u, v]]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(%[\([2]\)] // MatrixForm\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(trp[1, 3] . % . trp[1, 3]\)], "Input",
  CellLabel->"In[71]:="],

Cell["This is the shape we prefer, and in which we defined jop:", "Text"],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[72]:="],

Cell[TextData[StyleBox["Adaption of an pseudo-orthonormal frame:",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
We  want to find all symmetric operators sj[u,v], up to pseudo-orthogonal \
equivalence,  with this given Jordan decomposition. Let{a1,a2,a3} be a \
Jordan-Basis; that is a basis for which the operator has a matrix of shape \
jop[u,v]. By assumption, a3 is an eigenvector with a one-dimensional Jordan \
cell. It cannot be timelike, since than a would be diagonazable, see 4.2.  \
From the symmetry property
<a(x),y> = <x,a(y)> , applied to the basic vectors x,y = ai,aj, it follows:
x=a1, y=a2: => a2 is isotropic,
x= a1, y = a3: =>  <a2,a3> = 0.
Since there do not exist isotropic, linear independent orthogonal vectors \
(the index of the space is 1), a3 must be spacelike, and we may put a3 = \
stb[3].  Since for a symmetric operator a  with a subspace U also its \
orthogonal subspace is invariant, the jordan cell of order 2 can be chosen as \
the span of {stb[1], stb[2]}.  To adapt the basis we first consider the \
isotropy subgroup of jop[u,v] with respect to conjugation, or equivalently, \
we consider the set of all Jordan bases in the cell of order 2:\
\>", "Text"],

Cell[BoxData[
    \(mmm = {{m11, m12, 0}, {m21, m22, 0}, {0, 0, 1}}\)], "Input",
  CellLabel->"In[73]:="],

Cell["We find the isotropy group of jop[u,v]", "Text"],

Cell[BoxData[
    \(Solve[
      Inverse[mmm] . jop[u, v] . mmm\  \[Equal] \ jop[u, v], {m11, m12, m21, 
        m22}]\)], "Input",
  CellLabel->"In[74]:="],

Cell["The solutions coincide with the matrix", "Text"],

Cell[BoxData[
    \(Clear[mmm]; 
    mmm[s_, t_] := \ {{s, 0, 0}, {t, s, 0}, {0, 0, 1}}\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(mmm[s, t] // MatrixForm\)], "Input",
  CellLabel->"In[76]:="],

Cell["Consider the corresponding basis transformation", "Text"],

Cell[BoxData[
    \(b1\  = \ a1*s\  + a2*t; \ b2\  = \ a2*t\)], "Input",
  CellLabel->"In[77]:="],

Cell["and the equations", "Text"],

Cell["\<\
pssp[b1, b1] == pssp[a1, a1]*s^2 + 
   2*t*pssp[a1, a2]*s == -1\
\>", "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(pssp[b1, b2] \[Equal] \ pssp[a1, a2]*\(\(s^2\)\(\ \)\)\)], "Input",
  CellLabel->"In[79]:="],

Cell["\<\
Since a2 is isotropic it follows pssp[a1,a2]\[NotEqual]0; therefore we may \
choose s in such away that pssp[b1,b2]=\[PlusMinus]1, depending on  the \
sign[a1,a2],  being invariant under the transformation. Having chosen s we \
define t as the unique solution of the first equation. Thus, we have to \
distinguish two cases \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Case pssp[a1,a2] < 0", "Subsubsection"],

Cell["\<\
We find a pseudo-orthonormal basis such that the Jordan Basis is\
\>", "Text"],

Cell[BoxData[
    \(b1 = stb[1]; b2 = \ stb[1]\  + \ stb[2]; \ b3\  = \ stb[3];\)], "Input",\

  CellLabel->"In[34]:=",
  InitializationCell->True],

Cell["The transformation matrix is ", "Text"],

Cell[BoxData[
    \(mtrb\  = \ Transpose[{b1, b2, b3}]\)], "Input",
  CellLabel->"In[35]:=",
  InitializationCell->True],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(mtrb . jop[u, v] . Inverse[mtrb] // MatrixForm\)], "Input",
  CellLabel->"In[59]:="],

Cell["\<\
the matrix of the corresponding operator with respect to this basis then is\
\>", "Text"],

Cell[BoxData[
    \(jopmi[u_, v_]\  := \ mtrb . jop[u, v] . Inverse[mtrb]\)], "Input",
  CellLabel->"In[36]:=",
  InitializationCell->True],

Cell[BoxData[
    \(jopmi[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
The operator is of course symmetric, the matrix of the corresponding \
Bilinearform is\
\>", "Text"],

Cell[BoxData[
    \(blmi[u_, v_]\  := \ blf[jopmi[u, v]]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(blmi[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Simplify[vec[x] . blmi[u, v] . vec[x]]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(% /. {x[1]\  \[Rule] \ 1, x[2]\  \[Rule] x, \ 
        x[3]\  \[Rule] \ y}\)], "Input",
  CellLabel->"In[67]:="],

Cell["eqmi[u_, v_] = -1 - v + 2*x + (-1 + v)*x^2 + u*y^2", "Input",
  CellLabel->"In[37]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Case pssp[a1,a2] > 0", "Subsubsection"],

Cell["\<\
We find a pseudo-orthonormal basis such that the Jordan basis is\
\>", "Text"],

Cell[BoxData[
    \(a1 = stb[1]; a2 = \ \(-stb[1]\)\  + \ stb[2]; \ 
    a3\  = \ stb[3];\)], "Input",
  CellLabel->"In[38]:=",
  InitializationCell->True],

Cell["The transformation matrix is ", "Text"],

Cell[BoxData[
    \(mtra\  = \ Transpose[{a1, a2, a3}]\)], "Input",
  CellLabel->"In[39]:=",
  InitializationCell->True],

Cell["\<\
the matrix of the corresponding operator with respect to this basis then is\
\>", "Text"],

Cell[BoxData[
    \(joppl[u_, v_]\  := mtra . jop[u, v] . Inverse[mtra]\)], "Input",
  CellLabel->"In[40]:=",
  InitializationCell->True],

Cell[BoxData[
    \(joppl[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[72]:="],

Cell["Compare:", "Text"],

Cell[BoxData[
    \(jopmi[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(trp[1, 2] . % . trp[1, 2]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(refl[2] . % . refl[2]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(% \[Equal] \ joppl[u, v]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(%% // MatrixForm\)], "Input",
  CellLabel->"In[78]:="],

Cell["\<\
It follows: Both opertors joppl, joppmi are conjugate with respect to the \
pseudo-orthogonal group. \
\>", "Text"],

Cell["\<\
The operator joppl[u,v] is of course symmetric, the matrix of the \
corresponding bilinear form is\
\>", "Text"],

Cell[BoxData[
    \(blpl[u_, v_]\  := \ blf[joppl[u, v]]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(blpl[u, v] // MatrixForm\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(Simplify[vec[x] . blpl[u, v] . vec[x]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(% /. {x[1]\  \[Rule] \ 1, x[2]\  \[Rule] x, \ 
        x[3]\  \[Rule] \ y}\)], "Input",
  CellLabel->"In[82]:="],

Cell["eqpl[u_, v_] := 1 - v + 2*x + (1 + v)*x^2 + u*y^2", "Input",
  CellLabel->"In[41]:=",
  InitializationCell->True],

Cell[BoxData[
    \(eqmi[u, v]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(\(-eqmi[\(-u\), \(-v\)]\)\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(% /. x \[Rule] \ \(-x\)\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(Simplify[% - eqpl[u, v]]\)], "Input",
  CellLabel->"In[87]:="],

Cell["\<\
We conclude: In the Klein model the solutions of eqpl[u,v] = 0  can be \
obtained by solving eqmi[-u,-v] = 0, and reflecting the result at the y-axis.\
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[" 4.6.2 The solutions. Quadrics of type 2,1", "Subsubsection"],

Cell["\<\
From 4.6.1 it follows  that the  symmetric operators joppl, jopmi define  \
congruent families of quadrics. Therefore it suffices to consider one of the \
cases mentioned above. We first consider the quadrics within the Klein model. \
Thus, choosing the  family belonging to the negative sign, we have to solve   \
\
\>", "Text"],

Cell[BoxData[
    \(eqmi[u, v] \[Equal] \ 0\)], "Input",
  CellLabel->"In[91]:="],

Cell["\<\
for all values of u, v.  For u=0 the quadric dgenerates to a pair of lines, \
which also may coincide, or do not meet the hyperbolic plane, represented by \
the unit disk.  Clearly, all solutions are symmetric with respect to the \
x-axis. Their upper part is defined  as the graph of the function of x, \
-1<x<1, \
\>", "Text"],

Cell[BoxData[
    \(\(qfct[v_, u_:  1]\)[x_]\  := \ 
      Sqrt[\((1 + v - 2\ x - \((\(-1\) + v)\)\ x\^2)\)/u]\)], "Input",
  CellLabel->"In[42]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[\(qfct[v]\)[x]]\)], "Input",
  CellLabel->"In[33]:="],

Cell["eqmi[u, v]/.y^2 -> (1 + v - 2*x - (-1 + v)*x^2)/u", "Input",
  CellLabel->"In[54]:="],

Cell["Define", "Text"],

Cell[BoxData[
    \(pol[v_, x_] := \ 1 + v - 2*x - \((\(-1\) + v)\)*x^2\)], "Input",
  CellLabel->"In[43]:=",
  InitializationCell->True],

Cell["\<\
We get solutions being  hyperbolic points only for -1<x<1. The real solutions \
are obtained
a) for u>o and pol[v,x]>0, and
b)for u<0 and pol[v,x]<0.
Deciding are the zeros of pol\
\>", "Text"],

Cell[BoxData[
    \(Solve[pol[v, x] \[Equal] \ 0, x]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(eqmi[0, v] /. x \[Rule] \ 1\)], "Input",
  CellLabel->"In[75]:="],

Cell["\<\
It follows: for all parameters u,v the infinite point {1,0} of the hyperbolic \
plane is a solution. \
\>", "Text"],

Cell[BoxData[
    \(eqmi[u, v] /. \ {x \[Rule] \ 1, \ y^2\  \[Rule] \ 0}\)], "Input",
  CellLabel->"In[117]:="],

Cell[TextData[{
  "And: for all parameters u  the  point {",
  Cell[BoxData[
      \(\(\(-1\) - v\)\/\(\(-1\) + v\)\)]],
  ", 0} of the x-axis is a solution. "
}], "Text"],

Cell[BoxData[
    \(eqmi[u, v] /. {y \[Rule] \ 0, 
        x \[Rule] \((\(-\ 1\) - v)\)/\((\(-1\) + v)\)}\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[75]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The special case v = 1", "Subsubsection"],

Cell["\<\
The value v = 1 is a pole of the second root as a function of v:\
\>", "Text"],

Cell[BoxData[
    \(Plot[\((1 + v)\)/\((1 - v)\), {v, \(-1\), 2}]\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \(Plot[\((1 + v)\)/\((1 - v)\), {v, 1.5, 10}, \ 
      PlotRange\  \[Rule] \ {\(-20\), 0}]\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \(Plot[pol[1, x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(Plot[pol[1, x] + x^2, {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(pol[1, x] + x^2\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(Simplify[% \[Equal] \ 1 + \((1 - x)\)^2]\)], "Input",
  CellLabel->"In[133]:="],

Cell["\<\
It follows: for v=1 and u with 0<u\[LessEqual]1 there don't exist hyperpolic \
solution points.  Consider the case u>1:\
\>", "Text"],

Cell[BoxData[
    \(pol[1, x]/u + x^2\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Plot[pol[1, x]/1.5 + x^2, {x, 0, 1}]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(Solve[pol[1, x]/u\  + \ x^2 \[Equal] \ 1, x]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Plot[\((2 - u)\)/u, {u, 1, 5}]\)], "Input",
  CellLabel->"In[136]:="],

Cell["\<\
Thus, we get a family of solutions vor v = 1, u>1. In the conformal model \
e.g.\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, Sqrt[pol[1, x]/u]}], {x, \ \((2 - u)\)/u, 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u, 1.1, 3.2,  .3}]\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    \(Show[{%, klkr}]\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \(bsp1upl\  = \ %\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-Sqrt[pol[1, x]/u]\)}], {x, \ \((2 - u)\)/u, 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u, 1.1, 3.2,  .3}]\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(Show[{%, bsp1upl}, Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[166]:="],

Cell[BoxData[
    \(bsp1u = %\)], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \(Export["\<bsp1u.eps\>", bsp1u]\)], "Input",
  CellLabel->"In[168]:="],

Cell["\<\
The picture shows the quadrics with eigenvalues v = 1, u = 1.1, 1.4,...,3.2. \
For u to infinity the quadfrics tend to the double counting x-axis.\
\>", "Text"],

Cell["Let now be v=1, and u <0 . For u = -1 we have to consider", "Text"],

Cell[BoxData[
    \(Plot[\(-pol[1, x]\), \ {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[169]:="],

Cell["\<\
Also, for any u<0 and v 01 there don't exist real solutions within the \
hyperbolic plane.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The case v>1", "Subsubsection"],

Cell["For all u>0 the radicand is positive for -1<x<1:", "Text"],

Cell[BoxData[
    \(Plot[pol[5, x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(Solve[pol[v, x]/u\  + x^2 \[Equal] \ 1, x]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(infpt[u_, v_] := \ \((1 - u + v)\)/\((1 + u - v)\)\)], "Input",
  CellLabel->"In[44]:=",
  InitializationCell->True],

Cell[BoxData[
    \(D[pol[v, x]/u\  + x^2, x]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Simplify[% /. \ x \[Rule] 1]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(der1[u_, v_]\  := \ 2 \((u - v)\)/u\)], "Input",
  CellLabel->"In[45]:=",
  InitializationCell->True],

Cell["\<\
To get hyperbolic points for x<1 this derivative must be positive, what means \
u>v, e.g\
\>", "Text"],

Cell[BoxData[
    \(Plot[pol[5, x]/10\  + x^2, {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    RowBox[{"ParametricPlot", "[", 
      RowBox[{
        RowBox[{"euklein", "[", 
          RowBox[{"{", 
            RowBox[{"x", ",", " ", 
              RowBox[{"Sqrt", "[", 
                RowBox[{\(pol[5, x]/10\), Cell[""]}], "]"}]}], "}"}], "]"}], 
        ",", \({x, \(-1\), 1}\)}], "]"}]], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[186]:="],

Cell[BoxData[
    RowBox[{"ParametricPlot", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"x", ",", " ", 
            RowBox[{"Sqrt", "[", 
              RowBox[{\(pol[5, x]/10\), Cell[""]}], "]"}]}], "}"}], 
        ",", \({x, \(-1\), 1}\)}], "]"}]], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    RowBox[{"ParametricPlot", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"x", ",", " ", 
            RowBox[{"Sqrt", "[", 
              RowBox[{\(pol[5, x]/4\), Cell[""]}], "]"}]}], "}"}], 
        ",", \({x, \(-1\), 1}\)}], "]"}]], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, Sqrt[pol[3, x]/u]}], {x, \ \((4 - u)\)/\((u - 2)\), 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u, 3.1, 8,  .7}]\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-Sqrt[pol[3, x]/u]\)}], {x, \ \((4 - u)\)/\((u - 2)\), 
          1}, AspectRatio\  \[Rule] \ Automatic], {u, 3.1, 
        8,  .7}]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(Show[{%, %%}, Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(q2pic2\  = \ %\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Export["\<q2pic2.eps\>", q2pic2]\)], "Input",
  CellLabel->"In[118]:="],

Cell["\<\
q2pic2 shows the family of quadrics of type 2.2 with v=3, u = 3.1, 3.8,  4.5, \
..., 8\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Other examples with v>1", "Subsubsection"],

Cell[BoxData[
    \(Table[
      ParametricPlot[euklein[{x, Sqrt[pol[u - 1, x]/u]}], {x, \ 0, 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u, 2.1, 16.1, 2}]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(Show[{%, klkr}]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, Sqrt[pol[v, x]/10]}], {x, \ \((v - 9)\)/\((11 - v)\), 1}, 
        AspectRatio\  \[Rule] \ Automatic], {v, 1.5, 9.5, 1}]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(Show[{%, klkr}]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-Sqrt[pol[v, x]/10]\)}], {x, \ \((v - 9)\)/\((11 - 
                v)\), 1}, AspectRatio\  \[Rule] \ Automatic], {v, 1.5, 9.5, 
        1}]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(Show[{%, %%}]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(Show[%, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(q2pic3 = %\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(Export["\<q2pic3.eps\>", q2pic3]\)], "Input",
  CellLabel->"In[131]:="],

Cell["\<\
q2pic3 shows the quadrics of type 2.2 with u = 10, v = 1.5, 2.5, ..., 9.5.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The case 0<v<1", "Subsubsection"],

Cell["For all u>0 the radicand is positive for -1<x<1:", "Text"],

Cell[BoxData[
    \(Plot[pol[ .5, x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(pol[v, x]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(Plot[\((1 + v)\)/\((1 - v)\), {v, 0,  .9}, \ 
      PlotRange\  \[Rule] \ {0, 20}]\)], "Input",
  CellLabel->"In[45]:="],

Cell["\<\
At any rate, for 0<v<1 and u>0 the radicand is positive; we get real \
solutions, and for 0<v<1 and  u<0 there don't exist real solutions. The \
question is wether there exist hyperbolic solution points. Remember\
\>", "Text"],

Cell[BoxData[
    \(infpt[u, v]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(der1[u, v]\)], "Input",
  CellLabel->"In[138]:="],

Cell["\<\
Again, we expect hyperbolic points only in case u>v; the case u=v will be \
considered later.  \
\>", "Text"],

Cell[BoxData[
    \(Plot[Sqrt[pol[ .5, x]/1.7], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(Plot[Sqrt[pol[ .8, x]/ .3], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[104]:="],

Cell["Therefore we get a family of solutions for u>v:", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, Sqrt[pol[ .2, x]/u]}], {x, \ infpt[u,  .2], 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u,  .3, 18.3, 2}]\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-Sqrt[pol[ .2, x]/u]\)}], {x, \ infpt[u,  .2], 1}, 
        AspectRatio\  \[Rule] \ Automatic], {u,  .3, 18.3, 2}]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(Show[{%, %%}, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(q2pic4 = %\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(Export["\<q2pic4.eps\>", q2pic4]\)], "Input",
  CellLabel->"In[154]:="],

Cell["\<\
q2pic4 shows the family of quadrics of type 2.2 with v=.2, u = .3, 2.3,  4.3, \
..., 18.3\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The case u = v", "Subsubsection"],

Cell[BoxData[
    \(infpt[v, v]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(der1[v, v]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(pol[v, x]/v\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(Plot[pol[ .3, x]/ .3, {x, \(-1\), 1.5}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(pol[ .3, 1.5]/0.3\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(Together[pol[v, x]/v]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(Solve[pol[v, x] \[Equal] \ 0, x]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Plot[Sqrt[pol[ .3, x]/ .3], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(infpt[ .3,  .3]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Plot[x^2\  + \ pol[ .3, x]/ .3, \ {x,  .7, 1.2}]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Simplify[x^2\  + \ pol[v, x]/v]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(D[x^2\  + \ pol[v, x]/v, x]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Solve[% \[Equal] \ 0, x]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[69]:="],

Cell["\<\
Looking at the sign of the coefficient 1/v of x^2 one sees that in case v<0 \
there exist hyperbolic solution points, e.g.\
\>", "Text"],

Cell[BoxData[
    \(Plot[x^2\  + \ pol[\(-1\), x]/\((\(-1\))\), {x, \(-1\), 1}]\)], "Input",\

  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Plot[pol[\(-1\), x]/\((\(-1\))\), {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Plot[x^2\  + \ pol[\(-3\), x]/\((\(-3\))\), {x, \(-1\), 1}]\)], "Input",\

  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Plot[pol[\(-3\), x]/\((\(-3\))\), {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[73]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The case v<0", "Subsubsection"],

Cell[BoxData[
    \(Simplify[pol[v, x]]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(Solve[pol[v, x] \[Equal] \ 0, x]\)], "Input",
  CellLabel->"In[44]:="],

Cell["\<\
We recognize: for v<0 one has pol[v,x] <0 for (1+v)/(1-v)< x < 1, and \
pol[v,x]>0 for x< (1+v)/(1-v). Therefore we get solutions in the first case \
for u<0, and in the second case for u>0 \
\>", "Text"],

Cell[BoxData[
    \(Plot[\((1 + v)\)/\((1 - v)\), {v, \(-2\), 0}]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(Plot[pol[\(- .5\), x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(Plot[pol[\(-5\), x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[47]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The case v<0, u>0", "Subsubsection"],

Cell[BoxData[
    RowBox[{\(ParametricPlot[{x, \(qfct[\(- .3\)]\)[
            x]}, {x, \(-1\), \((1 -  .3)\)/\((1 +  .3)\)}]\), Cell[
      ""]}]], "Input",
  CellLabel->"In[44]:="],

Cell["\<\
The infinite points of the quadrics under consideration have the x-coordinate\
\
\>", "Text"],

Cell[BoxData[
    \(infpt[u, v]\)], "Input",
  CellLabel->"In[58]:="],

Cell["For simplicity, take u = 1.  We obtain a family", "Text"],

Cell[BoxData[
    RowBox[{\(Table[
        ParametricPlot[
          euklein[{x, \(qfct[\(-v\)]\)[x]}], {x, 
            infpt[1, \(-v\)], \((1 - v)\)/\((1 + v)\)}], \ {v, 0.1, 8.1, 
          1}]\), Cell[""]}]], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    RowBox[{\(Table[
        ParametricPlot[
          euklein[{x, \(-\(qfct[\(-v\)]\)[x]\)}], {x, 
            infpt[1, \(-v\)], \((1 - v)\)/\((1 + v)\)}], \ {v, 0.1, 8.1, 
          1}]\), Cell[""]}]], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Show[{%%, %}, Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(q2pic5 = %\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Export["\<q2pic5.eps\>", q2pic5]\)], "Input",
  CellLabel->"In[70]:="],

Cell["\<\
q2pic5 shows the family of quadrics of type 2.2 with  u = 1, v= -.1,-1.1, \
-2.1, ...,-8.1\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(Table[
        ParametricPlot[
          euklein[{x, \(qfct[\(-v\)]\)[x]}], {x, 
            infpt[1, \(-v\)], \((1 - v)\)/\((1 + v)\)}], \ {v, 0, \ 
          2,  .2}]\), Cell[""]}]], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Show[{%, klkr}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    RowBox[{\(Table[
        ParametricPlot[
          euklein[{x, \(-\(qfct[\(-v\)]\)[x]\)}], {x, 
            infpt[1, \(-v\)], \((1 - v)\)/\((1 + v)\)}], \ {v, 0, \ 
          2,  .2}]\), Cell[""]}]], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(Show[{%%, %}, \ Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(q2pic6 = %\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(Export["\<q2pic6.eps\>", q2pic6]\)], "Input",
  CellLabel->"In[86]:="],

Cell["\<\
q2pic6 shows the family of quadrics of type 2.2 with  u = 1, v=0,  -0.2, \
-0.4, -0.6, ...,-2. For v=0 the quadric degenerates into a pair of parallel \
lines.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random test", "Subsubsection"],

Cell["\<\
Statement. For all u<0, v<0 we get a real (half-)quadric by (Hint. Use \
arbitrary positive factors in the definitions of u,v!)\
\>", "Text"],

Cell[BoxData[
    \(u = 10*\ Random[]; v = \ 2*\ Random[]; Print[u, "\<;\>", v]; 
    graph = ParametricPlot[
        euklein[{x, \(qfct[\(-v\), u]\)[x]}], {x, 
          infpt[u, \(-v\)], \((1 - v)\)/\((1 + v)\)}]; 
    Show[{graph, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
Special statement. For all u>0, v=0 we get a real line by (Hint. Use \
arbitrary positive factors in the definitions of u!  Remember: In the Klein \
picture, a line is a circle arc intersecting the unit circle orthogonally.)\
\>", "Text"],

Cell[BoxData[
    \(u = 10*\ Random[]; v = \ 0; Print[u, "\<;\>", v]; 
    graph = ParametricPlot[
        euklein[{x, \(qfct[\(-v\), u]\)[x]}], {x, 
          infpt[u, \(-v\)], \((1 - v)\)/\((1 + v)\)}]; 
    Show[{graph, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(Clear[u, v, graph]\)], "Input",
  CellLabel->"In[99]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The case v<0, u<0", "Subsubsection"],

Cell[BoxData[
    \(Plot[\(qfct[\(-3\), \(-1\)]\)[x], {x, \((1 - 3)\)/\((1 + 3)\), 
        1}]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(\(\(Show[{%, \ klkr}, 
      AspectRatio\  \[Rule] \ Automatic]\)\(\ \)\)\)], "Input",
  CellLabel->"In[82]:="],

Cell["In case u>v , u<0, we have", "Text"],

Cell[BoxData[
    \(der1[u, v] < 0\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(der1[\(-1\), \(-3\)]\)], "Input",
  CellLabel->"In[84]:="],

Cell["\<\
the quadric lies outside the unit disk in the neighbourhood of (1,0).  As we \
see, there exist another part of th quadric belonging to the unit disk.\
\>", "Text"],

Cell[BoxData[
    \(Plot[\(qfct[\(-3\), \(-1\)]\)[x], {x, \((1 - 3)\)/\((1 + 3)\), 
        infpt[\(-1\), \(-3\)]}]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(\(\(Show[{%, \ klkr}, 
      AspectRatio\  \[Rule] \ Automatic]\)\(\ \)\)\)], "Input",
  CellLabel->"In[86]:="],

Cell["Now we consider an example with 0>u>v:", "Text"],

Cell[BoxData[
    \(Plot[\(qfct[\(- .3\), \(-1\)]\)[x], {x, \((1 -  .3)\)/\((1 +  .3)\), 
        1}]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(\(\(Show[{%, \ klkr}, 
      AspectRatio\  \[Rule] \ Automatic]\)\(\ \)\)\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(ParametricPlot[
      euklein[{x, \(qfct[\(- .3\), \(-1\)]\)[
            x]}], {x, \((1 -  .3)\)/\((1 +  .3)\), 1}]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(\(\(Show[{%, \ klkr}, 
      AspectRatio\  \[Rule] \ Automatic]\)\(\ \)\)\)], "Input",
  CellLabel->"In[90]:="],

Cell["\<\
We have to distinguish three cases:
0>u>v
0>v>u
0>v=u\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 0>u>v", "Subsubsection"],

Cell["Random Test:", "Text"],

Cell[BoxData[{
    \(v =  .1*Random[]; \ u\  = \ v*\((\(-1\) + Random[])\); \ 
    Print[u, \ "\<:\>", v];\), "\[IndentingNewLine]", 
    \(graph = 
      ParametricPlot[
        euklein[{x, \(qfct[\(-v\), u]\)[x]}], {x, \((1 - v)\)/\((1 + v)\), 
          infpt[u, \(-v\)]}]; 
    Show[{graph, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)}], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Clear[u, v, graph]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(qfct[\(-10\), \(-u\)]\)[
              x]}], {x, \((1 - 10)\)/\((1 + 10)\), 
          infpt[\(-u\), \(-10\)]}], {u, 1, 9}]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-\(qfct[\(-10\), \(-u\)]\)[x]\)}], {x, \((1 - 
                10)\)/\((1 + 10)\), infpt[\(-u\), \(-10\)]}], {u, 1, 
        9}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Show[{%, %%}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(\(\(Show[%, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False, 
      PlotRange\  \[Rule] \ All]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(pictuv1 = \ %\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Export["\<pictuv1.eps\>", pictuv1]\)], "Input",
  CellLabel->"In[72]:="],

Cell["\<\
pictuv1 shows the family of quadrics of type 2.2 with  u = -1,-2,...,-9, v = \
-10.\
\>", "Text"],

Cell[BoxData[
    \(\(?qfct\)\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(qfct[\(-v\), \(-v\) + 1]\)[
              x]}], {x, \((1 - v)\)/\((1 + v)\), 
          infpt[\(-v\) + 1, \(-v\)]}], {v, 2, 11}]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-\(qfct[\(-v\), \(-v\) + 1]\)[x]\)}], {x, \((1 - 
                v)\)/\((1 + v)\), infpt[\(-v\) + 1, \(-v\)]}], {v, 2, 
        11}]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(\(\(Show[{%%, %}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False, 
      PlotRange\  \[Rule] \ All]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(pictuv2\  = \ %\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Export["\<pictuv2.eps\>", pictuv2]\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
pictuv1 shows the family of quadrics of type 2.2 with  v = -2,...,-11, u = \
v+1.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 0>v>u", "Subsubsection"],

Cell["Random Test:", "Text"],

Cell[BoxData[{
    \(v = 10*Random[]; \ u\  = \ v*\((\(-1\) - Random[])\); \ 
    Print[u, \ "\<:\>", v];\), "\[IndentingNewLine]", 
    \(graph = 
      ParametricPlot[
        euklein[{x, \(qfct[\(-v\), u]\)[x]}], {x, \((1 - v)\)/\((1 + v)\), 
          1}]; Show[{graph, klkr}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)}], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(Clear[u, v, graph]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(qfct[\(-10\), \(-u\)]\)[
              x]}], {x, \((1 - 10)\)/\((1 + 10)\), 1}], {u, 11, 
        19}]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-\(qfct[\(-10\), \(-u\)]\)[x]\)}], {x, \((1 - 
                10)\)/\((1 + 10)\), 1}], {u, 11, 19}]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(\(\(Show[{%, %%}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False, 
      PlotRange\  \[Rule] \ All]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(pictvu1 = \ %\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(Export["\<pictvu1.eps\>", pictvu1]\)], "Input",
  CellLabel->"In[103]:="],

Cell["\<\
pictvu1 shows the family of quadrics of type 2.2 with  u = -11,-2,...,-19, v \
= -10.\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(qfct[\(-v\), \(-v\) - 1]\)[
              x]}], {x, \((1 - v)\)/\((1 + v)\), 1}], {v, 1, 11}]\)], "Input",\

  CellLabel->"In[104]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-\(qfct[\(-v\), \(-v\) - 1]\)[x]\)}], {x, \((1 - 
                v)\)/\((1 + v)\), 1}], {v, 1, 11}]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(\(\(Show[{%%, %}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False, 
      PlotRange\  \[Rule] \ All]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(pictvu2\  = \ %\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(Export["\<pictvu2.eps\>", pictvu2]\)], "Input",
  CellLabel->"In[109]:="],

Cell["\<\
pictuv1 shows the family of quadrics of type 2.2 with  v = -1...,-11, u = \
v-1.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 0>v=u", "Subsubsection"],

Cell[BoxData[
    \(Simplify[eqmi[\(-v\), \(-v\)]]\)], "Input",
  CellLabel->"In[130]:="],

Cell["Random Test:", "Text"],

Cell[BoxData[{
    \(v = 2*Random[]; \ \ Print[v];\), "\[IndentingNewLine]", 
    \(graph = 
      ParametricPlot[
        euklein[{x, \(qfct[\(-v\), \(-v\)]\)[
              x]}], {x, \((1 - v)\)/\((1 + v)\), 1}]; 
    Show[{graph, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)}], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    \(Clear[u, v, graph]\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(qfct[\(-u\), \(-u\)]\)[
              x]}], {x, \((1 - u)\)/\((1 + u)\), 1}], {u, 1, 10}]\)], "Input",\

  CellLabel->"In[123]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(Table[
      ParametricPlot[
        euklein[{x, \(-\(qfct[\(-u\), \(-u\)]\)[x]\)}], {x, \((1 - 
                u)\)/\((1 + u)\), 1}], {u, 1, 10}]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(\(\(Show[{%, %%}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] \ False, 
      PlotRange\  \[Rule] \ All]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(pictory = \ %\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(Export["\<pictory.eps\>", pictory]\)], "Input",
  CellLabel->"In[128]:="],

Cell["\<\
pictory shows the family of quadrics of type 2.2 with  u = v = -1, -2,...,  \
-10. For u = v = -1 we see the horocycle.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.7 Quadrics in the non-euclidean plane whose associated operator has a pair \
of complex conjugated eigenvalues\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["4.7.1 The normal form of the operator", "Subsubsection"],

Cell["\<\
The general symmetric operator having one real eigenvalue w with a spacelike \
eigenvector taken as stb[3] and two other (may be complex) eigenvalues has \
the form \
\>", "Text"],

Cell[BoxData[
    \(opcomp = {{a, b, 0}, {c, d, 0}, {0, 0, w}}\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[177]:="],

Cell["\<\
(invariance of the orthogonal complement of stb[3]). The corresponding \
bilinear form is\
\>", "Text"],

Cell[BoxData[
    \(blf[opcomp]\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[179]:="],

Cell["Symmetry condition is c = -b. Set", "Text"],

Cell[BoxData[
    \(ac1 = {a, b, 0}; ac2 = {\(-b\), d, 0}\)], "Input",
  CellLabel->"In[180]:="],

Cell[BoxData[
    \(opcomp\  = \ {ac1, ac2, w*stb[3]}\)], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \(ev1\  = \ %[\([1]\)]\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(ev2\  = \ %%[\([2]\)]\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(Simplify[vec[x] . blf[opcomp] . vec[x]]\)], "Input",
  CellLabel->"In[186]:="],

Cell["\<\
We norm the equation of the quadric requiring w = 1.  Specialize\
\>", "Text"],

Cell[BoxData[
    \(opcomp\  = \ {ac1, ac2, stb[3]}\)], "Input",
  CellLabel->"In[187]:="],

Cell["\<\
Now we want to find those values of a,b,d for which ac1  + I*ac2 is a complex \
eigenvector with the eigenvalue ev2. To this aim we solve\
\>", "Text"],

Cell[BoxData[
    \(Solve[
      opcomp . \((ac1\  + \ I*ac2)\) \[Equal] \ \((ac1\  + \ I*ac2)\)*
          ev2, {a, b, d}]\)], "Input",
  CellLabel->"In[188]:="],

Cell["\<\
Since a, b must be real,  and the operator is not degenerate,  the only \
solution of interest is a=d. We set\
\>", "Text"],

Cell[BoxData[
    \(opc[a_, b_]\  := {{a, b, 0}, {\(-b\), a, 0}, {0, 0, 1}}\)], "Input",
  CellLabel->"In[46]:=",
  InitializationCell->True],

Cell[BoxData[
    \(opc[a, b] // MatrixForm\)], "Input",
  CellLabel->"In[190]:="],

Cell["Control:", "Text"],

Cell[BoxData[
    \(Eigensystem[opc[a, b]]\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(ac1 = {a, b, 0}; ac2 = {\(-b\), a, 0}\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(Simplify[
      opc[a, b] . \((ac1\  + \ I*ac2)\)\  \[Equal] \ \((ac1\  + \ 
              I*ac2)\)*\((a + \[ImaginaryI]\ b)\)]\)], "Input",
  CellLabel->"In[193]:="],

Cell[BoxData[
    \(Simplify[
      opc[a, b] . \((ac1\  - \ I*ac2)\)\  \[Equal] \ \((ac1\  - \ 
              I*ac2)\)*\((a - \[ImaginaryI]\ b)\)]\)], "Input",
  CellLabel->"In[194]:="],

Cell[BoxData[
    \(pssp[ac1, ac1] + pssp[ac2, ac2]\)], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    \(pssp[ac1, ac2]\)], "Input",
  CellLabel->"In[196]:="],

Cell[BoxData[
    \(pssp[ac1, ac1]\)], "Input",
  CellLabel->"In[197]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["4.7.2 The corresponding symmetric bilinear form", "Subsubsection"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[198]:="],

Cell[BoxData[
    \(blf[opc[a, b]]\)], "Input",
  CellLabel->"In[199]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[200]:="],

Cell[BoxData[
    \(vec[x] . %% . vec[x]\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[202]:="],

Cell[BoxData[
    \(vec[x] . blf[opc[a, b]] . vec[x] /. \ {x[1]\  \[Rule] 1, 
        x[2]\  \[Rule] \ x, \ x[3]\  \[Rule] \ y}\)], "Input",
  CellLabel->"In[203]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[204]:="],

Cell["eqc[a_, b_] := -2*b*x + a*(-1 + x^2) + y^2", "Input",
  CellLabel->"In[205]:="],

Cell[BoxData[
    \(\(polqc[a_, b_]\)[x_]\  := \ 2*b*x\  + \ a*\((1 - x^2)\)\)], "Input",
  CellLabel->"In[47]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[\(polqc[a, b]\)[x]]\)], "Input",
  CellLabel->"In[207]:="],

Cell[BoxData[
    \(Plot[x^2 + \(polqc[1, 5]\)[x], {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[208]:="],

Cell[BoxData[
    \(x^2\  + \(polqc[1, b]\)[x] /. \ x \[Rule] \ 0\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(\(polqc[1, b]\)[0]\)], "Input",
  CellLabel->"In[87]:="],

Cell["\<\
Real points correspond to the regions where polqc[a,b][x] \[GreaterEqual] 0. \
For all a \[NotEqual] 0 we get two distinct real roots\
\>", "Text"],

Cell[BoxData[
    \(Solve[\(polqc[a, b]\)[x] \[Equal] \ 0, x]\)], "Input",
  CellLabel->"In[88]:="],

Cell["The zeroes of polqc are", "Text"],

Cell["reqcmi[a_, b_] := (b - Sqrt[a^2 + b^2])/a", "Input",
  CellLabel->"In[48]:=",
  InitializationCell->True],

Cell["reqcpl[a_, b_] := (b + Sqrt[a^2 + b^2])/a", "Input",
  CellLabel->"In[49]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Plot[{reqcmi[ .5, b], reqcpl[ .5, b]}, {b, \(-2\), 2}]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(reqcmi[a, 0]\)], "Input",
  CellLabel->"In[92]:="],

Cell["\<\
For a>0 we have reqcmi[ab]< reqcpl[a,b], and for a <0 the converse \
reqcpl[a,b]<reqcmi[a,b]. The hyperbolic points of the quadric must fulfil the \
following conditions:
a)  -1<x<1.
b)  polqc[a,b][x]\[GreaterEqual]0.
c) The following function must be less 1.\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b]; \(dist[a_, b_]\)[x_]\  := 
      x^2\  + \ \(polqc[a, b]\)[x]\)], "Input",
  CellLabel->"In[50]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[\(dist[a, b]\)[x]]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(Series[%, {x, 0, 2}]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(Normal[%]\)], "Input",
  CellLabel->"In[96]:="],

Cell["We also need the derivative of this function.", "Text"],

Cell[BoxData[
    \(D[\(dist[a, b]\)[x], x]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(\(derqc[a_, b_]\)[x_]\  := \ b + x*\((1 - a)\)\)], "Input",
  CellLabel->"In[51]:=",
  InitializationCell->True],

Cell["\<\
The infinite points of the corresponding quadric are  solutions of\
\>", "Text"],

Cell[BoxData[
    \(Solve[\(dist[a, b]\)[x] \[Equal] \ 1, \ x]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[100]:="],

Cell["infqcmi[a_, b_] := (b - Sqrt[1 - 2*a + a^2 + b^2])/(-1 + a)", "Input",
  CellLabel->"In[52]:=",
  InitializationCell->True],

Cell["infqcpl[a_, b_] := (b + Sqrt[1 - 2*a + a^2 + b^2])/(-1 + a)", "Input",
  CellLabel->"In[53]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Limit[infqcpl[a, b], \ a \[Rule] \ 1]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(Plot[infqcpl[a, 2], {a, 0, 2}]\)], "Input",
  CellLabel->"In[104]:="],

Cell["\<\
Obviously, the case a= 1 has to be treated especially. The only infinite \
point of the curve is given by x=0:\
\>", "Text"],

Cell[BoxData[
    \(Solve[x^2\  + \ \(polqc[1, b]\)[x]\  \[Equal] \ 1, x]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(Plot[x^2\  + \ \(polqc[1, 3]\)[x], {x, \ \(-1\), 1}]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(x^2\  + \ \(polqc[1, b]\)[x]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(infmin[a_, b_] := 
      Min[{\((b - Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\), \((b + 
                Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\)}]\)], "Input",
  CellLabel->"In[54]:=",
  InitializationCell->True],

Cell[BoxData[
    \(infmax[a_, b_] := 
      Max[{\((b - Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\), \((b + 
                Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\)}]\)], "Input",
  CellLabel->"In[55]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Clear[qc, a, b, c, d]\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(\((b + Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\) - \((b - 
            Sqrt[1 - 2*a + a^2 + b^2])\)/\((\(-1\) + a)\)\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[112]:="],

Cell["\<\
Obviously, the difference of the two roots is greater or equal two, therefore \
only one of these entiiies may belong to the interval [-1,1].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.7.3 The module qc plotting the quadric", "Subsubsection"],

Cell[BoxData[
    \(Clear[a, b, qc]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(\(\(qc[a_, b_, 
        opt___]\)\(\ \)\(:=\)\(\ \)\(Module[{x0\  = \ \(-1\), \ x1\  = \ 1, 
          gr = {}, gr1, gr2, hr, c, d}, \[IndentingNewLine]If[
          Not[NumberQ[a]] || Not[NumberQ[b]], 
          Print[a, "\<, \>", \ b, \ "\< must be numbers!\>"]; 
          Return[]]; \[IndentingNewLine]If[a \[Equal] \ 0 && b == \ 0, \ 
          Print["\<Invalid arguments a = b = 0!\>"]; \ 
          Return[]]; \[IndentingNewLine]If\ [a \[Equal] \ 0, 
          x0\  = \ \(-b\) + Sign[b]*Sqrt[1 + b^2]; \ x1\  = \ 0; 
          Goto[fin]]; \[IndentingNewLine]If[
          a \[Equal] \ 1 && \ b \[Equal] \ 0, \ 
          Print["\<The quadric is the Infinity.\>"]; 
          Return[]]; \[IndentingNewLine]If[a \[Equal] \ 1\  && \ b > 0, \ 
          x0\  = \ reqcmi[1, b]; x1\  = \ 0; 
          Goto[fin]]; \[IndentingNewLine]If[a \[Equal] \ 1\  && \ b < 0, \ 
          x0\  = \ 0; \ x1\  = \ reqcpl[1, b];; 
          Goto[fin]]; \[IndentingNewLine]c = 
          infmin[a, b]; \[IndentingNewLine]d = \ 
          infmax[a, b]; \[IndentingNewLine]Print["\<c= \>", c]; 
        Print["\<d= \>", d]; \[IndentingNewLine]If[a < 0, \ 
          Goto[min]]; \[IndentingNewLine]If[b \[Equal] \ 0 && \ a < 1, \ 
          x0\  = \(-1\); x1\  = \ 1; Goto[fin]]; \[IndentingNewLine]If[
          b \[Equal] \ 0 && \ a > 1, Print["\<No real quadric!\>"]; 
          Return[]]; \[IndentingNewLine]x0\  = 
          Max[{\(-1\), \ reqcmi[a, b]}]; \[IndentingNewLine]x1\  = \ 
          Min[{1, \ reqcpl[a, b]}]; \[IndentingNewLine]If[
          c \[GreaterEqual] \ x0\  && 
            c < x1\  && \ \(derqc[a, b]\)[c] \[LessEqual] 0, \ x0\  = \ c]; 
        Print["\<x0 = \>", x0]; \[IndentingNewLine]If[
          c \[GreaterEqual] \ x0\  && c < x1\  && \ \(derqc[a, b]\)[c] > 0, \ 
          x1\  = \ c]; 
        Print["\<x1 = \>", x1]; \[IndentingNewLine]If[
          d \[GreaterEqual] \ x0\  && 
            d < x1\  && \ \(derqc[a, b]\)[d] \[LessEqual] 0, \ x0\  = \ d]; 
        Print["\<x0 = \>", x0]; \[IndentingNewLine]If[
          d \[GreaterEqual] \ x0\  && d < x1\  && \ \(derqc[a, b]\)[d] > 0, \ 
          x1\  = \ d]; 
        Print["\<x1 = \>", x1]; \[IndentingNewLine]Goto[
          fin]; \[IndentingNewLine]Label[min]; \[IndentingNewLine]If[
          reqcpl[a, b] \[GreaterEqual] \ 1 || 
            reqcmi[a, b] \[LessEqual] \ \ \(-1\) || b \[Equal] \ 0, 
          Print["\<No real quadric!\>"]; Return[]]; \[IndentingNewLine]If[
          c \[GreaterEqual] \ \(-1\) && \ 
            c \[LessEqual] \ 1 && \(polqc[a, b]\)[c] \[GreaterEqual] \ 0, \ 
          x0 = c; \ x1\  = \ Min[{1, reqcpl[a, b]}]; 
          Goto[fin]]; \[IndentingNewLine]If[
          d \[GreaterEqual] \(-1\) && 
            d \[LessEqual] 1 && \(polqc[a, b]\)[d] \[GreaterEqual] \ 0, 
          x0 = Max[{\(-1\), reqcmi[a, b]}]; x1\  = \ d; 
          Goto[fin]]; \[IndentingNewLine]Print["\<Hallo!\>"]; \
\[IndentingNewLine]Return[]; \[IndentingNewLine]Label[
          fin]; \[IndentingNewLine]Print["\<x0 = \>", 
          x0]; \[IndentingNewLine]Print["\<x1 = \>", 
          x1]; \[IndentingNewLine]gr1\  = \ 
          ParametricPlot[euklein[{x, Sqrt[\(polqc[a, b]\)[x]]}], {x, x0, x1}, 
            PlotRange\  \[Rule] \ All]; \[IndentingNewLine]gr2\  = \ 
          ParametricPlot[
            euklein[{x, \(-Sqrt[\(polqc[a, b]\)[x]]\)}], {x, x0, x1}, 
            PlotRange\  \[Rule] \ All]; \[IndentingNewLine]hr\  = 
          Show[{gr1, gr2}]; \[IndentingNewLine]AppendTo[gr, 
          hr]; \[IndentingNewLine]Show[{gr, klkr}, \ 
          opt]]\)\(\ \)\)\)], "Input",
  CellLabel->"In[56]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["4.7.4 Tests", "Subsubsection"],

Cell[BoxData[
    \(qc[20, \(-10\), AspectRatio\  \[Rule] \ Automatic, 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(Table[
      qc[2^i, \((\(-1\))\)^i*N[Sqrt[i]], AspectRatio\  \[Rule] \ Automatic, 
        Axes\  \[Rule] \ False], {i, 1, 10}]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(grqc1\  = \ %\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(Table[
      qc[2^i, \((\(-1\))\)^\((i - 1)\)*N[Sqrt[i]], 
        AspectRatio\  \[Rule] \ Automatic, Axes\  \[Rule] \ False], {i, 1, 
        10}]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(grqc2\  = \ %\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(Show[{grqc1, grqc2}]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(grqc\  = \ %\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(Export["\<grqc.eps\>", grqc]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \(Table[{2^i, \((\(-1\))\)^i*Sqrt[i]}, {i, 1, 10}]\)], "Input",
  CellLabel->"In[175]:="],

Cell["\<\
The figure qrc shows the quadrics qc{a,b) with (a,b) = ( 2^j,  \
\[PlusMinus]Sqrt[j]), j = 1,...,10. The eigenvalues are 2^j  \
\[PlusMinus]Sqrt[j]*\[ImaginaryI].\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(ParametricPlot[
      euklein[{x, Sqrt[\(polqc[\(-1\), 10]\)[x]]}], {x, \(-1\), 1}, 
      PlotRange\  \[Rule] \ All]\)\)\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(Show[{%, klkr}, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[228]:="],

Cell[BoxData[
    \(Table[
      qc[N[Re[Exp[\(-Pi\)*I*\((j/10)\)]]], N[Im[Exp[\(-Pi\)*I*\((j/10)\)]]], 
        AspectRatio\  \[Rule] \ Automatic, Axes\  \[Rule] \ False], {j, 1, 
        9}]\)], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[251]:="],

Cell[BoxData[
    \(grt1\  = \ %\)], "Input",
  CellLabel->"In[252]:="],

Cell[BoxData[
    \(Table[
      qc[N[Re[Exp[Pi*I*\((j/10)\)]]], N[Im[Exp[Pi*I*\((j/10)\)]]], 
        AspectRatio\  \[Rule] \ Automatic, Axes\  \[Rule] \ False], {j, 1, 
        9}]\)], "Input",
  CellLabel->"In[253]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[254]:="],

Cell[BoxData[
    \(grt2\  = \ %\)], "Input",
  CellLabel->"In[255]:="],

Cell[BoxData[
    \(Show[{grt1, grt2}]\)], "Input",
  CellLabel->"In[256]:="],

Cell[BoxData[
    \(grabs1\  = \ %\)], "Input",
  CellLabel->"In[257]:="],

Cell[BoxData[
    \(Export["\<grabs1.eps\>", grabs1]\)], "Input",
  CellLabel->"In[258]:="],

Cell["\<\
The figure grabs1.eps shows the quadrics qc[a,b] wit a+\[ImaginaryI]b = \
Exp[2Pi \[ImaginaryI] j/10), j = \[PlusMinus]1,..., \[PlusMinus]9.\
\>", "Text"],

Cell["Random test:", "Text"],

Cell[BoxData[
    \(a = \ \(-100\)*Random[]; \ b = \ 20*Random[]; \ Print[a + I*b]; 
    qc[a, b, AspectRatio\  \[Rule] \ Automatic, 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \(qc[a, \(-b\), AspectRatio\  \[Rule] \ Automatic, 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[224]:="],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[231]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Thanks", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
to Michael Trott from Wolfram Research Inc. for his hints to two mistakes, \
which are corrected now.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
[1] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092\
\>", "Text",
  CellTags->"S1"],

Cell["\<\
[2] Oniscik, A. and  R. Sulanke.Projective and Cayley-Klein Geometries.  \
2005.  (in German on the second authors homepage)\
\>", "Text",
  CellTags->{"S1", "[2]"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's address", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke
e-Mail:\
\>", "Text"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"RulerBar",
WindowSize->{1218, 1112},
WindowMargins->{{Automatic, 172}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rolf", "mymath", \
"spheres.v3"}, "pseuklid.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
SpellingDictionaries->{"CorrectWords"->{
  "orthonormalization", "orthonorm", "Erhard", "parameterfree", "nul"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the Notebook level. \
 \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{5, Inherited}, {2, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 13},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 10}, {2, 0}},
    FontSize->28,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 4}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 8}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{8, 4}, {2, 50}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0, 0, 1],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Section", "Printout"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{6, 4}, {2, 70}},
    CellFrameColor->GrayLevel[0],
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 5},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{19, 4}, {2, 18}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{7, 4}, {2, 18}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{7, 0}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{3, 0}, {0, 0.5}},
    CellMargins->{{47, 14}, {0, 14}},
    CellFrameColor->RGBColor[0, 0, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 54}, {0, 14}},
    CellFrameColor->GrayLevel[0],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.    \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{54, 14}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 4}, {8, 3}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    FontSize->14],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{42, 4}, {3, 8}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{26, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-19,
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    ParagraphIndent->-14,
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{45, 4}, {0, 5}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 5},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{34, 4}, {0, 4}},
    ParagraphSpacing->{0, 4},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{26, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0, 0, 1],
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{7, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{7, 50}, {2, 4}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontSize->14,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{7, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Euklid"->{
    Cell[8919, 270, 670, 17, 104, "Text",
      CellTags->"Euklid"]},
  "S1"->{
    Cell[163664, 6146, 140, 4, 27, "Text",
      CellTags->"S1"],
    Cell[163807, 6152, 175, 4, 27, "Text",
      CellTags->{"S1", "[2]"}]},
  "[2]"->{
    Cell[163807, 6152, 175, 4, 27, "Text",
      CellTags->{"S1", "[2]"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Euklid", 192664, 7085},
  {"S1", 192744, 7088},
  {"[2]", 192897, 7093}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 80, 2, 74, "Title"],
Cell[1859, 57, 149, 4, 32, "Subtitle",
  Evaluatable->False],
Cell[2011, 63, 145, 5, 29, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2181, 72, 144, 4, 36, "Subsubsection",
  Evaluatable->False],
Cell[2328, 78, 1055, 17, 134, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3420, 100, 32, 0, 36, "Subsubsection"],
Cell[3455, 102, 200, 6, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3692, 113, 33, 0, 30, "Subsubsection"],
Cell[3728, 115, 357, 7, 58, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4122, 127, 34, 0, 30, "Subsubsection"],
Cell[4159, 129, 553, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4749, 142, 59, 1, 39, "Subsection"],
Cell[4811, 145, 302, 5, 46, "Text"],
Cell[5116, 152, 183, 4, 32, "Input"],
Cell[5302, 158, 30, 0, 27, "Text"],
Cell[5335, 160, 145, 4, 32, "Input",
  InitializationCell->True],
Cell[5483, 166, 156, 3, 31, "Text"],
Cell[5642, 171, 128, 4, 32, "Input",
  InitializationCell->True],
Cell[5773, 177, 97, 2, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5907, 184, 54, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[5986, 188, 45, 0, 45, "Subsection"],
Cell[6034, 190, 361, 8, 50, "Text",
  Evaluatable->False],
Cell[6398, 200, 122, 4, 29, "Input",
  InitializationCell->True],
Cell[6523, 206, 717, 13, 137, "Text"],
Cell[7243, 221, 127, 3, 30, "Input",
  InitializationCell->True],
Cell[7373, 226, 174, 4, 30, "Input",
  InitializationCell->True],
Cell[7550, 232, 206, 4, 30, "Input",
  InitializationCell->True],
Cell[7759, 238, 100, 3, 30, "Input",
  InitializationCell->True],
Cell[7862, 243, 549, 11, 71, "Text",
  Evaluatable->False],
Cell[8414, 256, 291, 5, 46, "Text"],
Cell[8708, 263, 208, 5, 51, "Input",
  InitializationCell->True],
Cell[8919, 270, 670, 17, 104, "Text",
  CellTags->"Euklid"],
Cell[9592, 289, 70, 2, 30, "Input"],
Cell[9665, 293, 73, 2, 30, "Input"],
Cell[9741, 297, 89, 2, 30, "Input"],
Cell[9833, 301, 77, 2, 30, "Input"],
Cell[9913, 305, 73, 2, 30, "Input"],
Cell[9989, 309, 73, 2, 30, "Input"],
Cell[10065, 313, 73, 2, 30, "Input"],
Cell[10141, 317, 119, 3, 27, "Text"],
Cell[10263, 322, 173, 4, 30, "Input",
  InitializationCell->True],
Cell[10439, 328, 98, 3, 30, "Input",
  InitializationCell->True],
Cell[10540, 333, 371, 6, 46, "Text"],
Cell[10914, 341, 195, 5, 30, "Input",
  InitializationCell->True],
Cell[11112, 348, 133, 3, 30, "Input"],
Cell[11248, 353, 110, 2, 30, "Input"],
Cell[11361, 357, 146, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11544, 365, 36, 0, 45, "Subsection"],
Cell[11583, 367, 347, 7, 46, "Text"],
Cell[11933, 376, 102, 3, 29, "Text"],
Cell[12038, 381, 110, 4, 29, "Input",
  InitializationCell->True],
Cell[12151, 387, 107, 3, 27, "Text"],
Cell[12261, 392, 91, 3, 30, "Input",
  InitializationCell->True],
Cell[12355, 397, 37, 0, 27, "Text"],
Cell[12395, 399, 111, 3, 30, "Input",
  InitializationCell->True],
Cell[12509, 404, 85, 2, 27, "Text"],
Cell[12597, 408, 160, 4, 30, "Input",
  InitializationCell->True],
Cell[12760, 414, 70, 0, 27, "Text"],
Cell[12833, 416, 67, 2, 30, "Input"],
Cell[12903, 420, 145, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[13073, 427, 67, 1, 36, "Subsubsection"],
Cell[13143, 430, 67, 0, 27, "Text"],
Cell[13213, 432, 90, 3, 32, "Input"],
Cell[13306, 437, 89, 3, 32, "Input"],
Cell[13398, 442, 93, 3, 32, "Input"],
Cell[13494, 447, 89, 3, 32, "Input"],
Cell[13586, 452, 91, 3, 32, "Input"],
Cell[13680, 457, 93, 3, 32, "Input"],
Cell[13776, 462, 90, 3, 32, "Input"],
Cell[13869, 467, 91, 3, 32, "Input"],
Cell[13963, 472, 94, 3, 32, "Input"],
Cell[14060, 477, 97, 3, 32, "Input"],
Cell[14160, 482, 96, 3, 32, "Input"],
Cell[14259, 487, 89, 3, 32, "Input"],
Cell[14351, 492, 90, 3, 32, "Input"],
Cell[14444, 497, 105, 3, 32, "Input"],
Cell[14552, 502, 97, 3, 32, "Input"],
Cell[14652, 507, 95, 3, 32, "Input"],
Cell[14750, 512, 101, 3, 32, "Input"],
Cell[14854, 517, 92, 3, 32, "Input"],
Cell[14949, 522, 91, 3, 32, "Input"],
Cell[15043, 527, 93, 3, 32, "Input"],
Cell[15139, 532, 92, 3, 32, "Input"],
Cell[15234, 537, 95, 3, 32, "Input"],
Cell[15332, 542, 72, 0, 27, "Text"],
Cell[15407, 544, 94, 3, 32, "Input"],
Cell[15504, 549, 92, 3, 32, "Input"],
Cell[15599, 554, 98, 3, 32, "Input"],
Cell[15700, 559, 95, 3, 32, "Input"],
Cell[15798, 564, 97, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15932, 572, 98, 2, 30, "Subsubsection"],
Cell[16033, 576, 66, 2, 30, "Input"],
Cell[16102, 580, 67, 2, 30, "Input"],
Cell[16172, 584, 67, 2, 30, "Input"],
Cell[16242, 588, 70, 2, 30, "Input"],
Cell[16315, 592, 70, 2, 30, "Input"],
Cell[16388, 596, 65, 2, 30, "Input"],
Cell[16456, 600, 65, 2, 30, "Input"],
Cell[16524, 604, 72, 2, 30, "Input"],
Cell[16599, 608, 76, 2, 30, "Input"],
Cell[16678, 612, 69, 2, 30, "Input"],
Cell[16750, 616, 69, 2, 30, "Input"],
Cell[16822, 620, 71, 2, 30, "Input"],
Cell[16896, 624, 72, 2, 30, "Input"],
Cell[16971, 628, 73, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17081, 635, 64, 1, 30, "Subsubsection"],
Cell[17148, 638, 128, 3, 27, "Text"],
Cell[17279, 643, 65, 2, 30, "Input"],
Cell[17347, 647, 92, 3, 32, "Input"],
Cell[17442, 652, 73, 2, 30, "Input"],
Cell[17518, 656, 72, 2, 30, "Input"],
Cell[17593, 660, 298, 6, 46, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17940, 672, 31, 0, 39, "Subsection"],
Cell[17974, 674, 135, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[18134, 681, 102, 2, 36, "Subsubsection"],
Cell[18239, 685, 140, 5, 27, "Text"],
Cell[18382, 692, 142, 3, 30, "Input",
  InitializationCell->True],
Cell[18527, 697, 165, 4, 27, "Text"],
Cell[18695, 703, 260, 6, 93, "Input",
  InitializationCell->True],
Cell[18958, 711, 81, 2, 30, "Input"],
Cell[19042, 715, 56, 0, 27, "Text"],
Cell[19101, 717, 85, 2, 30, "Input"],
Cell[19189, 721, 60, 0, 27, "Text"],
Cell[19252, 723, 86, 2, 30, "Input"],
Cell[19341, 727, 85, 2, 30, "Input"],
Cell[19429, 731, 126, 4, 27, "Text"],
Cell[19558, 737, 246, 6, 72, "Input",
  InitializationCell->True],
Cell[19807, 745, 74, 2, 30, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19942, 754, 130, 4, 60, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20097, 762, 101, 3, 41, "Subsection",
  Evaluatable->False],
Cell[20201, 767, 182, 6, 29, "Text",
  Evaluatable->False],
Cell[20386, 775, 94, 3, 49, "Input"],
Cell[20483, 780, 96, 3, 29, "Text",
  Evaluatable->False],
Cell[20582, 785, 220, 8, 29, "Input"],
Cell[20805, 795, 306, 8, 62, "Text",
  Evaluatable->False],
Cell[21114, 805, 160, 4, 30, "Input",
  InitializationCell->True],
Cell[21277, 811, 161, 6, 29, "Input",
  InitializationCell->True],
Cell[21441, 819, 104, 3, 29, "Text",
  Evaluatable->False],
Cell[21548, 824, 122, 5, 29, "Input"],
Cell[21673, 831, 102, 3, 29, "Text",
  Evaluatable->False],
Cell[21778, 836, 80, 3, 29, "Input"],
Cell[21861, 841, 86, 3, 29, "Text",
  Evaluatable->False],
Cell[21950, 846, 129, 5, 29, "Input"],
Cell[22082, 853, 82, 2, 30, "Input"],
Cell[22167, 857, 302, 8, 50, "Text"],
Cell[22472, 867, 125, 3, 29, "Input"],
Cell[22600, 872, 192, 6, 29, "Text",
  Evaluatable->False],
Cell[22795, 880, 141, 5, 29, "Input"],
Cell[22939, 887, 158, 5, 29, "Input"],
Cell[23100, 894, 147, 5, 29, "Input"],
Cell[23250, 901, 124, 4, 29, "Text"],
Cell[23377, 907, 92, 3, 29, "Input"],
Cell[23472, 912, 69, 2, 30, "Input"],
Cell[23544, 916, 156, 4, 29, "Input"],
Cell[23703, 922, 85, 3, 29, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23825, 930, 58, 1, 35, "Subsection"],
Cell[23886, 933, 428, 8, 71, "Text"],
Cell[24317, 943, 81, 3, 29, "Input"],

Cell[CellGroupData[{
Cell[24423, 950, 72, 2, 36, "Subsubsection"],
Cell[24498, 954, 62, 1, 29, "Text"],
Cell[24563, 957, 84, 3, 29, "Input"],
Cell[24650, 962, 69, 1, 29, "Text"],
Cell[24722, 965, 87, 3, 29, "Input"],
Cell[24812, 970, 48, 1, 29, "Text"],
Cell[24863, 973, 134, 5, 26, "Input"],
Cell[25000, 980, 115, 3, 29, "Input"],
Cell[25118, 985, 50, 1, 29, "Text"],
Cell[25171, 988, 121, 3, 29, "Input"],
Cell[25295, 993, 103, 3, 29, "Input"],
Cell[25401, 998, 50, 1, 29, "Text"],
Cell[25454, 1001, 86, 3, 29, "Input"],
Cell[25543, 1006, 115, 3, 29, "Input"],
Cell[25661, 1011, 111, 3, 30, "Input"],
Cell[25775, 1016, 82, 2, 30, "Input"],
Cell[25860, 1020, 83, 3, 30, "Input"],
Cell[25946, 1025, 106, 3, 30, "Input"],
Cell[26055, 1030, 39, 0, 27, "Text"],
Cell[26097, 1032, 71, 2, 30, "Input"],
Cell[26171, 1036, 106, 2, 30, "Input"],
Cell[26280, 1040, 64, 2, 30, "Input"],
Cell[26347, 1044, 116, 3, 27, "Text"],
Cell[26466, 1049, 236, 6, 72, "Input"],
Cell[26705, 1057, 77, 2, 30, "Input"],
Cell[26785, 1061, 168, 4, 29, "Text"],
Cell[26956, 1067, 89, 3, 30, "Input"],
Cell[27048, 1072, 116, 3, 29, "Input"],
Cell[27167, 1077, 92, 1, 29, "Text"],
Cell[27262, 1080, 157, 5, 29, "Input"],
Cell[27422, 1087, 125, 3, 27, "Text"],
Cell[27550, 1092, 124, 3, 29, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27723, 1101, 49, 1, 35, "Subsection"],
Cell[27775, 1104, 93, 2, 29, "Text"],
Cell[27871, 1108, 112, 4, 29, "Input"],
Cell[27986, 1114, 388, 9, 71, "Text"],
Cell[28377, 1125, 66, 2, 30, "Input"],
Cell[28446, 1129, 101, 2, 30, "Input"],
Cell[28550, 1133, 70, 2, 30, "Input"],
Cell[28623, 1137, 80, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[28728, 1143, 114, 4, 36, "Subsubsection",
  Evaluatable->False],
Cell[28845, 1149, 73, 2, 30, "Input"],
Cell[28921, 1153, 147, 5, 29, "Input"],
Cell[29071, 1160, 106, 3, 29, "Text"],
Cell[29180, 1165, 152, 5, 29, "Input"],
Cell[29335, 1172, 85, 3, 29, "Input"],
Cell[29423, 1177, 86, 3, 29, "Input"],
Cell[29512, 1182, 112, 3, 29, "Input"],
Cell[29627, 1187, 271, 7, 46, "Text"],
Cell[29901, 1196, 111, 3, 29, "Input"],
Cell[30015, 1201, 147, 4, 29, "Input"],
Cell[30165, 1207, 145, 4, 29, "Input"],
Cell[30313, 1213, 128, 3, 29, "Input"],
Cell[30444, 1218, 118, 3, 29, "Input"],
Cell[30565, 1223, 127, 4, 29, "Text"],
Cell[30695, 1229, 113, 3, 29, "Input"],
Cell[30811, 1234, 123, 3, 29, "Input"],
Cell[30937, 1239, 137, 4, 29, "Text"],
Cell[31077, 1245, 154, 5, 29, "Input"],
Cell[31234, 1252, 74, 2, 30, "Input"],
Cell[31311, 1256, 113, 3, 29, "Text"],
Cell[31427, 1261, 148, 5, 29, "Input"],
Cell[31578, 1268, 152, 5, 29, "Input"],
Cell[31733, 1275, 167, 5, 29, "Input"],
Cell[31903, 1282, 85, 3, 29, "Input"],
Cell[31991, 1287, 88, 2, 30, "Input"],
Cell[32082, 1291, 112, 4, 29, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32243, 1301, 109, 3, 35, "Subsection",
  Evaluatable->False],
Cell[32355, 1306, 529, 15, 95, "Text",
  Evaluatable->False],
Cell[32887, 1323, 128, 5, 29, "Input"],
Cell[33018, 1330, 544, 11, 169, "Input",
  Evaluatable->False],
Cell[33565, 1343, 274, 9, 29, "Text",
  Evaluatable->False],
Cell[33842, 1354, 83, 3, 29, "Input"],
Cell[33928, 1359, 132, 3, 29, "Text",
  Evaluatable->False],
Cell[34063, 1364, 128, 5, 29, "Input"],
Cell[34194, 1371, 168, 4, 29, "Text"],
Cell[34365, 1377, 176, 6, 29, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[34566, 1387, 114, 4, 36, "Subsubsection",
  Evaluatable->False],
Cell[34683, 1393, 70, 2, 30, "Input"],
Cell[34756, 1397, 136, 4, 29, "Input"],
Cell[34895, 1403, 134, 4, 29, "Input"],
Cell[35032, 1409, 138, 4, 29, "Input"],
Cell[35173, 1415, 85, 3, 29, "Input"],
Cell[35261, 1420, 122, 3, 29, "Input"],
Cell[35386, 1425, 93, 3, 29, "Input"],
Cell[35482, 1430, 138, 4, 29, "Input"],
Cell[35623, 1436, 134, 3, 30, "Input"],
Cell[35760, 1441, 138, 3, 30, "Input"],
Cell[35901, 1446, 136, 3, 30, "Input"],
Cell[36040, 1451, 136, 4, 29, "Input"],
Cell[36179, 1457, 136, 4, 29, "Input"],
Cell[36318, 1463, 199, 5, 49, "Input"],
Cell[36520, 1470, 86, 3, 29, "Input"],
Cell[36609, 1475, 174, 4, 51, "Input"],
Cell[36786, 1481, 157, 4, 51, "Input"],
Cell[36946, 1487, 178, 4, 51, "Input"],
Cell[37127, 1493, 163, 3, 51, "Input"],
Cell[37293, 1498, 70, 2, 30, "Input"]
}, Closed]]
}, Closed]],
Cell[37390, 1504, 40, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[37455, 1508, 54, 1, 41, "Subsection"],
Cell[37512, 1511, 2325, 55, 293, "Text"],
Cell[39840, 1568, 65, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[39942, 1573, 78, 1, 35, "Subsection"],

Cell[CellGroupData[{
Cell[40045, 1578, 48, 0, 36, "Subsubsection"],
Cell[40096, 1580, 1485, 48, 191, "Text"],
Cell[41584, 1630, 87, 3, 29, "Input"],
Cell[41674, 1635, 102, 3, 29, "Input"],
Cell[41779, 1640, 69, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41885, 1647, 51, 0, 36, "Subsubsection"],
Cell[41939, 1649, 144, 3, 27, "Text"],
Cell[42086, 1654, 73, 2, 30, "Input"],
Cell[42162, 1658, 77, 2, 30, "Input"],
Cell[42242, 1662, 71, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[42338, 1668, 3375, 64, 1059, "Input",
  Evaluatable->False],
Cell[45716, 1734, 208, 4, 26, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[45973, 1744, 43, 0, 36, "Subsubsection"],
Cell[46019, 1746, 608, 9, 103, "Text"],
Cell[46630, 1757, 303, 5, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46982, 1768, 59, 1, 35, "Subsection"],

Cell[CellGroupData[{
Cell[47066, 1773, 62, 0, 36, "Subsubsection"],
Cell[47131, 1775, 70, 2, 30, "Input"],
Cell[47204, 1779, 78, 2, 30, "Input"],
Cell[47285, 1783, 126, 3, 27, "Text"],
Cell[47414, 1788, 95, 2, 30, "Input"],
Cell[47512, 1792, 104, 2, 30, "Input"],
Cell[47619, 1796, 110, 2, 30, "Input"],
Cell[47732, 1800, 71, 2, 30, "Input"],
Cell[47806, 1804, 110, 2, 30, "Input"],
Cell[47919, 1808, 104, 2, 30, "Input"],
Cell[48026, 1812, 110, 3, 27, "Text"],
Cell[48139, 1817, 147, 3, 30, "Input"],
Cell[48289, 1822, 151, 3, 30, "Input"],
Cell[48443, 1827, 110, 2, 30, "Input"],
Cell[48556, 1831, 152, 3, 30, "Input"],
Cell[48711, 1836, 138, 3, 30, "Input"],
Cell[48852, 1841, 110, 2, 30, "Input"],
Cell[48965, 1845, 159, 3, 27, "Text"],
Cell[49127, 1850, 140, 3, 30, "Input"],
Cell[49270, 1855, 110, 2, 30, "Input"],
Cell[49383, 1859, 67, 0, 27, "Text"],
Cell[49453, 1861, 406, 10, 89, "Input"],
Cell[49862, 1873, 69, 0, 27, "Text"],
Cell[49934, 1875, 357, 8, 89, "Input"],
Cell[50294, 1885, 70, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[50401, 1892, 64, 0, 36, "Subsubsection"],
Cell[50468, 1894, 128, 3, 27, "Text"],
Cell[50599, 1899, 212, 4, 51, "Input"],
Cell[50814, 1905, 247, 5, 51, "Input"],
Cell[51064, 1912, 171, 3, 30, "Input"],
Cell[51238, 1917, 143, 3, 30, "Input"],
Cell[51384, 1922, 110, 2, 30, "Input"],
Cell[51497, 1926, 80, 2, 30, "Input"],
Cell[51580, 1930, 71, 2, 30, "Input"],
Cell[51654, 1934, 64, 2, 30, "Input"],
Cell[51721, 1938, 64, 2, 30, "Input"],
Cell[51788, 1942, 90, 2, 30, "Input"],
Cell[51881, 1946, 127, 3, 30, "Input"],
Cell[52011, 1951, 117, 2, 30, "Input"],
Cell[52131, 1955, 217, 4, 46, "Text"],
Cell[52351, 1961, 218, 4, 51, "Input"],
Cell[52572, 1967, 142, 4, 30, "Input"],
Cell[52717, 1973, 96, 2, 30, "Input"],
Cell[52816, 1977, 67, 2, 30, "Input"],
Cell[52886, 1981, 120, 3, 30, "Input"],
Cell[53009, 1986, 130, 3, 30, "Input"],
Cell[53142, 1991, 69, 2, 30, "Input"],
Cell[53214, 1995, 69, 2, 30, "Input"],
Cell[53286, 1999, 190, 4, 51, "Input"],
Cell[53479, 2005, 189, 4, 51, "Input"],
Cell[53671, 2011, 142, 4, 30, "Input"],
Cell[53816, 2017, 80, 2, 30, "Input"],
Cell[53899, 2021, 190, 4, 51, "Input"],
Cell[54092, 2027, 78, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54207, 2034, 46, 0, 30, "Subsubsection"],
Cell[54256, 2036, 179, 4, 29, "Text"],
Cell[54438, 2042, 70, 2, 30, "Input"],
Cell[54511, 2046, 78, 2, 30, "Input"],
Cell[54592, 2050, 79, 2, 30, "Input"],
Cell[54674, 2054, 124, 3, 27, "Text"],
Cell[54801, 2059, 128, 3, 29, "Input"],
Cell[54932, 2064, 173, 4, 29, "Text"],
Cell[55108, 2070, 160, 4, 29, "Input"],
Cell[55271, 2076, 110, 2, 30, "Input"],
Cell[55384, 2080, 119, 4, 29, "Text"],
Cell[55506, 2086, 159, 4, 29, "Input"],
Cell[55668, 2092, 110, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55815, 2099, 73, 0, 30, "Subsubsection"],
Cell[55891, 2101, 62, 2, 30, "Input"],
Cell[55956, 2105, 257, 6, 72, "Input"],
Cell[56216, 2113, 334, 8, 72, "Input"],
Cell[56553, 2123, 355, 8, 93, "Input"],
Cell[56911, 2133, 355, 8, 93, "Input"],
Cell[57269, 2143, 311, 7, 72, "Input"],
Cell[57583, 2152, 78, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[57698, 2159, 72, 0, 30, "Subsubsection"],
Cell[57773, 2161, 198, 4, 58, "Text"],
Cell[57974, 2167, 165, 3, 27, "Text"],
Cell[58142, 2172, 521, 10, 135, "Input"],
Cell[58666, 2184, 60, 0, 27, "Text"],
Cell[58729, 2186, 175, 4, 51, "Input"],
Cell[58907, 2192, 79, 2, 30, "Input"],
Cell[58989, 2196, 42, 0, 27, "Text"],
Cell[59034, 2198, 107, 2, 30, "Input"],
Cell[59144, 2202, 138, 3, 27, "Text"],
Cell[59285, 2207, 70, 2, 30, "Input"],
Cell[59358, 2211, 242, 6, 51, "Input",
  Evaluatable->False],
Cell[59603, 2219, 80, 2, 30, "Input"],
Cell[59686, 2223, 137, 3, 30, "Input"],
Cell[59826, 2228, 74, 2, 30, "Input"],
Cell[59903, 2232, 181, 4, 51, "Input"],
Cell[60087, 2238, 115, 3, 27, "Text"],
Cell[60205, 2243, 102, 2, 30, "Input"],
Cell[60310, 2247, 91, 2, 27, "Text"],
Cell[60404, 2251, 104, 2, 30, "Input"],
Cell[60511, 2255, 138, 3, 27, "Text"],
Cell[60652, 2260, 185, 4, 51, "Input"],
Cell[60840, 2266, 119, 3, 27, "Text"],
Cell[60962, 2271, 176, 3, 51, "Input"],
Cell[61141, 2276, 75, 2, 30, "Input"],
Cell[61219, 2280, 74, 2, 30, "Input"],
Cell[61296, 2284, 75, 2, 30, "Input"],
Cell[61374, 2288, 83, 2, 30, "Input"],
Cell[61460, 2292, 47, 0, 27, "Text"],
Cell[61510, 2294, 172, 3, 51, "Input"],
Cell[61685, 2299, 99, 2, 27, "Text"],
Cell[61787, 2303, 864, 15, 219, "Input"],
Cell[62654, 2320, 86, 2, 27, "Text"],
Cell[62743, 2324, 175, 4, 51, "Input"],
Cell[62921, 2330, 72, 2, 30, "Input"],
Cell[62996, 2334, 80, 2, 30, "Input"],
Cell[63079, 2338, 145, 3, 27, "Text"],
Cell[63227, 2343, 68, 2, 30, "Input"],
Cell[63298, 2347, 116, 2, 30, "Input"],
Cell[63417, 2351, 59, 0, 27, "Text"],
Cell[63479, 2353, 110, 2, 30, "Input"],
Cell[63592, 2357, 63, 0, 27, "Text"],
Cell[63658, 2359, 152, 4, 30, "Input"],
Cell[63813, 2365, 179, 4, 51, "Input"],
Cell[63995, 2371, 287, 5, 46, "Text"],
Cell[64285, 2378, 150, 4, 30, "Input"],
Cell[64438, 2384, 190, 4, 27, "Text"],
Cell[64631, 2390, 67, 2, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[64747, 2398, 53, 1, 35, "Subsection"],
Cell[64803, 2401, 43, 0, 27, "Text"],
Cell[64849, 2403, 70, 2, 30, "Input"],
Cell[64922, 2407, 73, 2, 30, "Input"],
Cell[64998, 2411, 173, 3, 46, "Text"],
Cell[65174, 2416, 174, 3, 46, "Text"],
Cell[65351, 2421, 72, 2, 30, "Input"],
Cell[65426, 2425, 618, 12, 177, "Input",
  Evaluatable->False],
Cell[66047, 2439, 88, 2, 30, "Input"],
Cell[66138, 2443, 113, 2, 30, "Input"],
Cell[66254, 2447, 95, 2, 27, "Text"],
Cell[66352, 2451, 137, 3, 30, "Input"],
Cell[66492, 2456, 70, 2, 30, "Input"],
Cell[66565, 2460, 153, 3, 30, "Input"],
Cell[66721, 2465, 107, 3, 27, "Text"],
Cell[66831, 2470, 70, 2, 30, "Input"],
Cell[66904, 2474, 44, 1, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[66997, 2481, 53, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[67075, 2485, 45, 0, 45, "Subsection"],
Cell[67123, 2487, 181, 7, 27, "Text"],
Cell[67307, 2496, 301, 5, 46, "Text"],
Cell[67611, 2503, 430, 9, 114, "Input",
  InitializationCell->True],
Cell[68044, 2514, 121, 3, 27, "Text"],
Cell[68168, 2519, 69, 2, 30, "Input"],
Cell[68240, 2523, 89, 2, 30, "Input"],
Cell[68332, 2527, 72, 2, 30, "Input"],
Cell[68407, 2531, 72, 2, 30, "Input"],
Cell[68482, 2535, 144, 4, 30, "Input"],
Cell[68629, 2541, 123, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[68789, 2549, 44, 0, 45, "Subsection"],
Cell[68836, 2551, 128, 3, 27, "Text"],
Cell[68967, 2556, 71, 2, 30, "Input"],
Cell[69041, 2560, 196, 4, 27, "Text"],
Cell[69240, 2566, 280, 7, 51, "Input",
  InitializationCell->True],
Cell[69523, 2575, 89, 2, 30, "Input"],
Cell[69615, 2579, 73, 2, 30, "Input"],
Cell[69691, 2583, 183, 4, 30, "Input"],
Cell[69877, 2589, 351, 7, 46, "Text"],
Cell[70231, 2598, 289, 7, 58, "Text"],
Cell[70523, 2607, 84, 2, 30, "Input"],
Cell[70610, 2611, 474, 7, 65, "Text"],
Cell[71087, 2620, 187, 5, 30, "Input"],
Cell[71277, 2627, 146, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[71460, 2635, 51, 0, 45, "Subsection"],
Cell[71514, 2637, 137, 3, 27, "Text"],
Cell[71654, 2642, 77, 2, 30, "Input"],
Cell[71734, 2646, 300, 5, 46, "Text"],
Cell[72037, 2653, 129, 3, 30, "Input",
  InitializationCell->True],
Cell[72169, 2658, 165, 3, 27, "Text"],
Cell[72337, 2663, 154, 4, 30, "Input",
  InitializationCell->True],
Cell[72494, 2669, 67, 2, 30, "Input"],
Cell[72564, 2673, 93, 2, 30, "Input"],
Cell[72660, 2677, 96, 2, 27, "Text"],
Cell[72759, 2681, 192, 5, 30, "Input"],
Cell[72954, 2688, 183, 3, 30, "Input"],
Cell[73140, 2693, 66, 2, 30, "Input"],
Cell[73209, 2697, 171, 3, 27, "Text"],
Cell[73383, 2702, 195, 4, 51, "Input"],
Cell[73581, 2708, 171, 5, 30, "Input"],
Cell[73755, 2715, 150, 3, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[73954, 2724, 54, 0, 60, "Section"],
Cell[74011, 2726, 577, 9, 65, "Text"],

Cell[CellGroupData[{
Cell[74613, 2739, 75, 0, 45, "Subsection"],
Cell[74691, 2741, 196, 7, 27, "Text"],
Cell[74890, 2750, 99, 2, 30, "Input",
  Evaluatable->False],
Cell[74992, 2754, 18, 0, 27, "Text"],
Cell[75013, 2756, 67, 2, 30, "Input"],
Cell[75083, 2760, 143, 3, 27, "Text"],
Cell[75229, 2765, 131, 3, 30, "Input",
  InitializationCell->True],
Cell[75363, 2770, 76, 2, 30, "Input"],
Cell[75442, 2774, 73, 2, 30, "Input"],
Cell[75518, 2778, 127, 3, 27, "Text"],
Cell[75648, 2783, 185, 4, 51, "Input"],
Cell[75836, 2789, 107, 3, 27, "Text"],
Cell[75946, 2794, 166, 3, 30, "Input"],
Cell[76115, 2799, 185, 4, 58, "Text"],
Cell[76303, 2805, 96, 2, 30, "Input",
  Evaluatable->False],
Cell[76402, 2809, 111, 3, 27, "Text"],
Cell[76516, 2814, 120, 3, 30, "Input",
  InitializationCell->True],
Cell[76639, 2819, 72, 2, 30, "Input"],
Cell[76714, 2823, 73, 2, 30, "Input"],
Cell[76790, 2827, 21, 0, 27, "Text"],
Cell[76814, 2829, 69, 2, 30, "Input"],
Cell[76886, 2833, 124, 3, 27, "Text"],
Cell[77013, 2838, 125, 3, 30, "Input",
  InitializationCell->True],
Cell[77141, 2843, 91, 2, 30, "Input"],
Cell[77235, 2847, 96, 2, 30, "Input"],
Cell[77334, 2851, 96, 2, 30, "Input"],
Cell[77433, 2855, 88, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[77546, 2861, 41, 0, 36, "Subsubsection"],
Cell[77590, 2863, 71, 0, 27, "Text"],
Cell[77664, 2865, 110, 2, 30, "Input"],
Cell[77777, 2869, 79, 2, 30, "Input"],
Cell[77859, 2873, 75, 2, 30, "Input"],
Cell[77937, 2877, 83, 2, 30, "Input"],
Cell[78023, 2881, 65, 0, 27, "Text"],
Cell[78091, 2883, 120, 3, 30, "Input"],
Cell[78214, 2888, 93, 2, 30, "Input"],
Cell[78310, 2892, 69, 2, 30, "Input"],
Cell[78382, 2896, 55, 0, 27, "Text"],
Cell[78440, 2898, 130, 3, 30, "Input"],
Cell[78573, 2903, 69, 2, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[78691, 2911, 42, 0, 39, "Subsection"],
Cell[78736, 2913, 163, 3, 27, "Text"],
Cell[78902, 2918, 128, 3, 30, "Input"],
Cell[79033, 2923, 89, 2, 30, "Input"],
Cell[79125, 2927, 117, 3, 27, "Text"],
Cell[79245, 2932, 94, 2, 30, "Input"],
Cell[79342, 2936, 272, 5, 46, "Text"],
Cell[79617, 2943, 178, 4, 30, "Input",
  InitializationCell->True],
Cell[79798, 2949, 241, 4, 27, "Text"],
Cell[80042, 2955, 119, 3, 30, "Input"],
Cell[80164, 2960, 112, 2, 30, "Input"],
Cell[80279, 2964, 74, 2, 30, "Input"],
Cell[80356, 2968, 94, 2, 30, "Input"],
Cell[80453, 2972, 59, 0, 27, "Text"],
Cell[80515, 2974, 127, 3, 30, "Input"],
Cell[80645, 2979, 128, 3, 30, "Input"],
Cell[80776, 2984, 71, 2, 30, "Input"],
Cell[80850, 2988, 92, 2, 30, "Input"],
Cell[80945, 2992, 51, 0, 27, "Text"],
Cell[80999, 2994, 115, 2, 30, "Input"],
Cell[81117, 2998, 120, 3, 30, "Input"],
Cell[81240, 3003, 108, 3, 27, "Text"],
Cell[81351, 3008, 106, 2, 30, "Input"],
Cell[81460, 3012, 110, 2, 30, "Input"],
Cell[81573, 3016, 320, 5, 46, "Text"],
Cell[81896, 3023, 120, 3, 30, "Input"],
Cell[82019, 3028, 232, 4, 27, "Text"],
Cell[82254, 3034, 95, 2, 27, "Text"],
Cell[82352, 3038, 108, 2, 30, "Input"],
Cell[82463, 3042, 112, 2, 30, "Input"],
Cell[82578, 3046, 72, 2, 30, "Input"],
Cell[82653, 3050, 129, 3, 30, "Input"],
Cell[82785, 3055, 69, 2, 30, "Input"],
Cell[82857, 3059, 249, 6, 70, "Input"],
Cell[83109, 3067, 70, 2, 30, "Input"],
Cell[83182, 3071, 254, 6, 70, "Input"],
Cell[83439, 3079, 72, 2, 30, "Input"],
Cell[83514, 3083, 130, 3, 30, "Input"],
Cell[83647, 3088, 74, 2, 30, "Input"],
Cell[83724, 3092, 94, 2, 30, "Input"],
Cell[83821, 3096, 252, 6, 70, "Input"],
Cell[84076, 3104, 76, 2, 30, "Input"],
Cell[84155, 3108, 266, 7, 70, "Input"],
Cell[84424, 3117, 76, 2, 30, "Input"],
Cell[84503, 3121, 153, 3, 30, "Input"],
Cell[84659, 3126, 73, 2, 30, "Input"],
Cell[84735, 3130, 92, 2, 30, "Input"],
Cell[84830, 3134, 93, 2, 30, "Input"],
Cell[84926, 3138, 189, 4, 70, "Input"],
Cell[85118, 3144, 73, 2, 30, "Input"],
Cell[85194, 3148, 93, 2, 30, "Input"],
Cell[85290, 3152, 189, 4, 70, "Input"],
Cell[85482, 3158, 191, 4, 70, "Input"],
Cell[85676, 3164, 173, 3, 70, "Input"],
Cell[85852, 3169, 178, 3, 70, "Input"],
Cell[86033, 3174, 226, 4, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[86296, 3183, 69, 0, 45, "Subsection"],
Cell[86368, 3185, 62, 0, 27, "Text"],
Cell[86433, 3187, 76, 2, 30, "Input"],
Cell[86512, 3191, 49, 0, 27, "Text"],
Cell[86564, 3193, 91, 2, 30, "Input"],
Cell[86658, 3197, 128, 3, 70, "Input"],
Cell[86789, 3202, 188, 6, 27, "Text"],
Cell[86980, 3210, 198, 5, 30, "Input",
  InitializationCell->True],
Cell[87181, 3217, 151, 3, 27, "Text"],
Cell[87335, 3222, 172, 5, 30, "Input",
  InitializationCell->True],
Cell[87510, 3229, 80, 2, 30, "Input"],
Cell[87593, 3233, 135, 3, 30, "Input"],
Cell[87731, 3238, 185, 6, 27, "Text"],
Cell[87919, 3246, 132, 3, 30, "Input"],
Cell[88054, 3251, 69, 2, 30, "Input"],
Cell[88126, 3255, 137, 3, 30, "Input"],
Cell[88266, 3260, 69, 2, 30, "Input"],
Cell[88338, 3264, 151, 3, 30, "Input"],
Cell[88492, 3269, 79, 2, 30, "Input"],
Cell[88574, 3273, 95, 2, 30, "Input"],
Cell[88672, 3277, 83, 2, 30, "Input"],
Cell[88758, 3281, 82, 2, 30, "Input"],
Cell[88843, 3285, 67, 2, 30, "Input"],
Cell[88913, 3289, 67, 2, 30, "Input"],
Cell[88983, 3293, 113, 3, 27, "Text"],
Cell[89099, 3298, 180, 5, 30, "Input",
  InitializationCell->True],
Cell[89282, 3305, 85, 2, 27, "Text"],
Cell[89370, 3309, 143, 3, 30, "Input"],
Cell[89516, 3314, 73, 2, 30, "Input"],
Cell[89592, 3318, 160, 3, 27, "Text"],
Cell[89755, 3323, 82, 2, 30, "Input"],
Cell[89840, 3327, 73, 2, 30, "Input"],
Cell[89916, 3331, 69, 0, 27, "Text"],
Cell[89988, 3333, 187, 4, 30, "Input"],
Cell[90178, 3339, 108, 2, 30, "Input"],
Cell[90289, 3343, 87, 2, 27, "Text"],
Cell[90379, 3347, 77, 2, 30, "Input"],
Cell[90459, 3351, 58, 0, 27, "Text"],
Cell[90520, 3353, 182, 4, 30, "Input"],
Cell[90705, 3359, 70, 2, 30, "Input"],
Cell[90778, 3363, 170, 3, 30, "Input"],
Cell[90951, 3368, 72, 2, 30, "Input"],
Cell[91026, 3372, 169, 3, 30, "Input"],
Cell[91198, 3377, 71, 2, 30, "Input"],
Cell[91272, 3381, 135, 3, 30, "Input"],
Cell[91410, 3386, 73, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[91520, 3391, 59, 0, 45, "Subsection"],
Cell[91582, 3393, 311, 8, 27, "Text"],
Cell[91896, 3403, 171, 5, 30, "Input",
  InitializationCell->True],
Cell[92070, 3410, 81, 2, 30, "Input"],
Cell[92154, 3414, 70, 2, 30, "Input"],
Cell[92227, 3418, 57, 0, 27, "Text"],
Cell[92287, 3420, 101, 2, 30, "Input"],
Cell[92391, 3424, 74, 2, 30, "Input"],
Cell[92468, 3428, 80, 2, 30, "Input"],
Cell[92551, 3432, 70, 2, 30, "Input"],
Cell[92624, 3436, 82, 2, 30, "Input"],
Cell[92709, 3440, 70, 2, 30, "Input"],
Cell[92782, 3444, 159, 3, 27, "Text"],
Cell[92944, 3449, 83, 2, 30, "Input"],
Cell[93030, 3453, 74, 2, 30, "Input"],
Cell[93107, 3457, 77, 2, 30, "Input"],
Cell[93187, 3461, 78, 2, 30, "Input"],
Cell[93268, 3465, 136, 3, 30, "Input"],
Cell[93407, 3470, 76, 2, 30, "Input"],
Cell[93486, 3474, 66, 0, 27, "Text"],
Cell[93555, 3476, 139, 3, 30, "Input"],
Cell[93697, 3481, 91, 2, 30, "Input"],
Cell[93791, 3485, 74, 2, 30, "Input"],
Cell[93868, 3489, 122, 3, 27, "Text"],
Cell[93993, 3494, 104, 2, 30, "Input"],
Cell[94100, 3498, 74, 2, 30, "Input"],
Cell[94177, 3502, 91, 2, 30, "Input"],
Cell[94271, 3506, 74, 2, 30, "Input"],
Cell[94348, 3510, 61, 0, 27, "Text"],
Cell[94412, 3512, 100, 2, 30, "Input"],
Cell[94515, 3516, 74, 2, 30, "Input"],
Cell[94592, 3520, 280, 6, 58, "Text"],
Cell[94875, 3528, 195, 4, 30, "Input"],
Cell[95073, 3534, 71, 2, 30, "Input"],
Cell[95147, 3538, 105, 2, 30, "Input"],
Cell[95255, 3542, 198, 4, 30, "Input"],
Cell[95456, 3548, 113, 3, 27, "Text"],
Cell[95572, 3553, 182, 4, 30, "Input"],
Cell[95757, 3559, 77, 2, 30, "Input"],
Cell[95837, 3563, 69, 2, 30, "Input"],
Cell[95909, 3567, 88, 2, 27, "Text"],
Cell[96000, 3571, 185, 4, 51, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[96222, 3580, 103, 2, 39, "Subsection"],
Cell[96328, 3584, 110, 2, 30, "Input"],
Cell[96441, 3588, 81, 2, 30, "Input"],
Cell[96525, 3592, 85, 2, 30, "Input"],
Cell[96613, 3596, 69, 2, 30, "Input"],
Cell[96685, 3600, 268, 5, 46, "Text"],
Cell[96956, 3607, 91, 2, 30, "Input"],
Cell[97050, 3611, 79, 2, 30, "Input"],
Cell[97132, 3615, 70, 2, 30, "Input"],
Cell[97205, 3619, 78, 2, 30, "Input"],
Cell[97286, 3623, 82, 2, 30, "Input"],
Cell[97371, 3627, 128, 3, 30, "Input"],
Cell[97502, 3632, 73, 2, 30, "Input"],
Cell[97578, 3636, 22, 0, 27, "Text"],
Cell[97603, 3638, 92, 2, 30, "Input"],
Cell[97698, 3642, 154, 3, 30, "Input"],
Cell[97855, 3647, 130, 3, 30, "Input"],
Cell[97988, 3652, 27, 0, 27, "Text"],
Cell[98018, 3654, 78, 2, 30, "Input"],
Cell[98099, 3658, 143, 3, 30, "Input"],
Cell[98245, 3663, 26, 0, 27, "Text"],
Cell[98274, 3665, 78, 2, 30, "Input"],
Cell[98355, 3669, 68, 0, 27, "Text"],
Cell[98426, 3671, 106, 2, 30, "Input"],
Cell[98535, 3675, 73, 2, 30, "Input"],
Cell[98611, 3679, 23, 0, 27, "Text"],
Cell[98637, 3681, 92, 2, 30, "Input"],
Cell[98732, 3685, 73, 2, 30, "Input"],
Cell[98808, 3689, 73, 2, 30, "Input"],
Cell[98884, 3693, 73, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[98982, 3699, 62, 0, 36, "Subsubsection"],
Cell[99047, 3701, 86, 2, 30, "Input"],
Cell[99136, 3705, 70, 2, 30, "Input"],
Cell[99209, 3709, 29, 0, 27, "Text"],
Cell[99241, 3711, 200, 4, 31, "Input"],
Cell[99444, 3717, 57, 0, 27, "Text"],
Cell[99504, 3719, 87, 1, 34, "Input"],
Cell[99594, 3722, 92, 2, 30, "Input"],
Cell[99689, 3726, 141, 3, 30, "Input"],
Cell[99833, 3731, 100, 1, 34, "Input"],
Cell[99936, 3734, 72, 2, 30, "Input"],
Cell[100011, 3738, 67, 2, 30, "Input"],
Cell[100081, 3742, 141, 3, 30, "Input"],
Cell[100225, 3747, 99, 1, 34, "Input"],
Cell[100327, 3750, 72, 2, 30, "Input"],
Cell[100402, 3754, 67, 0, 27, "Text"],
Cell[100472, 3756, 129, 3, 30, "Input"],
Cell[100604, 3761, 67, 2, 30, "Input"],
Cell[100674, 3765, 117, 2, 30, "Input"],
Cell[100794, 3769, 120, 3, 30, "Input"],
Cell[100917, 3774, 92, 2, 30, "Input"],
Cell[101012, 3778, 205, 6, 27, "Text"],
Cell[101220, 3786, 94, 1, 34, "Input"],
Cell[101317, 3789, 74, 2, 30, "Input"],
Cell[101394, 3793, 94, 1, 34, "Input"],
Cell[101491, 3796, 70, 2, 30, "Input"],
Cell[101564, 3800, 133, 3, 30, "Input"],
Cell[101700, 3805, 48, 0, 27, "Text"],
Cell[101751, 3807, 103, 1, 34, "Input"],
Cell[101857, 3810, 69, 2, 30, "Input"],
Cell[101929, 3814, 103, 1, 34, "Input"],
Cell[102035, 3817, 69, 2, 30, "Input"],
Cell[102107, 3821, 131, 3, 30, "Input"],
Cell[102241, 3826, 60, 0, 27, "Text"],
Cell[102304, 3828, 114, 3, 34, "Input"],
Cell[102421, 3833, 75, 2, 30, "Input"],
Cell[102499, 3837, 114, 3, 34, "Input"],
Cell[102616, 3842, 71, 2, 30, "Input"],
Cell[102690, 3846, 129, 3, 30, "Input"],
Cell[102822, 3851, 79, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[102938, 3858, 62, 0, 36, "Subsubsection"],
Cell[103003, 3860, 221, 4, 46, "Text"],
Cell[103227, 3866, 137, 3, 32, "Output"],
Cell[103367, 3871, 105, 3, 27, "Text"],
Cell[103475, 3876, 135, 3, 30, "Input"],
Cell[103613, 3881, 69, 2, 30, "Input"],
Cell[103685, 3885, 33, 0, 27, "Text"],
Cell[103721, 3887, 111, 3, 34, "Input"],
Cell[103835, 3892, 102, 1, 34, "Input"],
Cell[103940, 3895, 32, 0, 27, "Text"],
Cell[103975, 3897, 84, 1, 34, "Input"],
Cell[104062, 3900, 95, 2, 30, "Input"],
Cell[104160, 3904, 108, 2, 57, "Input"],
Cell[104271, 3908, 135, 3, 27, "Text"],
Cell[104409, 3913, 68, 2, 30, "Input"],
Cell[104480, 3917, 73, 2, 30, "Input"],
Cell[104556, 3921, 73, 2, 30, "Input"],
Cell[104632, 3925, 73, 2, 30, "Input"],
Cell[104708, 3929, 33, 0, 27, "Text"],
Cell[104744, 3931, 90, 2, 30, "Input"],
Cell[104837, 3935, 90, 2, 30, "Input"],
Cell[104930, 3939, 108, 2, 30, "Input"],
Cell[105041, 3943, 110, 2, 30, "Input"],
Cell[105154, 3947, 137, 3, 27, "Text"],
Cell[105294, 3952, 101, 2, 30, "Input"],
Cell[105398, 3956, 79, 2, 30, "Input"],
Cell[105480, 3960, 96, 2, 27, "Text"],
Cell[105579, 3964, 82, 2, 30, "Input"],
Cell[105664, 3968, 83, 2, 30, "Input"],
Cell[105750, 3972, 127, 3, 27, "Text"],
Cell[105880, 3977, 132, 3, 31, "Input"],
Cell[106015, 3982, 37, 0, 27, "Text"],
Cell[106055, 3984, 186, 5, 30, "Input"],
Cell[106244, 3991, 67, 2, 30, "Input"],
Cell[106314, 3995, 33, 0, 27, "Text"],
Cell[106350, 3997, 184, 5, 30, "Input"],
Cell[106537, 4004, 65, 2, 30, "Input"],
Cell[106605, 4008, 79, 2, 30, "Input"],
Cell[106687, 4012, 85, 2, 30, "Input"],
Cell[106775, 4016, 53, 0, 27, "Text"],
Cell[106831, 4018, 102, 2, 30, "Input"],
Cell[106936, 4022, 137, 3, 30, "Input"],
Cell[107076, 4027, 192, 4, 27, "Text"],
Cell[107271, 4033, 70, 0, 27, "Text"],
Cell[107344, 4035, 160, 3, 30, "Input"],
Cell[107507, 4040, 192, 4, 30, "Input"],
Cell[107702, 4046, 73, 2, 30, "Input"],
Cell[107778, 4050, 91, 2, 30, "Input"],
Cell[107872, 4054, 75, 2, 30, "Input"],
Cell[107950, 4058, 96, 2, 30, "Input"],
Cell[108049, 4062, 108, 3, 27, "Text"],
Cell[108160, 4067, 108, 3, 27, "Text"],
Cell[108271, 4072, 197, 4, 51, "Input"],
Cell[108471, 4078, 91, 2, 30, "Input"],
Cell[108565, 4082, 102, 3, 27, "Text"],
Cell[108670, 4087, 209, 5, 51, "Input"],
Cell[108882, 4094, 65, 2, 30, "Input"],
Cell[108950, 4098, 80, 2, 27, "Text"],
Cell[109033, 4102, 198, 4, 51, "Input"],
Cell[109234, 4108, 73, 2, 30, "Input"],
Cell[109310, 4112, 124, 3, 27, "Text"],
Cell[109437, 4117, 165, 3, 30, "Input"],
Cell[109605, 4122, 193, 4, 30, "Input"],
Cell[109801, 4128, 101, 2, 30, "Input"],
Cell[109905, 4132, 76, 2, 30, "Input"],
Cell[109984, 4136, 98, 2, 30, "Input"],
Cell[110085, 4140, 128, 3, 30, "Input"],
Cell[110216, 4145, 68, 2, 30, "Input"],
Cell[110287, 4149, 86, 2, 30, "Input"],
Cell[110376, 4153, 105, 3, 27, "Text"],
Cell[110484, 4158, 195, 4, 51, "Input"],
Cell[110682, 4164, 102, 2, 30, "Input"],
Cell[110787, 4168, 79, 2, 30, "Input"],
Cell[110869, 4172, 116, 3, 27, "Text"],
Cell[110988, 4177, 196, 4, 30, "Input"],
Cell[111187, 4183, 65, 2, 30, "Input"],
Cell[111255, 4187, 80, 2, 30, "Input"],
Cell[111338, 4191, 112, 3, 27, "Text"],
Cell[111453, 4196, 82, 2, 30, "Input"],
Cell[111538, 4200, 73, 2, 30, "Input"],
Cell[111614, 4204, 92, 2, 30, "Input"],
Cell[111709, 4208, 140, 3, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[111898, 4217, 98, 2, 45, "Subsection"],

Cell[CellGroupData[{
Cell[112021, 4223, 75, 0, 36, "Subsubsection"],
Cell[112099, 4225, 105, 1, 27, "Text"],
Cell[112207, 4228, 134, 3, 30, "Input",
  InitializationCell->True],
Cell[112344, 4233, 81, 2, 30, "Input"],
Cell[112428, 4237, 170, 5, 27, "Text"],
Cell[112601, 4244, 88, 2, 30, "Input"],
Cell[112692, 4248, 82, 2, 30, "Input"],
Cell[112777, 4252, 83, 2, 30, "Input"],
Cell[112863, 4256, 73, 0, 27, "Text"],
Cell[112939, 4258, 73, 2, 30, "Input"],
Cell[113015, 4262, 108, 1, 27, "Text"],
Cell[113126, 4265, 1090, 17, 265, "Text"],
Cell[114219, 4284, 105, 2, 30, "Input"],
Cell[114327, 4288, 54, 0, 27, "Text"],
Cell[114384, 4290, 156, 4, 30, "Input"],
Cell[114543, 4296, 54, 0, 27, "Text"],
Cell[114600, 4298, 125, 3, 30, "Input"],
Cell[114728, 4303, 81, 2, 30, "Input"],
Cell[114812, 4307, 63, 0, 27, "Text"],
Cell[114878, 4309, 97, 2, 30, "Input"],
Cell[114978, 4313, 33, 0, 27, "Text"],
Cell[115014, 4315, 113, 4, 57, "Input"],
Cell[115130, 4321, 112, 2, 30, "Input"],
Cell[115245, 4325, 348, 6, 65, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[115630, 4336, 45, 0, 30, "Subsubsection"],
Cell[115678, 4338, 88, 2, 27, "Text"],
Cell[115769, 4342, 147, 4, 30, "Input",
  InitializationCell->True],
Cell[115919, 4348, 45, 0, 27, "Text"],
Cell[115967, 4350, 120, 3, 30, "Input",
  InitializationCell->True],
Cell[116090, 4355, 73, 2, 30, "Input"],
Cell[116166, 4359, 104, 2, 30, "Input"],
Cell[116273, 4363, 99, 2, 27, "Text"],
Cell[116375, 4367, 139, 3, 30, "Input",
  InitializationCell->True],
Cell[116517, 4372, 83, 2, 30, "Input"],
Cell[116603, 4376, 110, 3, 27, "Text"],
Cell[116716, 4381, 94, 2, 30, "Input"],
Cell[116813, 4385, 82, 2, 30, "Input"],
Cell[116898, 4389, 96, 2, 30, "Input"],
Cell[116997, 4393, 132, 3, 30, "Input"],
Cell[117132, 4398, 120, 2, 34, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[117289, 4405, 45, 0, 30, "Subsubsection"],
Cell[117337, 4407, 88, 2, 27, "Text"],
Cell[117428, 4411, 155, 4, 30, "Input",
  InitializationCell->True],
Cell[117586, 4417, 45, 0, 27, "Text"],
Cell[117634, 4419, 120, 3, 30, "Input",
  InitializationCell->True],
Cell[117757, 4424, 99, 2, 27, "Text"],
Cell[117859, 4428, 137, 3, 30, "Input",
  InitializationCell->True],
Cell[117999, 4433, 83, 2, 30, "Input"],
Cell[118085, 4437, 24, 0, 27, "Text"],
Cell[118112, 4439, 83, 2, 30, "Input"],
Cell[118198, 4443, 83, 2, 30, "Input"],
Cell[118284, 4447, 73, 2, 30, "Input"],
Cell[118360, 4451, 79, 2, 30, "Input"],
Cell[118442, 4455, 82, 2, 30, "Input"],
Cell[118527, 4459, 74, 2, 30, "Input"],
Cell[118604, 4463, 125, 3, 27, "Text"],
Cell[118732, 4468, 122, 3, 27, "Text"],
Cell[118857, 4473, 94, 2, 30, "Input"],
Cell[118954, 4477, 82, 2, 30, "Input"],
Cell[119039, 4481, 96, 2, 30, "Input"],
Cell[119138, 4485, 132, 3, 30, "Input"],
Cell[119273, 4490, 119, 2, 34, "Input",
  InitializationCell->True],
Cell[119395, 4494, 68, 2, 30, "Input"],
Cell[119466, 4498, 83, 2, 30, "Input"],
Cell[119552, 4502, 81, 2, 30, "Input"],
Cell[119636, 4506, 82, 2, 30, "Input"],
Cell[119721, 4510, 176, 4, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[119934, 4519, 67, 0, 36, "Subsubsection"],
Cell[120004, 4521, 339, 6, 46, "Text"],
Cell[120346, 4529, 81, 2, 30, "Input"],
Cell[120430, 4533, 338, 6, 46, "Text"],
Cell[120771, 4541, 176, 4, 34, "Input",
  InitializationCell->True],
Cell[120950, 4547, 82, 2, 30, "Input"],
Cell[121035, 4551, 91, 1, 34, "Input"],
Cell[121129, 4554, 22, 0, 27, "Text"],
Cell[121154, 4556, 137, 3, 30, "Input",
  InitializationCell->True],
Cell[121294, 4561, 203, 6, 120, "Text"],
Cell[121500, 4569, 90, 2, 30, "Input"],
Cell[121593, 4573, 85, 2, 30, "Input"],
Cell[121681, 4577, 125, 3, 27, "Text"],
Cell[121809, 4582, 111, 2, 30, "Input"],
Cell[121923, 4586, 171, 5, 30, "Text"],
Cell[122097, 4593, 143, 3, 30, "Input"],
Cell[122243, 4598, 69, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[122349, 4605, 47, 0, 36, "Subsubsection"],
Cell[122399, 4607, 88, 2, 27, "Text"],
Cell[122490, 4611, 104, 2, 30, "Input"],
Cell[122597, 4615, 147, 3, 30, "Input"],
Cell[122747, 4620, 90, 2, 30, "Input"],
Cell[122840, 4624, 96, 2, 30, "Input"],
Cell[122939, 4628, 74, 2, 30, "Input"],
Cell[123016, 4632, 99, 2, 30, "Input"],
Cell[123118, 4636, 143, 3, 27, "Text"],
Cell[123264, 4641, 76, 2, 30, "Input"],
Cell[123343, 4645, 95, 2, 30, "Input"],
Cell[123441, 4649, 103, 2, 30, "Input"],
Cell[123547, 4653, 89, 2, 30, "Input"],
Cell[123639, 4657, 104, 3, 27, "Text"],
Cell[123746, 4662, 218, 5, 51, "Input"],
Cell[123967, 4669, 74, 2, 30, "Input"],
Cell[124044, 4673, 74, 2, 30, "Input"],
Cell[124121, 4677, 223, 5, 51, "Input"],
Cell[124347, 4684, 66, 2, 30, "Input"],
Cell[124416, 4688, 101, 2, 30, "Input"],
Cell[124520, 4692, 68, 2, 30, "Input"],
Cell[124591, 4696, 89, 2, 30, "Input"],
Cell[124683, 4700, 170, 3, 27, "Text"],
Cell[124856, 4705, 73, 0, 27, "Text"],
Cell[124932, 4707, 97, 2, 30, "Input"],
Cell[125032, 4711, 114, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[125183, 4719, 37, 0, 30, "Subsubsection"],
Cell[125223, 4721, 64, 0, 27, "Text"],
Cell[125290, 4723, 89, 2, 30, "Input"],
Cell[125382, 4727, 100, 2, 30, "Input"],
Cell[125485, 4731, 136, 3, 30, "Input",
  InitializationCell->True],
Cell[125624, 4736, 84, 2, 30, "Input"],
Cell[125711, 4740, 87, 2, 30, "Input"],
Cell[125801, 4744, 121, 3, 30, "Input",
  InitializationCell->True],
Cell[125925, 4749, 112, 3, 27, "Text"],
Cell[126040, 4754, 101, 2, 30, "Input"],
Cell[126144, 4758, 349, 9, 37, "Input"],
Cell[126496, 4769, 109, 2, 30, "Input"],
Cell[126608, 4773, 301, 8, 37, "Input"],
Cell[126912, 4783, 109, 2, 30, "Input"],
Cell[127024, 4787, 300, 8, 37, "Input"],
Cell[127327, 4797, 109, 2, 30, "Input"],
Cell[127439, 4801, 226, 5, 51, "Input"],
Cell[127668, 4808, 109, 2, 30, "Input"],
Cell[127780, 4812, 242, 6, 51, "Input"],
Cell[128025, 4820, 96, 2, 30, "Input"],
Cell[128124, 4824, 73, 2, 30, "Input"],
Cell[128200, 4828, 91, 2, 30, "Input"],
Cell[128294, 4832, 110, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[128441, 4840, 48, 0, 30, "Subsubsection"],
Cell[128492, 4842, 200, 4, 51, "Input"],
Cell[128695, 4848, 74, 2, 30, "Input"],
Cell[128772, 4852, 228, 5, 51, "Input"],
Cell[129003, 4859, 74, 2, 30, "Input"],
Cell[129080, 4863, 250, 6, 51, "Input"],
Cell[129333, 4871, 72, 2, 30, "Input"],
Cell[129408, 4875, 92, 2, 30, "Input"],
Cell[129503, 4879, 69, 2, 30, "Input"],
Cell[129575, 4883, 91, 2, 30, "Input"],
Cell[129669, 4887, 98, 2, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[129804, 4894, 39, 0, 30, "Subsubsection"],
Cell[129846, 4896, 64, 0, 27, "Text"],
Cell[129913, 4898, 91, 2, 30, "Input"],
Cell[130007, 4902, 67, 2, 30, "Input"],
Cell[130077, 4906, 140, 3, 30, "Input"],
Cell[130220, 4911, 236, 4, 46, "Text"],
Cell[130459, 4917, 69, 2, 30, "Input"],
Cell[130531, 4921, 69, 2, 30, "Input"],
Cell[130603, 4925, 119, 3, 27, "Text"],
Cell[130725, 4930, 101, 2, 30, "Input"],
Cell[130829, 4934, 109, 2, 30, "Input"],
Cell[130941, 4938, 102, 2, 30, "Input"],
Cell[131046, 4942, 109, 2, 30, "Input"],
Cell[131158, 4946, 63, 0, 27, "Text"],
Cell[131224, 4948, 219, 5, 51, "Input"],
Cell[131446, 4955, 109, 2, 30, "Input"],
Cell[131558, 4959, 224, 5, 51, "Input"],
Cell[131785, 4966, 98, 2, 30, "Input"],
Cell[131886, 4970, 69, 2, 30, "Input"],
Cell[131958, 4974, 91, 2, 30, "Input"],
Cell[132052, 4978, 113, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[132202, 4986, 39, 0, 30, "Subsubsection"],
Cell[132244, 4988, 69, 2, 30, "Input"],
Cell[132316, 4992, 68, 2, 30, "Input"],
Cell[132387, 4996, 69, 2, 30, "Input"],
Cell[132459, 5000, 97, 2, 30, "Input"],
Cell[132559, 5004, 75, 2, 30, "Input"],
Cell[132637, 5008, 79, 2, 30, "Input"],
Cell[132719, 5012, 90, 2, 30, "Input"],
Cell[132812, 5016, 101, 2, 30, "Input"],
Cell[132916, 5020, 110, 2, 30, "Input"],
Cell[133029, 5024, 73, 2, 30, "Input"],
Cell[133105, 5028, 106, 2, 30, "Input"],
Cell[133214, 5032, 89, 2, 30, "Input"],
Cell[133306, 5036, 85, 2, 30, "Input"],
Cell[133394, 5040, 82, 2, 30, "Input"],
Cell[133479, 5044, 69, 2, 30, "Input"],
Cell[133551, 5048, 146, 3, 27, "Text"],
Cell[133700, 5053, 119, 3, 30, "Input"],
Cell[133822, 5058, 107, 2, 30, "Input"],
Cell[133932, 5062, 119, 3, 30, "Input"],
Cell[134054, 5067, 107, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[134198, 5074, 37, 0, 30, "Subsubsection"],
Cell[134238, 5076, 77, 2, 30, "Input"],
Cell[134318, 5080, 90, 2, 30, "Input"],
Cell[134411, 5084, 214, 4, 27, "Text"],
Cell[134628, 5090, 103, 2, 30, "Input"],
Cell[134734, 5094, 96, 2, 30, "Input"],
Cell[134833, 5098, 94, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[134964, 5105, 42, 0, 30, "Subsubsection"],
Cell[135009, 5107, 182, 4, 36, "Input"],
Cell[135194, 5113, 103, 3, 27, "Text"],
Cell[135300, 5118, 69, 2, 30, "Input"],
Cell[135372, 5122, 63, 0, 27, "Text"],
Cell[135438, 5124, 246, 6, 58, "Input"],
Cell[135687, 5132, 108, 2, 30, "Input"],
Cell[135798, 5136, 251, 6, 58, "Input"],
Cell[136052, 5144, 95, 2, 30, "Input"],
Cell[136150, 5148, 68, 2, 30, "Input"],
Cell[136221, 5152, 90, 2, 30, "Input"],
Cell[136314, 5156, 114, 3, 27, "Text"],
Cell[136431, 5161, 246, 6, 58, "Input"],
Cell[136680, 5169, 108, 2, 30, "Input"],
Cell[136791, 5173, 251, 6, 58, "Input"],
Cell[137045, 5181, 97, 2, 30, "Input"],
Cell[137145, 5185, 68, 2, 30, "Input"],
Cell[137216, 5189, 90, 2, 30, "Input"],
Cell[137309, 5193, 183, 4, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[137529, 5202, 36, 0, 30, "Subsubsection"],
Cell[137568, 5204, 151, 3, 27, "Text"],
Cell[137722, 5209, 315, 6, 72, "Input"],
Cell[138040, 5217, 248, 4, 46, "Text"],
Cell[138291, 5223, 304, 6, 72, "Input"],
Cell[138598, 5231, 76, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[138711, 5238, 42, 0, 30, "Subsubsection"],
Cell[138756, 5240, 133, 3, 30, "Input"],
Cell[138892, 5245, 131, 3, 30, "Input"],
Cell[139026, 5250, 42, 0, 27, "Text"],
Cell[139071, 5252, 72, 2, 30, "Input"],
Cell[139146, 5256, 78, 2, 30, "Input"],
Cell[139227, 5260, 174, 3, 27, "Text"],
Cell[139404, 5265, 153, 3, 30, "Input"],
Cell[139560, 5270, 131, 3, 30, "Input"],
Cell[139694, 5275, 54, 0, 27, "Text"],
Cell[139751, 5277, 139, 3, 30, "Input"],
Cell[139893, 5282, 131, 3, 30, "Input"],
Cell[140027, 5287, 174, 4, 30, "Input"],
Cell[140204, 5293, 131, 3, 30, "Input"],
Cell[140338, 5298, 77, 5, 120, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[140452, 5308, 35, 0, 30, "Subsubsection"],
Cell[140490, 5310, 28, 0, 27, "Text"],
Cell[140521, 5312, 377, 8, 72, "Input"],
Cell[140901, 5322, 76, 2, 30, "Input"],
Cell[140980, 5326, 232, 6, 51, "Input"],
Cell[141215, 5334, 110, 2, 30, "Input"],
Cell[141328, 5338, 237, 6, 51, "Input"],
Cell[141568, 5346, 71, 2, 30, "Input"],
Cell[141642, 5350, 205, 5, 51, "Input"],
Cell[141850, 5357, 71, 2, 30, "Input"],
Cell[141924, 5361, 92, 2, 30, "Input"],
Cell[142019, 5365, 107, 3, 27, "Text"],
Cell[142129, 5370, 67, 2, 30, "Input"],
Cell[142199, 5374, 237, 6, 51, "Input"],
Cell[142439, 5382, 110, 2, 30, "Input"],
Cell[142552, 5386, 242, 6, 51, "Input"],
Cell[142797, 5394, 211, 5, 51, "Input"],
Cell[143011, 5401, 73, 2, 30, "Input"],
Cell[143087, 5405, 92, 2, 30, "Input"],
Cell[143182, 5409, 105, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[143324, 5417, 35, 0, 30, "Subsubsection"],
Cell[143362, 5419, 28, 0, 27, "Text"],
Cell[143393, 5421, 363, 8, 72, "Input"],
Cell[143759, 5431, 76, 2, 30, "Input"],
Cell[143838, 5435, 211, 6, 30, "Input"],
Cell[144052, 5443, 110, 2, 30, "Input"],
Cell[144165, 5447, 210, 5, 30, "Input"],
Cell[144378, 5454, 212, 5, 51, "Input"],
Cell[144593, 5461, 72, 2, 30, "Input"],
Cell[144668, 5465, 93, 2, 30, "Input"],
Cell[144764, 5469, 109, 3, 27, "Text"],
Cell[144876, 5474, 205, 6, 30, "Input"],
Cell[145084, 5482, 111, 2, 30, "Input"],
Cell[145198, 5486, 210, 5, 30, "Input"],
Cell[145411, 5493, 212, 5, 51, "Input"],
Cell[145626, 5500, 74, 2, 30, "Input"],
Cell[145703, 5504, 93, 2, 30, "Input"],
Cell[145799, 5508, 104, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[145940, 5516, 35, 0, 30, "Subsubsection"],
Cell[145978, 5518, 89, 2, 30, "Input"],
Cell[146070, 5522, 28, 0, 27, "Text"],
Cell[146101, 5524, 316, 7, 72, "Input"],
Cell[146420, 5533, 77, 2, 30, "Input"],
Cell[146500, 5537, 201, 6, 30, "Input"],
Cell[146704, 5545, 111, 2, 30, "Input"],
Cell[146818, 5549, 206, 5, 30, "Input"],
Cell[147027, 5556, 212, 5, 51, "Input"],
Cell[147242, 5563, 72, 2, 30, "Input"],
Cell[147317, 5567, 93, 2, 30, "Input"],
Cell[147413, 5571, 143, 3, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[147605, 5580, 142, 3, 45, "Subsection"],

Cell[CellGroupData[{
Cell[147772, 5587, 62, 0, 36, "Subsubsection"],
Cell[147837, 5589, 189, 4, 46, "Text"],
Cell[148029, 5595, 101, 2, 30, "Input"],
Cell[148133, 5599, 74, 2, 30, "Input"],
Cell[148210, 5603, 113, 3, 27, "Text"],
Cell[148326, 5608, 70, 2, 30, "Input"],
Cell[148399, 5612, 74, 2, 30, "Input"],
Cell[148476, 5616, 49, 0, 27, "Text"],
Cell[148528, 5618, 96, 2, 30, "Input"],
Cell[148627, 5622, 92, 2, 30, "Input"],
Cell[148722, 5626, 74, 2, 30, "Input"],
Cell[148799, 5630, 73, 2, 30, "Input"],
Cell[148875, 5634, 79, 2, 30, "Input"],
Cell[148957, 5638, 80, 2, 30, "Input"],
Cell[149040, 5642, 98, 2, 30, "Input"],
Cell[149141, 5646, 88, 2, 27, "Text"],
Cell[149232, 5650, 90, 2, 30, "Input"],
Cell[149325, 5654, 161, 3, 46, "Text"],
Cell[149489, 5659, 162, 4, 30, "Input"],
Cell[149654, 5665, 133, 3, 27, "Text"],
Cell[149790, 5670, 141, 3, 30, "Input",
  InitializationCell->True],
Cell[149934, 5675, 82, 2, 30, "Input"],
Cell[150019, 5679, 24, 0, 27, "Text"],
Cell[150046, 5681, 81, 2, 30, "Input"],
Cell[150130, 5685, 96, 2, 30, "Input"],
Cell[150229, 5689, 186, 4, 30, "Input"],
Cell[150418, 5695, 186, 4, 30, "Input"],
Cell[150607, 5701, 90, 2, 30, "Input"],
Cell[150700, 5705, 73, 2, 30, "Input"],
Cell[150776, 5709, 73, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[150886, 5716, 72, 0, 36, "Subsubsection"],
Cell[150961, 5718, 70, 2, 30, "Input"],
Cell[151034, 5722, 73, 2, 30, "Input"],
Cell[151110, 5726, 74, 2, 30, "Input"],
Cell[151187, 5730, 79, 2, 30, "Input"],
Cell[151269, 5734, 70, 2, 30, "Input"],
Cell[151342, 5738, 166, 3, 30, "Input"],
Cell[151511, 5743, 70, 2, 30, "Input"],
Cell[151584, 5747, 85, 1, 34, "Input"],
Cell[151672, 5750, 142, 3, 30, "Input",
  InitializationCell->True],
Cell[151817, 5755, 87, 2, 30, "Input"],
Cell[151907, 5759, 105, 2, 30, "Input"],
Cell[152015, 5763, 103, 2, 30, "Input"],
Cell[152121, 5767, 76, 2, 30, "Input"],
Cell[152200, 5771, 157, 3, 27, "Text"],
Cell[152360, 5776, 99, 2, 30, "Input"],
Cell[152462, 5780, 39, 0, 27, "Text"],
Cell[152504, 5782, 111, 2, 34, "Input",
  InitializationCell->True],
Cell[152618, 5786, 111, 2, 34, "Input",
  InitializationCell->True],
Cell[152732, 5790, 112, 2, 30, "Input"],
Cell[152847, 5794, 70, 2, 30, "Input"],
Cell[152920, 5798, 283, 7, 120, "Text"],
Cell[153206, 5807, 160, 4, 30, "Input",
  InitializationCell->True],
Cell[153369, 5813, 85, 2, 30, "Input"],
Cell[153457, 5817, 78, 2, 30, "Input"],
Cell[153538, 5821, 67, 2, 30, "Input"],
Cell[153608, 5825, 61, 0, 27, "Text"],
Cell[153672, 5827, 81, 2, 30, "Input"],
Cell[153756, 5831, 132, 3, 30, "Input",
  InitializationCell->True],
Cell[153891, 5836, 90, 2, 27, "Text"],
Cell[153984, 5840, 100, 2, 30, "Input"],
Cell[154087, 5844, 70, 2, 30, "Input"],
Cell[154160, 5848, 129, 2, 34, "Input",
  InitializationCell->True],
Cell[154292, 5852, 129, 2, 34, "Input",
  InitializationCell->True],
Cell[154424, 5856, 96, 2, 30, "Input"],
Cell[154523, 5860, 89, 2, 30, "Input"],
Cell[154615, 5864, 134, 3, 27, "Text"],
Cell[154752, 5869, 112, 2, 30, "Input"],
Cell[154867, 5873, 111, 2, 30, "Input"],
Cell[154981, 5877, 87, 2, 30, "Input"],
Cell[155071, 5881, 241, 5, 30, "Input",
  InitializationCell->True],
Cell[155315, 5888, 241, 5, 30, "Input",
  InitializationCell->True],
Cell[155559, 5895, 80, 2, 30, "Input"],
Cell[155642, 5899, 179, 3, 30, "Input"],
Cell[155824, 5904, 70, 2, 30, "Input"],
Cell[155897, 5908, 165, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[156099, 5916, 65, 0, 30, "Subsubsection"],
Cell[156167, 5918, 74, 2, 30, "Input"],
Cell[156244, 5922, 3653, 64, 996, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[159934, 5991, 36, 0, 36, "Subsubsection"],
Cell[159973, 5993, 139, 3, 30, "Input"],
Cell[160115, 5998, 186, 4, 51, "Input"],
Cell[160304, 6004, 65, 2, 30, "Input"],
Cell[160372, 6008, 71, 2, 30, "Input"],
Cell[160446, 6012, 205, 5, 51, "Input"],
Cell[160654, 6019, 65, 2, 30, "Input"],
Cell[160722, 6023, 71, 2, 30, "Input"],
Cell[160796, 6027, 78, 2, 30, "Input"],
Cell[160877, 6031, 70, 2, 30, "Input"],
Cell[160950, 6035, 87, 2, 30, "Input"],
Cell[161040, 6039, 107, 2, 30, "Input"],
Cell[161150, 6043, 186, 4, 27, "Text"],
Cell[161339, 6049, 190, 4, 51, "Input"],
Cell[161532, 6055, 111, 2, 30, "Input"],
Cell[161646, 6059, 70, 2, 30, "Input"],
Cell[161719, 6063, 231, 5, 51, "Input"],
Cell[161953, 6070, 66, 2, 30, "Input"],
Cell[162022, 6074, 71, 2, 30, "Input"],
Cell[162096, 6078, 221, 5, 51, "Input"],
Cell[162320, 6085, 66, 2, 30, "Input"],
Cell[162389, 6089, 71, 2, 30, "Input"],
Cell[162463, 6093, 77, 2, 30, "Input"],
Cell[162543, 6097, 73, 2, 30, "Input"],
Cell[162619, 6101, 91, 2, 30, "Input"],
Cell[162713, 6105, 164, 3, 27, "Text"],
Cell[162880, 6110, 28, 0, 27, "Text"],
Cell[162911, 6112, 202, 4, 51, "Input"],
Cell[163116, 6118, 138, 3, 30, "Input"],
Cell[163257, 6123, 70, 2, 30, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[163388, 6132, 52, 1, 23, "Subsubtitle"],
Cell[163443, 6135, 125, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[163605, 6143, 56, 1, 23, "Subsubtitle"],
Cell[163664, 6146, 140, 4, 27, "Text",
  CellTags->"S1"],
Cell[163807, 6152, 175, 4, 27, "Text",
  CellTags->{"S1", "[2]"}]
}, Closed]],

Cell[CellGroupData[{
Cell[164019, 6161, 62, 1, 23, "Subsubtitle"],
Cell[164084, 6164, 89, 4, 89, "Text"],
Cell[164176, 6170, 47, 0, 27, "Text"],
Cell[164226, 6172, 90, 2, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

